@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bcddb.h 569327 2006-08-03 14:55:06Z trueg $
+ * $Id: k3bcddb.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include <k3btoc.h>
 
 #include "k3bcddbresult.h"
-
+#include "k3b_export.h"
 
 class KConfig;
 class K3bCddbQuery;
@@ -35,7 +35,7 @@ class K3bCddbSubmit;
 class K3bCddbLocalSubmit;
 
 
-class K3bCddb : public QObject 
+class LIBK3B_EXPORT K3bCddb : public QObject 
 {
   Q_OBJECT
 
