@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bcddbresult.h 619556 2007-01-03 17:38:12Z trueg $
+ * $Id: k3bcddbresult.h 768492 2008-01-30 08:39:42Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -20,9 +20,10 @@
 
 
 #include <qstringlist.h>
+#include "k3b_export.h"
 
 
-class K3bCddbResultHeader
+class LIBK3B_EXPORT K3bCddbResultHeader
 {
  public:
   QString category;
@@ -32,7 +33,7 @@ class K3bCddbResultHeader
 };
 
 
-class K3bCddbResultEntry
+class LIBK3B_EXPORT K3bCddbResultEntry
 {
  public:
   // just to set a default
@@ -58,7 +59,7 @@ class K3bCddbResultEntry
 };
 
 
-class K3bCddbResult
+class LIBK3B_EXPORT K3bCddbResult
 {
  public:
   K3bCddbResult();
