@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdvdcopyjob.cpp 679276 2007-06-23 13:25:21Z trueg $
+ * $Id: k3bdvdcopyjob.cpp 690529 2007-07-21 10:51:47Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -31,7 +31,6 @@
 #include <k3bfilesplitter.h>
 #include <k3bchecksumpipe.h>
 #include <k3bverificationjob.h>
-#include <k3bglobalsettings.h>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -164,7 +163,7 @@ void K3bDvdCopyJob::slotDiskInfoReady( K3bDevice::DeviceHandler* dh )
     d->running = false;
   }
   else {
-    if( m_readerDevice->copyrightProtectionSystemType() > 0 ) {
+    if( m_readerDevice->copyrightProtectionSystemType() == 1 ) {
       emit infoMessage( i18n("Found encrypted DVD."), WARNING );
       // check for libdvdcss
       bool haveLibdvdcss = false;
@@ -449,7 +448,6 @@ void K3bDvdCopyJob::prepareWriter()
   d->writerJob->setBurnSpeed( m_speed );
   d->writerJob->setWritingMode( d->usedWritingMode );
   d->writerJob->setCloseDvd( true );
-  d->writerJob->setForceNoEject( true );
 
   //
   // In case the first layer size is not known let the
@@ -667,10 +665,6 @@ void K3bDvdCopyJob::slotWriterFinished( bool success )
     else {
       if( m_removeImageFiles )
 	removeImageFiles();
-
-      if( k3bcore->globalSettings()->ejectMedia() )
-          K3bDevice::eject( m_writerDevice );
-
       d->running = false;
       jobFinished(true);
     }
