@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3baudioclient.h 421129 2005-06-02 09:33:12Z trueg $
+ * $Id: k3baudioclient.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2004 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,12 +16,12 @@
 #ifndef _K3B_AUDIO_CLIENT_H_
 #define _K3B_AUDIO_CLIENT_H_
 
-
+#include "k3b_export.h"
 /**
  * Interface for all K3b audio client classes which may attach to 
  * a K3b Audio Server to play 44100 16bit stereo audio data.
  */
-class K3bAudioClient
+class LIBK3B_EXPORT K3bAudioClient
 {
  public:
   virtual ~K3bAudioClient();
