@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3baudiodoc.cpp 478440 2005-11-06 19:59:44Z trueg $
+ * $Id: k3baudiodoc.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,10 +20,10 @@
 #include "k3baudiojob.h"
 #include "k3baudiofile.h"
 #include "k3baudiozerodata.h"
-#include <k3bcuefileparser.h>
+#include "k3baudiocdtracksource.h"
 
-#include <k3bthread.h>
-#include <k3bthreadjob.h>
+#include <k3bcuefileparser.h>
+#include <k3bcdtextvalidator.h>
 #include <k3bcore.h>
 #include <k3baudiodecoder.h>
 
@@ -37,7 +37,6 @@
 #include <qdir.h>
 #include <qdom.h>
 #include <qdatetime.h>
-#include <qtimer.h>
 #include <qtextstream.h>
 #include <qsemaphore.h>
 
@@ -55,38 +54,28 @@
 #include <iostream>
 
 
-static QSemaphore s_threadCnt( 10 );
-
-// this simple thread is just used to asynchronously determine the
-// length and integrety of the tracks
-class K3bAudioDoc::AudioFileAnalyzerThread : public QThread
+class K3bAudioDoc::Private
 {
 public:
-  AudioFileAnalyzerThread( K3bAudioDecoder* dec ) 
-    : m_decoder(dec) {
+  Private() {
+    cdTextValidator = new K3bCdTextValidator();
   }
 
-  K3bAudioDecoder* m_decoder;
-
-protected:
-  void run() {
-    s_threadCnt++;
-    kdDebug() << "(AudioFileAnalyzerThread) running on decoder for " << m_decoder->filename() << endl;
-    m_decoder->analyseFile();
-    kdDebug() << "(AudioFileAnalyzerThread) finished for " << m_decoder->filename() << endl;
-    s_threadCnt--;
+  ~Private() {
+    delete cdTextValidator;
   }
+
+  K3bCdTextValidator* cdTextValidator;
 };
 
 
-
 K3bAudioDoc::K3bAudioDoc( QObject* parent )
   : K3bDoc( parent ),
     m_firstTrack(0),
     m_lastTrack(0)
 {
+  d = new Private;
   m_docType = AUDIO;
-  m_audioTrackStatusThreads.setAutoDelete(true);
 }
 
 K3bAudioDoc::~K3bAudioDoc()
@@ -100,6 +89,8 @@ K3bAudioDoc::~K3bAudioDoc()
     kdDebug() << "(K3bAudioDoc::~K3bAudioDoc) deleted." << endl;
     ++i;
   }
+
+  delete d;
 }
 
 bool K3bAudioDoc::newDocument()
@@ -113,13 +104,22 @@ bool K3bAudioDoc::newDocument()
   m_cdText = false;
   m_cdTextData.clear();
   m_audioRippingParanoiaMode = 0;
-  m_audioRippingRetries = 128;
-  m_audioRippingIgnoreReadErrors = false;
+  m_audioRippingRetries = 5;
+  m_audioRippingIgnoreReadErrors = true;
 
   return K3bDoc::newDocument();
 }
 
 
+QString K3bAudioDoc::name() const
+{
+  if( !m_cdTextData.title().isEmpty() )
+    return m_cdTextData.title();
+  else
+    return K3bDoc::name();
+}
+
+
 K3bAudioTrack* K3bAudioDoc::firstTrack() const
 {
   return m_firstTrack;
@@ -175,7 +175,8 @@ void K3bAudioDoc::addUrls( const KURL::List& urls )
 void K3bAudioDoc::addTracks( const KURL::List& urls, uint position )
 {
   KURL::List allUrls = extractUrlList( K3b::convertToLocalUrls(urls) );
-  for( KURL::List::iterator it = allUrls.begin(); it != allUrls.end(); it++, position++ ) {
+  KURL::List::iterator end( allUrls.end());
+  for( KURL::List::iterator it = allUrls.begin(); it != end; it++, position++ ) {
     KURL& url = *it;
     if( url.path().right(3).lower() == "cue" ) {
       // try adding a cue file
@@ -188,28 +189,15 @@ void K3bAudioDoc::addTracks( const KURL::List& urls, uint position )
     if( K3bAudioTrack* track = createTrack( url ) ) {
       addTrack( track, position );
 
-      //
-      // We need some evil hacking here because the meta info in the decoder will
-      // not be ready before it did not finish the analysing. So we somehow need to
-      // determine when this happens. With the current design that's a problem.
-      // So we check here if the decoder already finished and if so set the meta info
-      // right away. If not we set it in the housekeeping slot before the analysing
-      // thread is deleted.
-      //
-
       K3bAudioDecoder* dec = static_cast<K3bAudioFile*>( track->firstSource() )->decoder();
-      if( dec->length() == 0 && dec->isValid() )
-	m_decoderMetaInfoSetMap[dec].append( track );
-      else {
-	track->setTitle( dec->metaInfo( K3bAudioDecoder::META_TITLE ) );
-	track->setArtist( dec->metaInfo( K3bAudioDecoder::META_ARTIST ) );
-	track->setSongwriter( dec->metaInfo( K3bAudioDecoder::META_SONGWRITER ) );
-	track->setComposer( dec->metaInfo( K3bAudioDecoder::META_COMPOSER ) );
-	track->setCdTextMessage( dec->metaInfo( K3bAudioDecoder::META_COMMENT ) );
-      }
+      track->setTitle( dec->metaInfo( K3bAudioDecoder::META_TITLE ) );
+      track->setArtist( dec->metaInfo( K3bAudioDecoder::META_ARTIST ) );
+      track->setSongwriter( dec->metaInfo( K3bAudioDecoder::META_SONGWRITER ) );
+      track->setComposer( dec->metaInfo( K3bAudioDecoder::META_COMPOSER ) );
+      track->setCdTextMessage( dec->metaInfo( K3bAudioDecoder::META_COMMENT ) );
     }
   }
-  
+
   emit changed();
 
   informAboutNotFoundFiles();
@@ -233,6 +221,7 @@ KURL::List K3bAudioDoc::extractUrlList( const KURL::List& urls )
     }
     else if( !fi.exists() ) {
       it = allUrls.remove( it );
+      kdDebug() << url.path() << " not found" << endl;
       m_notFoundFiles.append( url );
     }
     else if( fi.isDir() ) {
@@ -246,7 +235,7 @@ KURL::List K3bAudioDoc::extractUrlList( const KURL::List& urls )
 	   dirIt != entries.end(); ++dirIt )
 	it = allUrls.insert( oldIt, KURL::fromPathOrURL( dir.absPath() + "/" + *dirIt ) );
     }
-    else if( readM3uFile( url, urlsFromPlaylist ) ) {
+    else if( readPlaylistFile( url, urlsFromPlaylist ) ) {
       it = allUrls.remove( it );
       KURL::List::iterator oldIt = it;
       // add all files into the list after the current item
@@ -262,7 +251,7 @@ KURL::List K3bAudioDoc::extractUrlList( const KURL::List& urls )
 }
 
 
-bool K3bAudioDoc::readM3uFile( const KURL& url, KURL::List& playlist )
+bool K3bAudioDoc::readPlaylistFile( const KURL& url, KURL::List& playlist )
 {
   // check if the file is a m3u playlist
   // and if so add all listed files
@@ -307,7 +296,8 @@ void K3bAudioDoc::addSources( K3bAudioTrack* parent,
 	    << urls.first().path() << ", " 
 	    << sourceAfter << " )" << endl;
   KURL::List allUrls = extractUrlList( urls );
-  for( KURL::List::const_iterator it = allUrls.begin(); it != allUrls.end(); it++ ) {
+  KURL::List::const_iterator end(allUrls.end());
+  for( KURL::List::const_iterator it = allUrls.begin(); it != end; ++it ) {
     if( K3bAudioFile* file = createAudioFile( *it ) ) {
       if( sourceAfter )
 	file->moveAfter( sourceAfter );
@@ -322,7 +312,7 @@ void K3bAudioDoc::addSources( K3bAudioTrack* parent,
 }
 
 
-K3bAudioTrack* K3bAudioDoc::importCueFile( const QString& cuefile, K3bAudioTrack* after )
+K3bAudioTrack* K3bAudioDoc::importCueFile( const QString& cuefile, K3bAudioTrack* after, K3bAudioDecoder* decoder )
 {
   if( !after )
     after = m_lastTrack;
@@ -339,8 +329,14 @@ K3bAudioTrack* K3bAudioDoc::importCueFile( const QString& cuefile, K3bAudioTrack
     if( !parser.cdText().performer().isEmpty() )
       setPerformer( parser.cdText().performer() );
 
-    K3bAudioDecoder* decoder = getDecoderForUrl( KURL::fromPathOrURL( parser.imageFilename() ) );
+    bool reused = true;
+    if( !decoder )
+      decoder = getDecoderForUrl( KURL::fromPathOrURL(parser.imageFilename()), &reused );
+
     if( decoder ) {
+      if( !reused )
+	decoder->analyseFile();
+      
       K3bAudioFile* newFile = 0;
       unsigned int i = 0;
       for( K3bDevice::Toc::const_iterator it = parser.toc().begin();
@@ -381,27 +377,21 @@ K3bAudioTrack* K3bAudioDoc::importCueFile( const QString& cuefile, K3bAudioTrack
 }
 
 
-K3bAudioDecoder* K3bAudioDoc::getDecoderForUrl( const KURL& url )
+K3bAudioDecoder* K3bAudioDoc::getDecoderForUrl( const KURL& url, bool* reused )
 {
   K3bAudioDecoder* decoder = 0;
 
   // check if we already have a proper decoder
   if( m_decoderPresenceMap.contains( url.path() ) ) {
     decoder = m_decoderPresenceMap[url.path()];
+    *reused = true;
   }
   else if( (decoder = K3bAudioDecoderFactory::createDecoder( url )) ) {
     kdDebug() << "(K3bAudioDoc) using " << decoder->className()
 	      << " for decoding of " << url.path() << endl;
     
     decoder->setFilename( url.path() );
-    
-    //
-    // start a thread to analyse the file
-    //
-    AudioFileAnalyzerThread* thread = new AudioFileAnalyzerThread( decoder );
-    thread->start();
-    m_audioTrackStatusThreads.append( thread );
-    QTimer::singleShot( 500, this, SLOT(slotHouseKeeping()) );
+    *reused = false;
   }
   
   return decoder;
@@ -412,15 +402,20 @@ K3bAudioFile* K3bAudioDoc::createAudioFile( const KURL& url )
 {
   if( !QFile::exists( url.path() ) ) {
     m_notFoundFiles.append( url.path() );
+    kdDebug() << "(K3bAudioDoc) could not find file " << url.path() << endl;
     return 0;
   }
-  
-  K3bAudioDecoder* decoder = getDecoderForUrl( url );
+
+  bool reused;  
+  K3bAudioDecoder* decoder = getDecoderForUrl( url, &reused );
   if( decoder ) {
+    if( !reused )
+      decoder->analyseFile();
     return new K3bAudioFile( decoder, this );
   }
   else {
     m_unknownFileFormatFiles.append( url.path() );
+    kdDebug() << "(K3bAudioDoc) unknown file type in file " << url.path() << endl;
     return 0;
   }
 }
@@ -617,6 +612,42 @@ bool K3bAudioDoc::loadDocumentData( QDomElement* root )
 		zero->setLength( K3b::Msf::fromString( sourceElem.attributeNode( "length" ).value() ) );
 		track->addSource( zero );
 	      }
+	      else if( sourceElem.nodeName() == "cdtrack" ) {
+		K3b::Msf length = K3b::Msf::fromString( sourceElem.attributeNode( "length" ).value() );
+		int titlenum = 0;
+		unsigned int discid = 0;
+		QString title, artist, cdTitle, cdArtist;
+
+		QDomNodeList cdTrackSourceNodes = sourceElem.childNodes();
+		for( unsigned int cdTrackSourceIndex = 0; cdTrackSourceIndex < cdTrackSourceNodes.length(); ++cdTrackSourceIndex ) {
+		  QDomElement cdTrackSourceItemElem = cdTrackSourceNodes.item(cdTrackSourceIndex).toElement();
+		  if( cdTrackSourceItemElem.nodeName() == "title_number" )
+		    titlenum = cdTrackSourceItemElem.text().toInt();
+		  else if( cdTrackSourceItemElem.nodeName() == "disc_id" )
+		    discid = cdTrackSourceItemElem.text().toUInt( 0, 16 );
+		  else if( cdTrackSourceItemElem.nodeName() == "title" )
+		    title = cdTrackSourceItemElem.text().toInt();
+		  else if( cdTrackSourceItemElem.nodeName() == "artist" )
+		    artist = cdTrackSourceItemElem.text().toInt();
+		  else if( cdTrackSourceItemElem.nodeName() == "cdtitle" )
+		    cdTitle = cdTrackSourceItemElem.text().toInt();
+		  else if( cdTrackSourceItemElem.nodeName() == "cdartist" )
+		    cdArtist = cdTrackSourceItemElem.text().toInt();
+		}
+
+		if( discid != 0 && titlenum > 0 ) {
+		  K3bAudioCdTrackSource* cdtrack = new K3bAudioCdTrackSource( discid, length, titlenum, 
+									      artist, title,
+									      cdArtist, cdTitle );
+		  cdtrack->setStartOffset( K3b::Msf::fromString( sourceElem.attributeNode( "start_offset" ).value() ) );
+		  cdtrack->setEndOffset( K3b::Msf::fromString( sourceElem.attributeNode( "end_offset" ).value() ) );
+		  track->addSource( cdtrack );
+		}
+		else {
+		  kdDebug() << "(K3bAudioDoc) invalid cdtrack source." << endl;
+		  return false;
+		}
+	      }
 	      else {
 		kdDebug() << "(K3bAudioDoc) unknown source type: " << sourceElem.nodeName() << endl;
 		return false;
@@ -654,6 +685,8 @@ bool K3bAudioDoc::loadDocumentData( QDomElement* root )
 	  else if( trackNodes.item(trackJ).nodeName() == "index0" )
 	    track->setIndex0( K3b::Msf::fromString( trackNodes.item(trackJ).toElement().text() ) );
 
+	  // TODO: load other indices
+
 	  // load options
 	  else if( trackNodes.item(trackJ).nodeName() == "copy_protection" )
 	    track->setCopyProtection( trackNodes.item(trackJ).toElement().text() == "yes" );
@@ -779,6 +812,38 @@ bool K3bAudioDoc::saveDocumentData( QDomElement* docElem )
 	sourceElem.setAttribute( "length", zero->length().toString() );
 	sourcesParent.appendChild( sourceElem );
       }
+      else if( K3bAudioCdTrackSource* cdTrack = dynamic_cast<K3bAudioCdTrackSource*>(source) ) {
+	QDomElement sourceElem = doc.createElement( "cdtrack" );
+	sourceElem.setAttribute( "length", cdTrack->originalLength().toString() );	
+	sourceElem.setAttribute( "start_offset", cdTrack->startOffset().toString() );
+	sourceElem.setAttribute( "end_offset", cdTrack->endOffset().toString() );
+
+	QDomElement subElem = doc.createElement( "title_number" );
+	subElem.appendChild( doc.createTextNode( QString::number(cdTrack->cdTrackNumber()) ) );
+	sourceElem.appendChild( subElem );
+
+	subElem = doc.createElement( "disc_id" );
+	subElem.appendChild( doc.createTextNode( QString::number(cdTrack->discId(), 16) ) );
+	sourceElem.appendChild( subElem );
+
+	subElem = doc.createElement( "title" );
+	subElem.appendChild( doc.createTextNode( cdTrack->metaInfo().titles[cdTrack->cdTrackNumber()-1] ) );
+	sourceElem.appendChild( subElem );
+
+	subElem = doc.createElement( "artist" );
+	subElem.appendChild( doc.createTextNode( cdTrack->metaInfo().artists[cdTrack->cdTrackNumber()-1] ) );
+	sourceElem.appendChild( subElem );
+
+	subElem = doc.createElement( "cdtitle" );
+	subElem.appendChild( doc.createTextNode( cdTrack->metaInfo().cdTitle ) );
+	sourceElem.appendChild( subElem );
+
+	subElem = doc.createElement( "cdartist" );
+	subElem.appendChild( doc.createTextNode( cdTrack->metaInfo().cdArtist ) );
+	sourceElem.appendChild( subElem );
+
+	sourcesParent.appendChild( sourceElem );
+      }
       else {
 	kdError() << "(K3bAudioDoc) saving sources other than file or zero not supported yet." << endl;
 	return false;
@@ -861,24 +926,27 @@ void K3bAudioDoc::informAboutNotFoundFiles()
 {
   if( !m_notFoundFiles.isEmpty() ) {
     QStringList l;
-    for( KURL::List::const_iterator it = m_notFoundFiles.begin(); 
+    for( KURL::List::const_iterator it = m_notFoundFiles.begin();
 	 it != m_notFoundFiles.end(); ++it )
       l.append( (*it).path() );
-    KMessageBox::informationList( qApp->activeWindow(), 
+    KMessageBox::informationList( qApp->activeWindow(),
 				  i18n("Could not find the following files:"),
- 				  l,
+				  l,
 				  i18n("Not Found") );
-    
+
     m_notFoundFiles.clear();
   }
   if( !m_unknownFileFormatFiles.isEmpty() ) {
     QStringList l;
-    for( KURL::List::const_iterator it = m_unknownFileFormatFiles.begin(); 
+    for( KURL::List::const_iterator it = m_unknownFileFormatFiles.begin();
 	 it != m_unknownFileFormatFiles.end(); ++it )
       l.append( (*it).path() );
-    KMessageBox::informationList( qApp->activeWindow(), 
-				  i18n("Unable to handle the following files due to an unsupported format:"),
- 				  l,
+    KMessageBox::informationList( qApp->activeWindow(),
+				  i18n("<p>Unable to handle the following files due to an unsupported format:"
+				       "<p>You may manually convert these audio files to wave using another "
+				       "application supporting the audio format and then add the wave files "
+				       "to the K3b project."),
+				  l,
 				  i18n("Unsupported Format") );
 
     m_unknownFileFormatFiles.clear();
@@ -886,6 +954,7 @@ void K3bAudioDoc::informAboutNotFoundFiles()
 }
 
 
+
 void K3bAudioDoc::removeCorruptTracks()
 {
 //   K3bAudioTrack* track = m_tracks->first();
@@ -904,10 +973,11 @@ void K3bAudioDoc::slotTrackChanged( K3bAudioTrack* track )
 {
   kdDebug() << "(K3bAudioDoc::slotTrackChanged " << track << endl;
   setModified( true );
-  emit changed();
   // if the track is empty now we simply delete it
-  if( track->firstSource() )
+  if( track->firstSource() ) {
     emit trackChanged(track);
+    emit changed();
+  }
   else {
     kdDebug() << "(K3bAudioDoc::slotTrackChanged) track " << track << " empty. Deleting." << endl;
     delete track; // this will emit the proper signal
@@ -939,50 +1009,15 @@ void K3bAudioDoc::increaseDecoderUsage( K3bAudioDecoder* decoder )
 
 void K3bAudioDoc::decreaseDecoderUsage( K3bAudioDecoder* decoder )
 {
-  // FIXME: what if the thread did not finish yet?
   m_decoderUsageCounterMap[decoder]--;
   if( m_decoderUsageCounterMap[decoder] <= 0 ) {
     m_decoderUsageCounterMap.erase(decoder);
     m_decoderPresenceMap.erase(decoder->filename());
-    m_decoderMetaInfoSetMap.erase(decoder);
     delete decoder;
   }
 }
 
 
-void K3bAudioDoc::slotHouseKeeping()
-{
-  kdDebug() << "(K3bAudioDoc::slotHouseKeeping)" << endl;
-  for( QPtrListIterator<AudioFileAnalyzerThread> it( m_audioTrackStatusThreads );
-       it.current(); ++it ) {
-    AudioFileAnalyzerThread* thread = *it;
-    if( thread->finished() ) {
-      kdDebug() << "(K3bAudioDoc::slotHouseKeeping) removing thread for "
-		<< thread->m_decoder->filename() << endl;
-
-      const QPtrList<K3bAudioTrack>& tracks = m_decoderMetaInfoSetMap[thread->m_decoder];
-      for( QPtrListIterator<K3bAudioTrack> it( tracks ); *it; ++it ) {
-	K3bAudioTrack* track = *it;
-	track->setTitle( thread->m_decoder->metaInfo( K3bAudioDecoder::META_TITLE ) );
-	track->setPerformer( thread->m_decoder->metaInfo( K3bAudioDecoder::META_ARTIST ) );
-	track->setSongwriter( thread->m_decoder->metaInfo( K3bAudioDecoder::META_SONGWRITER ) );
-	track->setComposer( thread->m_decoder->metaInfo( K3bAudioDecoder::META_COMPOSER ) );
-	track->setCdTextMessage( thread->m_decoder->metaInfo( K3bAudioDecoder::META_COMMENT ) );
-      }
-      m_decoderMetaInfoSetMap.erase( thread->m_decoder );
-      m_audioTrackStatusThreads.removeRef( thread );
-    }
-  }
-
-  if( !m_audioTrackStatusThreads.isEmpty() )
-    QTimer::singleShot( 500, this, SLOT(slotHouseKeeping()) );
-  else
-    emit changed(); // inform about the changed length
-
-  kdDebug() << "(K3bAudioDoc::slotHouseKeeping) finished" << endl;
-}
-
-
 K3bDevice::CdText K3bAudioDoc::cdTextData() const
 {
   K3bDevice::CdText text( m_cdTextData );
@@ -1013,4 +1048,80 @@ K3bDevice::Toc K3bAudioDoc::toToc() const
   return toc; 
 }
 
+
+void K3bAudioDoc::setTitle( const QString& v )
+{
+  m_cdTextData.setTitle( v );
+  emit changed();
+}
+
+
+void K3bAudioDoc::setArtist( const QString& v )
+{
+  setPerformer( v );
+}
+
+
+void K3bAudioDoc::setPerformer( const QString& v )
+{
+  QString s( v );
+  d->cdTextValidator->fixup( s );
+  m_cdTextData.setPerformer( s );
+  emit changed();
+}
+
+
+void K3bAudioDoc::setDisc_id( const QString& v )
+{
+  QString s( v );
+  d->cdTextValidator->fixup( s );
+  m_cdTextData.setDiscId( s );
+  emit changed();
+}
+
+
+void K3bAudioDoc::setArranger( const QString& v )
+{
+  QString s( v );
+  d->cdTextValidator->fixup( s );
+  m_cdTextData.setArranger( s );
+  emit changed();
+}
+
+
+void K3bAudioDoc::setSongwriter( const QString& v )
+{
+  QString s( v );
+  d->cdTextValidator->fixup( s );
+  m_cdTextData.setSongwriter( s );
+  emit changed();
+}
+
+
+void K3bAudioDoc::setComposer( const QString& v )
+{
+  QString s( v );
+  d->cdTextValidator->fixup( s );
+  m_cdTextData.setComposer( s );
+  emit changed();
+}
+
+
+void K3bAudioDoc::setUpc_ean( const QString& v )
+{
+  QString s( v );
+  d->cdTextValidator->fixup( s );
+  m_cdTextData.setUpcEan( s );
+  emit changed();
+}
+
+
+void K3bAudioDoc::setCdTextMessage( const QString& v )
+{
+  QString s( v );
+  d->cdTextValidator->fixup( s );
+  m_cdTextData.setMessage( s );
+  emit changed();
+}
+
 #include "k3baudiodoc.moc"
