@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3baudiojob.cpp 630823 2007-02-06 14:07:10Z trueg $
+ * $Id: k3baudiojob.cpp 690212 2007-07-20 11:02:13Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -692,9 +692,12 @@ void K3bAudioJob::cleanupAfterError()
 
 void K3bAudioJob::removeBufferFiles()
 {
-  emit infoMessage( i18n("Removing temporary files."), INFO );
+    if ( !m_doc->onTheFly() ) {
+        emit infoMessage( i18n("Removing temporary files."), INFO );
+    }
 
-  m_tempData->cleanup();
+    // removes buffer images and temp toc or inf files
+    m_tempData->cleanup();
 }
 
 
