@@ -52,10 +52,10 @@ void K3bAudioNormalizeJob::start()
   connect( m_process, SIGNAL(stderrLine(const QString&)), this, SLOT(slotStdLine(const QString&)) );
   connect( m_process, SIGNAL(processExited(KProcess*)), this, SLOT(slotProcessExited(KProcess*)) );
 
-  const K3bExternalBin* bin = k3bcore->externalBinManager()->binObject( "normalize-audio" );
+  const K3bExternalBin* bin = k3bcore->externalBinManager()->binObject( "normalize" );
 
   if( !bin ) {
-    emit infoMessage( i18n("Could not find normalize-audio executable."), ERROR );
+    emit infoMessage( i18n("Could not find normalize executable."), ERROR );
     jobFinished(false);
     return;
   }
@@ -82,8 +82,8 @@ void K3bAudioNormalizeJob::start()
   if( !m_process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) {
     // something went wrong when starting the program
     // it "should" be the executable
-    kdDebug() << "(K3bAudioNormalizeJob) could not start normalize-audio" << endl;
-    emit infoMessage( i18n("Could not start normalize-audio."), K3bJob::ERROR );
+    kdDebug() << "(K3bAudioNormalizeJob) could not start normalize" << endl;
+    emit infoMessage( i18n("Could not start normalize."), K3bJob::ERROR );
     jobFinished(false);
   }
 }
@@ -106,7 +106,7 @@ void K3bAudioNormalizeJob::slotStdLine( const QString& line )
 
   //  emit newSubTask( i18n("Normalizing track %1 of %2 (%3)").arg(t).arg(tt).arg(m_files.at(t-1)) );
 
-  emit debuggingOutput( "normalize-audio", line );
+  emit debuggingOutput( "normalize", line );
 
   // wenn "% done" drin:
   //    wenn ein --% drin ist, so beginnt ein neuer track
@@ -185,7 +185,7 @@ void K3bAudioNormalizeJob::slotProcessExited( KProcess* p )
       break;
     default:
       if( !m_canceled ) {
-	emit infoMessage( i18n("%1 returned an unknown error (code %2).").arg("normalize-audio").arg(p->exitStatus()), 
+	emit infoMessage( i18n("%1 returned an unknown error (code %2).").arg("normalize").arg(p->exitStatus()), 
 			  K3bJob::ERROR );
 	emit infoMessage( i18n("Please send me an email with the last output."), K3bJob::ERROR );
 	emit infoMessage( i18n("Error while normalizing tracks."), ERROR );
@@ -197,7 +197,7 @@ void K3bAudioNormalizeJob::slotProcessExited( KProcess* p )
     }
   }
   else {
-    emit infoMessage( i18n("%1 did not exit cleanly.").arg("Normalize-audio"), K3bJob::ERROR );
+    emit infoMessage( i18n("%1 did not exit cleanly.").arg("Normalize"), K3bJob::ERROR );
     jobFinished( false );
   }
 }
