@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdatajob.cpp 679276 2007-06-23 13:25:21Z trueg $
+ * $Id: k3bdatajob.cpp 690187 2007-07-20 09:18:03Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -480,9 +480,6 @@ void K3bDataJob::slotWriterJobFinished( bool success )
 	}
       }
       else {
-          if( k3bcore->globalSettings()->ejectMedia() )
-              K3bDevice::eject( d->doc->burner() );
-
 	cleanup();
 	jobFinished(true);
       }
@@ -636,7 +633,6 @@ bool K3bDataJob::prepareWriterJob()
     }
 
     writer->addArgument( QString("-tsize=%1s").arg(m_isoImager->size()) )->addArgument("-");
-    writer->setForceNoEject( true );
 
     setWriterJob( writer );
   }
@@ -649,7 +645,6 @@ bool K3bDataJob::prepareWriterJob()
     // multisession
     writer->setMulti( d->usedMultiSessionMode == K3bDataDoc::START ||
 		      d->usedMultiSessionMode == K3bDataDoc::CONTINUE );
-    writer->setForceNoEject( true );
 
     // now write the tocfile
     if( d->tocFile ) delete d->tocFile;
