@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bmkisofshandler.h 400832 2005-03-26 20:20:35Z trueg $
+ * $Id: k3bmkisofshandler.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2005 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2005 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,8 +36,22 @@ class K3bMkisofsHandler
   bool mkisofsReadError() const;
 
  protected:
-  void initMkisofs( const K3bExternalBin* );
-  void handleMkisofsOutput( const QString& line );
+  /**
+   * Initialize the MkisofsHandler.
+   * This method emits copyright information and an error message in case mkisofs is not installed
+   * through handleMkisofsInfoMessage.
+   *
+   * \return A mkisofs bin object to be used or 0 if mkisofs is not installed.
+   */
+  const K3bExternalBin* initMkisofs();
+
+  void parseMkisofsOutput( const QString& line );
+
+  /**
+   * Used internally by handleMkisofsOutput.
+   * May be used in case handleMkisofsOutput is not sufficient.
+   */
+  int parseMkisofsProgress( const QString& line );
 
   /**
    * Called by handleMkisofsOutput
@@ -51,8 +65,6 @@ class K3bMkisofsHandler
    */
   virtual void handleMkisofsInfoMessage( const QString&, int ) = 0;
 
-  int parseMkisofsProgress( const QString& line );
-
  private:
   class Private;
   Private* d;
