@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bsessionimportitem.h 411979 2005-05-10 14:49:41Z trueg $
+ * $Id: k3bsessionimportitem.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,13 +30,14 @@ class K3bSessionImportItem : public K3bDataItem
 {
  public:
   K3bSessionImportItem( const K3bIso9660File*, K3bDataDoc* doc, K3bDirItem* );
+  K3bSessionImportItem( const K3bSessionImportItem& );
   ~K3bSessionImportItem();
 
+  K3bDataItem* copy() const;
+
   K3bFileItem* replaceItem() const { return m_replaceItem; }
   void setReplaceItem( K3bFileItem* item ) { m_replaceItem = item; }
 
-  KIO::filesize_t size() const { return m_size; }
-
   bool isFile() const { return false; }
   bool isFromOldSession() const { return true; }
 
@@ -46,6 +47,14 @@ class K3bSessionImportItem : public K3bDataItem
   bool isHideable() const { return false; }
   bool writeToCd() const { return false; }
 
+ protected:
+  // the size of an item from an imported session does not depend
+  // on the value of followSymlinks
+  /**
+   * Normally one does not use this method but K3bDataItem::size()
+   */
+  KIO::filesize_t itemSize( bool ) const { return m_size; }
+
  private:
   K3bFileItem* m_replaceItem;
   KIO::filesize_t m_size;
