@@ -1,11 +1,11 @@
 /*
  *
- * $Id: k3bcdrdaowriter.cpp 383526 2005-01-29 00:17:20Z trueg $
+ * $Id: k3bcdrdaowriter.cpp 654649 2007-04-16 17:55:50Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *                    Klaus-Dieter Krannich <kd@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,9 +44,6 @@
 #include <kstandarddirs.h>
 #include <ktempfile.h>
 
-#include <errno.h>
-#include <string.h>
-
 #include <sys/types.h>
 #include <sys/socket.h>
 
@@ -289,6 +286,11 @@ void K3bCdrdaoWriter::setWriteArguments()
       emit infoMessage( i18n("Cdrdao %1 does not support disabling burnfree.").arg(m_cdrdaoBinObject->version), WARNING );
   }
   
+  if( k3bcore->globalSettings()->force() ) {
+    *m_process << "--force";
+    emit infoMessage( i18n("'Force unsafe operations' enabled."), WARNING );
+  }
+
   bool manualBufferSize =
     k3bcore->globalSettings()->useManualBufferSize();
   if( manualBufferSize ) {
@@ -453,7 +455,7 @@ K3bCdrdaoWriter* K3bCdrdaoWriter::addArgument( const QString& arg )
 
 void K3bCdrdaoWriter::start()
 {
-  emit started();
+  jobStarted();
 
   d->speedEst->reset();
 
@@ -474,7 +476,7 @@ void K3bCdrdaoWriter::start()
 
   if( !m_cdrdaoBinObject ) {
     emit infoMessage( i18n("Could not find %1 executable.").arg("cdrdao"), ERROR );
-    emit finished(false);
+    jobFinished(false);
     return;
   }
 
@@ -518,7 +520,7 @@ void K3bCdrdaoWriter::start()
 	      {
 		kdDebug() << "(K3bCdrdaoWriter) could not backup " << m_tocFile << " to " << m_backupTocFile << endl;
 		emit infoMessage( i18n("Could not backup tocfile."), ERROR );
-		emit finished(false);
+		jobFinished(false);
 		return;
 	      }
 	  }
@@ -561,13 +563,27 @@ void K3bCdrdaoWriter::start()
       break;
     }
 
+  // FIXME: check the return value
+  if( K3b::isMounted( burnDevice() ) ) {
+    emit infoMessage( i18n("Unmounting medium"), INFO );
+    K3b::unmount( burnDevice() );
+  }
+
+  // block the device (including certain checks)
+  k3bcore->blockDevice( burnDevice() );
+
+  // lock the device for good in this process since it will
+  // be opened in the growisofs process
+  burnDevice()->close();
+  burnDevice()->usageLock();
+
   if( !m_process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) )
     {
       // something went wrong when starting the program
       // it "should" be the executable
       kdDebug() << "(K3bCdrdaoWriter) could not start cdrdao" << endl;
       emit infoMessage( i18n("Could not start %1.").arg("cdrdao"), K3bJob::ERROR );
-      emit finished(false);
+      jobFinished(false);
     }
   else
     {
@@ -695,6 +711,11 @@ void K3bCdrdaoWriter::slotStdLine( const QString& line )
 
 void K3bCdrdaoWriter::slotProcessExited( KProcess* p )
 {
+  // release the device within this process
+  burnDevice()->usageUnlock();
+
+  // unblock the device
+  k3bcore->unblockDevice( burnDevice() );
 
   switch ( m_command )
   {
@@ -734,21 +755,21 @@ void K3bCdrdaoWriter::slotProcessExited( KProcess* p )
     {
     case 0:
       if( simulate() )
-        emit infoMessage( i18n("Simulation successfully finished"), K3bJob::SUCCESS );
+        emit infoMessage( i18n("Simulation successfully completed"), K3bJob::SUCCESS );
       else
         switch ( m_command )
         {
         case READ:
-          emit infoMessage( i18n("Reading successfully finished"), K3bJob::SUCCESS );
+          emit infoMessage( i18n("Reading successfully completed"), K3bJob::SUCCESS );
           break;
         case WRITE:
-          emit infoMessage( i18n("Writing successfully finished"), K3bJob::SUCCESS );
+          emit infoMessage( i18n("Writing successfully completed"), K3bJob::SUCCESS );
           break;
         case COPY:
-          emit infoMessage( i18n("Copying successfully finished"), K3bJob::SUCCESS );
+          emit infoMessage( i18n("Copying successfully completed"), K3bJob::SUCCESS );
           break;
         case BLANK:
-          emit infoMessage( i18n("Blanking successfully finished"), K3bJob::SUCCESS );
+          emit infoMessage( i18n("Blanking successfully completed"), K3bJob::SUCCESS );
           break;
         }
 
@@ -757,25 +778,24 @@ void K3bCdrdaoWriter::slotProcessExited( KProcess* p )
 	emit infoMessage( i18n("Average overall write speed: %1 KB/s (%2x)").arg(s).arg(KGlobal::locale()->formatNumber((double)s/150.0), 2), INFO );
       }
 
-      emit finished( true );
+      jobFinished( true );
       break;
 
     default:
       if( !m_knownError && !wasSourceUnreadable() ) {
         emit infoMessage( i18n("%1 returned an unknown error (code %2).").arg(m_cdrdaoBinObject->name()).arg(p->exitStatus()), 
 			  K3bJob::ERROR );
-	emit infoMessage( strerror(p->exitStatus()), K3bJob::ERROR );
 	emit infoMessage( i18n("Please include the debugging output in your problem report."), K3bJob::ERROR );
       }
 
-      emit finished( false );
+      jobFinished( false );
       break;
     }
   }
   else
   {
     emit infoMessage( i18n("%1 did not exit cleanly.").arg("cdrdao"), K3bJob::ERROR );
-    emit finished( false );
+    jobFinished( false );
   }
 }
 
