@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bcuefileparser.cpp 553356 2006-06-20 20:10:50Z trueg $
+ * $Id: k3bcuefileparser.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,24 @@
 #include <kdebug.h>
 
 
+// avoid usage of QTextStream since K3b often
+// tries to open big files (iso images) in a 
+// cue file parser to test it.
+static QString readLine( QFile* f )
+{
+  QString s;
+  Q_LONG r = f->readLine( s, 1024 );
+  if( r >= 0 ) {
+    // remove the trailing newline
+    return s.stripWhiteSpace();
+  }
+  else {
+    // end of file or error
+    return QString::null;
+  }
+}
+
+
 // TODO: add method: usableByCdrecordDirectly()
 // TODO: add Toc with sector sizes
 
@@ -78,8 +96,7 @@ void K3bCueFileParser::readFile()
 
   QFile f( filename() );
   if( f.open( IO_ReadOnly ) ) {
-    QTextStream s( &f );
-    QString line = s.readLine();
+    QString line = readLine( &f );
     while( !line.isNull() ) {
       
       if( !parseLine(line) ) {
@@ -87,7 +104,7 @@ void K3bCueFileParser::readFile()
 	break;
       }
 
-      line = s.readLine();
+      line = readLine( &f );
     }
 
     if( isValid() ) {
@@ -424,7 +441,7 @@ bool K3bCueFileParser::findImageFileName( const QString& dataFile )
   kdDebug() << "(K3bCueFileParser) checking folder " << parentDir.path() << " for files: " << filenamePrefix << "*" << endl;
 
   //
-  // we cannot use the nameFilter in QDir because of the spaces that may occure in filenames
+  // we cannot use the nameFilter in QDir because of the spaces that may occur in filenames
   //
   QStringList possibleImageFiles = parentDir.entryList( QDir::Files );
   int cnt = 0;
