@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bgrowisofshandler.cpp 510757 2006-02-17 23:13:49Z trueg $
+ * $Id: k3bgrowisofshandler.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -102,6 +102,14 @@ void K3bGrowisofsHandler::handleLine( const QString& line )
 	emit infoMessage( i18n("Trying to write more than the official disk capacity"), K3bJob::WARNING );
     }
 
+    else if( line.startsWith( ":-( unable to anonymously mmap" ) ) {
+      m_error = ERROR_MEMLOCK;
+    }
+
+    else if( line.startsWith( ":-( write failed" ) ) {
+      m_error = ERROR_WRITE_FAILED;
+    }
+
     else  
       emit infoMessage( line, K3bJob::ERROR );
   }
@@ -155,7 +163,7 @@ void K3bGrowisofsHandler::handleLine( const QString& line )
       // FIXME: it's not only the writer. It may be the media: something like does not support it with this media
       //        da war was mit: wenn einmal formattiert, dann geht nur noch dao oder wenn einmal als overwrite
       //        formattiert, dann nur noch dao oder sowas
-      emit infoMessage( i18n("Writer does not support Incremental Streaming"), K3bJob::WARNING );
+      emit infoMessage( i18n("Writing mode Incremental Streaming not available"), K3bJob::WARNING );
       emit infoMessage( i18n("Engaging DAO"), K3bJob::WARNING );
     }
   }
@@ -175,6 +183,9 @@ void K3bGrowisofsHandler::handleLine( const QString& line )
       kdDebug() << "(K3bGrowisofsHandler) parsing error: '" << line.mid( pos, endPos-pos ) << "'" << endl;
   }
   else if( (pos = line.find( "RBU" )) > 0 ) {
+
+    // FIXME: use QRegExp
+
     // parse ring buffer fill for growisofs >= 6.0
     pos += 4;
     int endPos = line.find( '%', pos+1 );
@@ -186,18 +197,25 @@ void K3bGrowisofsHandler::handleLine( const QString& line )
 	d->lastBuffer = newBuffer;
 	emit buffer( newBuffer );
       }
+
+      // device buffer for growisofs >= 7.0
+      pos = line.find( "UBU", pos );
+      endPos = line.find( '%', pos+5 );
+      if( pos > 0 ) {
+	pos += 4;
+	val = line.mid( pos, endPos-pos ).toDouble( &ok );
+	if( ok ) {
+	  int newBuffer = (int)(val+0.5);
+	  if( newBuffer != d->lastDeviceBuffer ) {
+	    d->lastDeviceBuffer = newBuffer;
+	    emit deviceBuffer( newBuffer );
+	  }
+	}
+      }
     }
     else
       kdDebug() << "(K3bGrowisofsHandler) failed to parse ring buffer fill from '" << line.mid( pos, endPos-pos ) << "'" << endl;
   }
-  else if( line.startsWith("Buffer fill") ) {
-    // parse device buffer fill for K3b patched growisofs
-    int newBuffer = line.mid(13, line.find('%',13)-13).toInt();
-    if( newBuffer != d->lastDeviceBuffer ) {
-      d->lastDeviceBuffer = newBuffer;
-      emit deviceBuffer( newBuffer );
-    }
-  }
 
   else {
     kdDebug() << "(growisofs) " << line << endl;
@@ -232,6 +250,17 @@ void K3bGrowisofsHandler::handleExit( int exitCode )
 			   "growisofs user parameters in the K3b settings."), K3bJob::ERROR );
     break;
 
+  case ERROR_MEMLOCK:
+    emit infoMessage( i18n("Unable to allocate software buffer."), K3bJob::ERROR );
+    emit infoMessage( i18n("This error is caused by the low memorylocked resource limit."), K3bJob::ERROR );
+    emit infoMessage( i18n("It can be solved by issuing the command 'ulimit -l unlimited'..."), K3bJob::ERROR );
+    emit infoMessage( i18n("...or by lowering the used software buffer size in the advanced K3b settings."), K3bJob::ERROR );
+    break;
+
+  case ERROR_WRITE_FAILED:
+    emit infoMessage( i18n("Write error"), K3bJob::ERROR );
+    break;
+
   default:
 
     //
@@ -243,7 +272,7 @@ void K3bGrowisofsHandler::handleExit( int exitCode )
 
     if( exitCode > 128 ) {
       // for now we just emit a message with the error
-      // in the future when I know more about what kinds of errors may occure
+      // in the future when I know more about what kinds of errors may occur
       // we will enhance this
       emit infoMessage( i18n("Fatal error at startup: %1").arg(strerror(exitCode-128)), 
 			K3bJob::ERROR );
