@@ -1,10 +1,10 @@
 /*
 *
-* $Id: k3bvcddoc.cpp 474610 2005-10-26 20:49:57Z trueg $
+* $Id: k3bvcddoc.cpp 619556 2007-01-03 17:38:12Z trueg $
 * Copyright (C) 2003-2005 Christian Kvasny <chris@k3b.org>
 *
 * This file is part of the K3b project.
-* Copyright (C) 1998-2005 Sebastian Trueg <trueg@k3b.org>
+* Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -88,6 +88,13 @@ bool K3bVcdDoc::newDocument()
     return K3bDoc::newDocument();
 }
 
+
+QString K3bVcdDoc::name() const
+{
+  return m_vcdOptions->volumeId();
+}
+
+
 KIO::filesize_t K3bVcdDoc::calcTotalSize() const
 {
     unsigned long long sum = 0;
@@ -138,8 +145,9 @@ void K3bVcdDoc::addUrls( const KURL::List& urls )
 
 void K3bVcdDoc::addTracks( const KURL::List& urls, uint position )
 {
-    for ( KURL::List::ConstIterator it = urls.begin(); it != urls.end(); it++ ) {
-      urlsToAdd.enqueue( new PrivateUrlToAdd( K3b::convertToLocalUrl(*it), position++ ) );
+    KURL::List::ConstIterator end( urls.end() );
+    for ( KURL::List::ConstIterator it = urls.begin(); it != end; ++it ) {
+        urlsToAdd.enqueue( new PrivateUrlToAdd( K3b::convertToLocalUrl(*it), position++ ) );
     }
 
     m_urlAddingTimer->start( 0 );
@@ -266,6 +274,7 @@ K3bVcdTrack* K3bVcdDoc::createTrack( const KURL& url )
             return newTrack;
         }
     } else if ( isImage( url ) ) { // image track
+        // woking on ...
         // for future use
         // photoalbum starts here
         // return here the new photoalbum track
