@@ -1,10 +1,10 @@
 /*
 *
-* $Id: k3bvcdjob.cpp 395391 2005-03-07 01:42:30Z trueg $
+* $Id: k3bvcdjob.cpp 619556 2007-01-03 17:38:12Z trueg $
 * Copyright (C) 2003-2004 Christian Kvasny <chris@k3b.org>
 *
 * This file is part of the K3b project.
-* Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+* Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -76,6 +76,9 @@ K3bDoc* K3bVcdJob::doc() const
 
 K3bDevice::Device* K3bVcdJob::writer() const
 {
+  if( doc()->onlyCreateImages() )
+    return 0;
+  else
     return doc() ->burner();
 }
 
@@ -84,7 +87,7 @@ void K3bVcdJob::cancel()
     cancelAll();
 
     emit canceled();
-    emit finished( false );
+    jobFinished( false );
 }
 
 
@@ -126,7 +129,7 @@ void K3bVcdJob::start()
 {
     kdDebug() << "(K3bVcdJob) starting job" << endl;
 
-    emit started();
+    jobStarted();
     emit burning( false );
     m_canceled = false;
 
@@ -158,7 +161,7 @@ void K3bVcdJob::xmlGen()
         kdDebug() << "(K3bVcdJob) could not write xmlfile." << endl;
         emit infoMessage( i18n( "Could not write correct XML-file." ), K3bJob::ERROR );
         cancelAll();
-        emit finished( false );
+        jobFinished( false );
     }
 
     //    emit infoMessage( i18n( "XML-file successfully created" ), K3bJob::SUCCESS );
@@ -185,7 +188,7 @@ void K3bVcdJob::vcdxBuild()
         emit infoMessage( i18n( "To create VideoCDs you must install VcdImager Version %1." ).arg( ">= 0.7.12" ), K3bJob::INFO );
         emit infoMessage( i18n( "You can find this on your distribution disks or download it from http://www.vcdimager.org" ), K3bJob::INFO );
         cancelAll();
-        emit finished( false );
+        jobFinished( false );
         return ;
     }
 
@@ -194,7 +197,7 @@ void K3bVcdJob::vcdxBuild()
         emit infoMessage( i18n( "%1 executable too old: need version %2 or greater." ).arg( "Vcdxbuild" ).arg( "0.7.12" ), K3bJob::ERROR );
         emit infoMessage( i18n( "You can find this on your distribution disks or download it from http://www.vcdimager.org" ), K3bJob::INFO );
         cancelAll();
-        emit finished( false );
+        jobFinished( false );
         return ;
     }
 
@@ -244,7 +247,7 @@ void K3bVcdJob::vcdxBuild()
         kdDebug() << "(K3bVcdJob) could not start vcdxbuild" << endl;
         emit infoMessage( i18n( "Could not start %1." ).arg( "vcdxbuild" ), K3bJob::ERROR );
         cancelAll();
-        emit finished( false );
+        jobFinished( false );
     }
 }
 
@@ -259,7 +262,7 @@ void K3bVcdJob::slotParseVcdxBuildOutput( KProcess*, char* output, int len )
     QDomElement xml_root;
 
     // do every line
-    for ( QStringList::Iterator str = lines.begin(); str != lines.end(); str++ ) {
+    for ( QStringList::Iterator str = lines.begin(); str != lines.end(); ++str ) {
         *str = ( *str ).stripWhiteSpace();
 
         emit debuggingOutput( "vcdxbuild", *str );
@@ -278,7 +281,7 @@ void K3bVcdJob::slotParseVcdxBuildOutput( KProcess*, char* output, int len )
 
             if ( tagName == "progress" ) {
                 const QString oper = el.attribute( "operation" ).lower();
-                const long long pos = el.attribute( "position" ).toLong();
+                const unsigned long long pos = el.attribute( "position" ).toLong();
                 const long long size = el.attribute( "size" ).toLong();
 
                 if ( oper == "scan" ) {
@@ -352,16 +355,15 @@ void K3bVcdJob::slotVcdxBuildFinished()
             default:
                 emit infoMessage( i18n( "%1 returned an unknown error (code %2)." ).arg( "vcdxbuild" ).arg( m_process->exitStatus() ),
                                   K3bJob::ERROR );
-                emit infoMessage( strerror( m_process->exitStatus() ), K3bJob::ERROR );
                 emit infoMessage( i18n( "Please send me an email with the last output." ), K3bJob::ERROR );
                 cancelAll();
-                emit finished( false );
+                jobFinished( false );
                 return ;
         }
     } else {
         emit infoMessage( i18n( "%1 did not exit cleanly." ).arg( "Vcdxbuild" ), K3bJob::ERROR );
         cancelAll();
-        emit finished( false );
+        jobFinished( false );
         return ;
     }
 
@@ -374,7 +376,7 @@ void K3bVcdJob::slotVcdxBuildFinished()
     if ( !vcdDoc() ->onlyCreateImages() )
         startWriterjob();
     else
-        emit finished( true );
+        jobFinished( true );
 }
 
 void K3bVcdJob::startWriterjob()
@@ -493,18 +495,18 @@ void K3bVcdJob::slotWriterJobFinished( bool success )
         // allright
         // the writerJob should have emited the "simulation/writing successful" signal
         if ( m_currentcopy >= m_doc->copies() ) {
-            emit finished( true );
+            jobFinished( true );
         } else {
             m_currentcopy++;
             startWriterjob();
         }
     } else {
         cancelAll();
-        emit finished( false );
+        jobFinished( false );
     }
 }
 
-void K3bVcdJob::parseInformation( QString text )
+void K3bVcdJob::parseInformation( const QString &text )
 {
     // parse warning
     if ( text.contains( "mpeg user scan data: one or more BCD fields out of range for" ) ) {
