@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bvideodvddoc.h 421129 2005-06-02 09:33:12Z trueg $
+ * $Id: k3bvideodvddoc.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,10 +17,10 @@
 #define _K3B_VIDEODVD_DOC_H_
 
 #include <k3bdvddoc.h>
-
+#include "k3b_export.h"
 class KConfig;
 
-class K3bVideoDvdDoc : public K3bDvdDoc
+class LIBK3B_EXPORT K3bVideoDvdDoc : public K3bDvdDoc
 {
  public:
   K3bVideoDvdDoc( QObject* parent = 0 );
