@@ -1,6 +1,6 @@
-/* 
+/*
  *
- * $Id: k3blistviewitemanimator.cpp 619556 2007-01-03 17:38:12Z trueg $
+ * $Id: k3blistviewitemanimator.cpp 689561 2007-07-18 15:19:38Z trueg $
  * Copyright (C) 2004 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -42,6 +42,12 @@ K3bListViewItemAnimator::~K3bListViewItemAnimator()
 }
 
 
+QListViewItem* K3bListViewItemAnimator::item() const
+{
+    return m_item;
+}
+
+
 void K3bListViewItemAnimator::init()
 {
   m_item = 0;
@@ -109,7 +115,7 @@ void K3bListViewItemAnimator::slotAnimate()
     KPixmap pix( m_pixmap );
     m_item->setPixmap( m_column, KPixmapEffect::fade( pix, val, m_fadeColor ) );;
   }
-  
+
   if( m_animationBack ) {
     --m_animationStep;
     if( m_animationStep < 0 ) {
