@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bmsfedit.h 421129 2005-06-02 09:33:12Z trueg $
+ * $Id: k3bmsfedit.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #include <qvalidator.h>
 
 #include <k3bmsf.h>
-
+#include "k3b_export.h"
 
 class K3bMsfValidator : public QRegExpValidator
 {
@@ -32,7 +32,7 @@ class K3bMsfValidator : public QRegExpValidator
 };
 
 
-class K3bMsfEdit : public QSpinBox
+class LIBK3B_EXPORT K3bMsfEdit : public QSpinBox
 {
   Q_OBJECT
 
