@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3btitlelabel.h 421129 2005-06-02 09:33:12Z trueg $
+ * $Id: k3btitlelabel.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,12 @@
 #define _K3B_TITLE_LABEL_H_
 
 #include <qframe.h>
-
+#include "k3b_export.h"
 class QPainter;
 class QResizeEvent;
 
 
-class K3bTitleLabel : public QFrame
+class LIBK3B_EXPORT K3bTitleLabel : public QFrame
 {
   Q_OBJECT
 
@@ -31,8 +31,6 @@ class K3bTitleLabel : public QFrame
   K3bTitleLabel( QWidget* parent = 0, const char* name = 0 );
   ~K3bTitleLabel();
 
-  void setTitle( const QString& title, const QString& subTitle = QString::null );
-
   QSize sizeHint() const;
   QSize minimumSizeHint() const;
 
@@ -42,6 +40,17 @@ class K3bTitleLabel : public QFrame
     */
   void setMargin( int );
 
+  void setTitle( const QString& title, const QString& subTitle = QString::null );
+  void setSubTitle( const QString& subTitle );
+
+  /**
+   * The title label only supports alignments left, hcenter, and right
+   *
+   * Default alignment is left.
+   */
+  // FIXME: honor right-to-left languages
+  void setAlignment( int align );
+
  protected:
   void resizeEvent( QResizeEvent* );
   void drawContents( QPainter* p );
@@ -49,6 +58,9 @@ class K3bTitleLabel : public QFrame
  private:
   void updatePositioning();
 
+  class ToolTip;
+  ToolTip* m_toolTip;
+
   class Private;
   Private* d;
 };
