@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3bdevice.h 543494 2006-05-22 08:32:30Z trueg $
- * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
+ * $Id: k3bdevice.h 679274 2007-06-23 13:23:58Z trueg $
+ * Copyright (C) 2003-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <k3bdiskinfo.h>
 #include <k3bcdtext.h>
 #include <k3bmsf.h>
+#include <k3bdevice_export.h>
 
 #ifdef Q_OS_FREEBSD
 struct cam_device;
@@ -38,8 +39,12 @@ namespace K3bDevice
    * \brief The main class representing a device.
    *
    * Devices are constructed by the DeviceManager.
+   *
+   * All methods except for open and close in Device are thread-safe which basicly means that
+   * no two commands are sent to the device at the same time.
    */
-  class Device
+  // FIXME: all methods are const which makes no sense at all!
+  class LIBK3BDEVICE_EXPORT Device
     {
     public:
 #ifdef Q_OS_FREEBSD
@@ -63,15 +68,30 @@ namespace K3bDevice
        *
        * \return K3bDevice::SCSI or K3bDevice::IDE.
        */
-      Interface interfaceType();
+      Interface interfaceType() const;
 
       /**
+       * \deprecated use readCapabilities() and writeCapabilities()
        * The device type.
        *
        * @return A bitwise or of K3bDevice::DeviceType.
        */
       int type() const;
 
+      /**
+       * The mediatypes this device is able to read.
+       *
+       * \return A bitwise or of K3bDevice::MediaType
+       */
+      int readCapabilities() const;
+
+      /**
+       * The media types this device is able to write.
+       *
+       * \return A bitwise or of K3bDevice::MediaType
+       */      
+      int writeCapabilities() const;
+
       /**
        * \return Vendor string as reported by the device's firmware.
        */
@@ -214,18 +234,6 @@ namespace K3bDevice
        */
       void addDeviceNode( const QString& );
 
-      /**
-       * \return The device name used for mounting.
-       * \see mountPoint()
-       */
-      const QString& mountDevice() const;
-
-      /**
-       * The mountpoint as found by DeviceManager::scanFstab()
-       * \see mountDevice()
-       */
-      const QString& mountPoint() const;
-
       /**
        * Makes only sense to use with scsi devices
        * @return a string for use with the cdrtools
@@ -244,11 +252,6 @@ namespace K3bDevice
        */
       const QString& cdrdaoDriver() const { return m_cdrdaoDriver; }
 
-      /**
-       * @return true if the device is mounted automatically (supermount or subfs)
-       */
-      bool automount() const { return m_automount; }
-
       /**
        * returns: 0 auto (no cdrdao-driver selected)
        *          1 yes
@@ -318,16 +321,6 @@ namespace K3bDevice
        */
       int numSessions() const;
 
-      /**
-       * @return The media size.
-       */
-      K3b::Msf discSize() const;
-
-      /**
-       * @return The remaining size on an appendable media
-       */
-      K3b::Msf remainingSize() const;
-
       /**
        * @return The toc of the media or an empty (invalid) K3bDevice::Toc if 
        *         no or an empty media is inserted.
@@ -336,7 +329,7 @@ namespace K3bDevice
 
       /**
        * Append ISRC and MCN to the TOC if found
-       * This has been moved to a seperate method since it can take a very long time
+       * This has been moved to a separate method since it can take a very long time
        * to scan for all ISRCs.
        */
       void readIsrcMcn( Toc& toc ) const;
@@ -381,6 +374,13 @@ namespace K3bDevice
        */
       bool load() const;
 
+      /**
+       * Enable or disable auto-ejecting. For now this is a no-op on non-Linux systems.
+       * \param enabled if true auto-ejecting will be enabled, otherwise disabled.
+       * \return true if the operation was successful, false otherwise
+       */
+      bool setAutoEjectEnabled( bool enabled ) const;
+
       /**
        * The supported writing modes.
        *
@@ -431,16 +431,11 @@ namespace K3bDevice
 			       K3b::Msf* currentMax = 0, int* currentMaxFormat = 0 ) const;
 
       /**
-       * Does only make sense for cd media.
-       * @returns -1 on error K3bDevice::MediaType otherwise
+       * Determine the type of the currently mounted medium
+       *
+       * @returns K3bDevice::MediaType
        */
-      int cdMediaType() const;
-
-      /**
-       * Does only make sense for dvd media.
-       * @returns -1 on error K3bDevice::MediaType otherwise
-       */
-      int dvdMediaType() const;
+      int mediaType() const;
 
       /**
        * Returnes the list of supported writing speeds as reported by
@@ -456,15 +451,19 @@ namespace K3bDevice
       int determineMaximalWriteSpeed() const;
 
       /**
-       * Open the device for acces via a file descriptor.
+       * Open the device for access via a file descriptor.
        * @return true on success or if the device is already open.
        * @see close()
+       *
+       * Be aware that this method is not thread-safe.
        */
       bool open( bool write = false ) const;
 
       /**
        * Close the files descriptor.
        * @see open()
+       *
+       * Be aware that this method is not thread-safe.
        */
       void close() const;
 
@@ -505,40 +504,51 @@ namespace K3bDevice
        * if true is returned dataLen specifies the actual length of *data which needs to be
        * deleted after using.
        */
-      bool readDiscInfo( unsigned char** data, int& dataLen ) const;
+      bool readDiscInformation( unsigned char** data, unsigned int& dataLen ) const;
 
       /**
        * @param pf If false all fields in the descriptor data is vendor specific. Default should be true.
        */
-      bool modeSelect( unsigned char* page, int pageLen, bool pf, bool sp ) const;
+      bool modeSelect( unsigned char* page, unsigned int pageLen, bool pf, bool sp ) const;
 
       /**
        * if true is returned pageLen specifies the actual length of *pageData which needs to be
        * deleted after using.
        */
-      bool modeSense( unsigned char** pageData, int& pageLen, int page ) const;
+      bool modeSense( unsigned char** pageData, unsigned int& pageLen, int page ) const;
 
       /**
        * if true is returned dataLen specifies the actual length of *data which needs to be
        * deleted after using.
        */
-      bool readTocPmaAtip( unsigned char** data, int& dataLen, int format, bool time, int track ) const;
+      bool readTocPmaAtip( unsigned char** data, unsigned int& dataLen, int format, bool msf, int track ) const;
 
       /**
        * @param type specifies what value means:
-       *        \li 00b - value refers to a logical block adress
+       *        \li 00b - value refers to a logical block address
        *        \li 01b - value refers to a track number where 0 will treat the lead-in as if it
        *                  were a logical track and ffh will read the invisible or incomplete track.
        *        \li 10b - value refers to a session number
        *
        */
-      bool readTrackInformation( unsigned char** data, int& dataLen, int type, unsigned long value ) const;
+      bool readTrackInformation( unsigned char** data, unsigned int& dataLen, int type, int value ) const;
 
       /**
        * if true is returned dataLen specifies the actual length of *data which needs to be
        * deleted after using.
        */
-      bool readDvdStructure( unsigned char** data, int& dataLen, 
+      bool readDiscStructure( unsigned char** data, unsigned int& dataLen, 
+			      unsigned int mediaType = 0x0,
+			      unsigned int format = 0x0,
+			      unsigned int layer = 0x0,
+			      unsigned long adress = 0,
+			      unsigned int agid = 0x0 ) const;
+
+      /**
+       * In MMC5 readDvdStructure was renamed to readDiscStructure. This method does the same
+       * like the above.
+       */
+      bool readDvdStructure( unsigned char** data, unsigned int& dataLen, 
 			     unsigned int format = 0x0,
 			     unsigned int layer = 0x0,
 			     unsigned long adress = 0,
@@ -548,20 +558,20 @@ namespace K3bDevice
        * if true is returned dataLen specifies the actual length of *data which needs to be
        * deleted after using.
        */
-      bool mechanismStatus( unsigned char** data, int& dataLen ) const;
+      bool mechanismStatus( unsigned char** data, unsigned int& dataLen ) const;
 
       /**
        * Read a single feature.
        * data will be filled with the feature header and the descriptor
        */
-      bool getFeature( unsigned char** data, int& dataLen, unsigned int feature ) const;
+      bool getFeature( unsigned char** data, unsigned int& dataLen, unsigned int feature ) const;
 
 
       /**
        * if true is returned dataLen specifies the actual length of *data which needs to be
        * deleted after using.
        */
-      bool getPerformance( unsigned char** data, int& dataLen,
+      bool getPerformance( unsigned char** data, unsigned int& dataLen,
 			   unsigned int type,
 			   unsigned int dataType,
 			   unsigned int lba = 0 ) const;
@@ -577,7 +587,7 @@ namespace K3bDevice
        * @param startAdress Lba 0 is mapped to msf 00:00:00 so this method uses
        *                    startAdress+150 as the starting msf.
        *
-       * @param endAdress This is the ending adress which is NOT included in the read operation.
+       * @param endAdress This is the ending address which is NOT included in the read operation.
        *                  Lba 0 is mapped to msf 00:00:00 so this method uses
        *                  endAdress+150 as the ending msf.
        *
@@ -591,7 +601,7 @@ namespace K3bDevice
        *                    \li 100b - Corrected and de-interleaved R-W Sub-channel (96 bytes)
        */
       bool readCdMsf( unsigned char* data,
-		      int dataLen,
+		      unsigned int dataLen,
 		      int sectorType,
 		      bool dap,
 		      const K3b::Msf& startAdress,
@@ -622,7 +632,7 @@ namespace K3bDevice
        *                    \li 100b - Corrected and de-interleaved R-W Sub-channel (96 bytes)
        */
       bool readCd( unsigned char* data,
-		   int dataLen,
+		   unsigned int dataLen,
 		   int sectorType,
 		   bool dap,
 		   unsigned long startAdress,
@@ -636,13 +646,13 @@ namespace K3bDevice
 		   int subChannel ) const;
 
       bool read10( unsigned char* data,
-		   int dataLen,
+		   unsigned int dataLen,
 		   unsigned long startAdress,
 		   unsigned int length,
 		   bool fua = false ) const;
 
       bool read12( unsigned char* data,
-		   int dataLen,
+		   unsigned int dataLen,
 		   unsigned long startAdress,
 		   unsigned long length,
 		   bool streaming = false,
@@ -655,7 +665,7 @@ namespace K3bDevice
        * @param trackNumber only valid if subchannelParam == 03h
        */
       bool readSubChannel( unsigned char** data,
-			   int& dataLen,
+			   unsigned int& dataLen,
 			   unsigned int subchannelParam,
 			   unsigned int trackNumber ) const;
 
@@ -691,6 +701,37 @@ namespace K3bDevice
        */
       bool seek( unsigned long lba ) const;
 
+      bool getNextWritableAdress( unsigned int& lastSessionStart, unsigned int& nextWritableAdress ) const;
+
+      /**
+       * Retrieve the next writable address from the currently mounted writable medium.
+       * \return The next writable address if the medium is empty or appendable or -1
+       * if an error occured.
+       */
+      int nextWritableAddress() const;
+
+      /**
+       * Locks the device for usage. This means that no MMC command can be performed
+       * until usageUnlock is called.
+       *
+       * Locking a device is useful when an external application or library is called
+       * that opens the device itself.
+       *
+       * \sa usageUnlock
+       */
+      void usageLock() const;
+
+      /**
+       * Unlock the device after a call to usageLock.
+       */
+      void usageUnlock() const;
+
+      /**
+       * Thread-safe ioctl call for this device for Linux and Net-BSD systems.
+       * Be aware that so far this does not include opening the device
+       */
+//      int ioctl( int request, ... ) const;
+
     protected:
       bool furtherInit();
 
@@ -706,7 +747,7 @@ namespace K3bDevice
        * undefined for DVDs.
        */
       bool readRawToc( Toc& ) const;
-      bool readFormattedToc( Toc&, bool dvd = false ) const;
+      bool readFormattedToc( Toc&, int mediaType ) const;
 
       /**
        * Fixes the last block on CD-Extra disks. This is needed if the readRawToc failed since
@@ -733,9 +774,6 @@ namespace K3bDevice
        */
       bool init( bool checkWritingModes = true );
 
-      void setMountPoint( const QString& );
-      void setMountDevice( const QString& );
-
       void searchIndexTransitions( long start, long end, K3bDevice::Track& track ) const;
       void checkWritingModes();
       void checkFeatures();
@@ -747,11 +785,13 @@ namespace K3bDevice
        * Internal method which checks if the raw toc data has bcd values or hex.
        * @return 0 if hex, 1 if bcd, -1 if none
        */
-      int rawTocDataWithBcdValues( unsigned char* data, int dataLen ) const;
+      int rawTocDataWithBcdValues( unsigned char* data, unsigned int dataLen ) const;
 
       bool getSupportedWriteSpeedsVia2A( QValueList<int>& list, bool dvd ) const;
       bool getSupportedWriteSpeedsViaGP( QValueList<int>& list, bool dvd ) const;
 
+      QCString mediaId( int mediaType ) const;
+
       QString m_vendor;
       QString m_description;
       QString m_version;
@@ -772,8 +812,6 @@ namespace K3bDevice
 
       int m_writeModes;
 
-      bool m_automount;
-
       // only needed on FreeBSD
       QString m_passDevice;
       QString m_blockDevice;
