@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdevice_mmc.cpp 677501 2007-06-19 08:33:51Z trueg $
+ * $Id: k3bdevice_mmc.cpp 690628 2007-07-21 16:05:08Z trueg $
  * Copyright (C) 2003-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -198,32 +198,24 @@ bool K3bDevice::Device::getPerformance( unsigned char** data, unsigned int& data
   cmd[9] = 1;      // first we read one descriptor
   cmd[10] = type;
   cmd[11] = 0;     // Necessary to set the proper command length
-  if( cmd.transport( TR_DIR_READ, header, 8 ) == 0 ) {
-    // again with real length
-    dataLen = from4Byte( header ) + 4;
-
-    // At least one Panasonic drive returns gigantic changing numbers for the data length
-    // which makes K3b crash below when *data cannot be allocated. That's why we cut the
-    // length here.
-    // FIXME: 2048 is a proper upper boundary for the write speed but not for all
-    //        return types. "Defect Status Data" for example might return way more data.
-    // FIXME: I added a "return false" here since there was a situation in which this method
-    //        returned a gigantic dataLen even with this cut. So there is still some bug here.
-    //        Since we only use getPerformance for writing speeds and without a proper length
-    //        those do not make sense it is better to fail here anyway.
-    if( dataLen > 2048 ) {
-      k3bDebug() << "(K3bDevice::Device) " << blockDeviceName()
-		 << ": GET PERFORMANCE reports bogus dataLen: " << dataLen << endl;
-      return false;
-      dataLen = 2048;
-    }
-  }
-  else
+  if( cmd.transport( TR_DIR_READ, header, 8 ) ) {
     k3bDebug() << "(K3bDevice::Device) " << blockDeviceName()
 	      << ": GET PERFORMANCE length det failed." << endl;
+    return false;
+  }
 
-  if( (dataLen-8) % descLen || dataLen <= 8 )
-    dataLen = 2048;
+  dataLen = from4Byte( header ) + 4;
+
+  k3bDebug() << "(K3bDevice::Device) " << blockDeviceName()
+             << ": GET PERFORMANCE dataLen = " << dataLen << endl;
+
+  if( (dataLen-8) % descLen ||
+      dataLen <= 8 ||
+      dataLen > 2048 ) {
+      k3bDebug() << "(K3bDevice::Device) " << blockDeviceName()
+                 << ": GET PERFORMANCE reports bogus dataLen: " << dataLen << endl;
+      return false;
+  }
 
   *data = new unsigned char[dataLen];
   ::memset( *data, 0, dataLen );
@@ -233,8 +225,10 @@ bool K3bDevice::Device::getPerformance( unsigned char** data, unsigned int& data
   cmd[8] = numDesc>>8;
   cmd[9] = numDesc;
   if( cmd.transport( TR_DIR_READ, *data, dataLen ) == 0 ) {
-    dataLen = QMIN( dataLen, from4Byte( *data ) + 4 );
-    return true;
+      k3bDebug() << "(K3bDevice::Device) " << blockDeviceName()
+                 << ": GET PERFORMANCE successful with reported length: " << from4Byte( *data ) << endl;
+      dataLen = QMIN( dataLen, from4Byte( *data ) + 4 );
+      return true;
   }
   else {
     k3bDebug() << "(K3bDevice::Device) " << blockDeviceName()
