@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3bdevicemanager.cpp 543494 2006-05-22 08:32:30Z trueg $
- * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
+ * $Id: k3bdevicemanager.cpp 676188 2007-06-16 08:55:00Z trueg $
+ * Copyright (C) 2003-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,10 +20,7 @@
 #include "k3bdeviceglobals.h"
 #include "k3bscsicommand.h"
 #include "k3bmmc.h"
-
-#ifdef HAVE_HAL
-#include "k3bhalconnection.h"
-#endif
+#include "k3bdebug.h"
 
 #include <qstring.h>
 #include <qstringlist.h>
@@ -38,14 +35,12 @@
 #include <ktempfile.h>
 
 #include <iostream>
-#include <fstab.h>
 #include <limits.h>
 #include <assert.h>
 
 #ifdef Q_OS_FREEBSD
 #include <sys/param.h>
 #include <sys/ucred.h>
-#include <sys/mount.h>
 #include <osreldate.h>
 #endif
 
@@ -57,6 +52,9 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 
+#ifdef HAVE_RESMGR
+#include <resmgr.h>
+#endif
 
 #ifdef Q_OS_LINUX
 
@@ -99,7 +97,6 @@ typedef unsigned char u8;
 #include <camlib.h>
 #endif
 
-
 #ifdef Q_OS_NETBSD
 #include <sys/scsiio.h>
 #endif
@@ -114,12 +111,10 @@ public:
   QPtrList<K3bDevice::Device> cdWriter;
   QPtrList<K3bDevice::Device> dvdReader;
   QPtrList<K3bDevice::Device> dvdWriter;
+  QPtrList<K3bDevice::Device> bdReader;
+  QPtrList<K3bDevice::Device> bdWriter;
 
   bool checkWritingModes;
-
-#ifdef HAVE_HAL
-  HalConnection hal;
-#endif
 };
 
 
@@ -128,13 +123,6 @@ K3bDevice::DeviceManager::DeviceManager( QObject* parent, const char* name )
   : QObject( parent, name )
 {
   d = new Private;
-
-#ifdef HAVE_HAL
-    connect( &d->hal, SIGNAL(deviceAdded(const QString&)),
-	     this, SLOT(addDevice(const QString&)) );
-    connect( &d->hal, SIGNAL(deviceRemoved(const QString&)),
-	     this, SLOT(removeDevice(const QString&)) );
-#endif
 }
 
 
@@ -177,12 +165,11 @@ K3bDevice::Device* K3bDevice::DeviceManager::findDevice( int bus, int id, int lu
 K3bDevice::Device* K3bDevice::DeviceManager::findDevice( const QString& devicename )
 {
   if( devicename.isEmpty() ) {
-    kdDebug() << "(K3bDevice::DeviceManager) request for empty device!" << endl;
+    k3bDebug() << "(K3bDevice::DeviceManager) request for empty device!" << endl;
     return 0;
   }
   QPtrListIterator<K3bDevice::Device> it( d->allDevices );
-  while( it.current() )
-  {
+  while( it.current() ) {
     if( it.current()->deviceNodes().contains(devicename) )
       return it.current();
 
@@ -193,40 +180,49 @@ K3bDevice::Device* K3bDevice::DeviceManager::findDevice( const QString& devicena
 }
 
 
-QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::cdWriter()
+const QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::cdWriter() const
 {
   return d->cdWriter;
 }
 
-QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::cdReader()
+const QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::cdReader() const
 {
   return d->cdReader;
 }
 
-QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::dvdWriter()
+const QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::dvdWriter() const
 {
   return d->dvdWriter;
 }
 
-QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::dvdReader()
+const QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::dvdReader() const
 {
   return d->dvdReader;
 }
 
+const QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::blueRayReader() const
+{
+  return d->bdReader;
+}
 
-QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::burningDevices()
+const QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::blueRayWriters() const
+{
+  return d->bdWriter;
+}
+
+const QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::burningDevices() const
 {
   return cdWriter();
 }
 
 
-QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::readingDevices()
+const QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::readingDevices() const
 {
   return cdReader();
 }
 
 
-QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::allDevices()
+const QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::allDevices() const
 {
   return d->allDevices;
 }
@@ -234,104 +230,82 @@ QPtrList<K3bDevice::Device>& K3bDevice::DeviceManager::allDevices()
 
 int K3bDevice::DeviceManager::scanBus()
 {
-  m_foundDevices = 0;
-
-#ifdef HAVE_HAL
-  d->hal.open();
-#endif
+  unsigned int numDevs = d->allDevices.count();
 
 #ifdef Q_OS_LINUX
   LinuxDeviceScan();
 #endif
-#ifdef Q_OS_NETBSD
-  NetBSDDeviceScan();
-#endif
 #ifdef Q_OS_FREEBSD
   BSDDeviceScan();
 #endif
-  scanFstab();
+#ifdef Q_OS_NETBSD
+  NetBSDDeviceScan();
+#endif
 
-  return m_foundDevices;
+  return d->allDevices.count() - numDevs;
 }
 
 
 void K3bDevice::DeviceManager::LinuxDeviceScan()
 {
+#ifdef HAVE_RESMGR
+  //
+  // Resmgr device scan
+  //
+  char** resmgrDevices = rsm_list_devices( 0 );
+  if( resmgrDevices ) {
+    for( int i = 0; resmgrDevices[i]; ++i ) {
+      addDevice( resmgrDevices[i] );
+      free( resmgrDevices[i] );
+    }
+
+    free( resmgrDevices );
+  }
+#endif
+
   QFile info("/proc/sys/dev/cdrom/info");
   QString line,devstring;
-  info.open(IO_ReadOnly);
-  info.readLine(line,80); // CD-ROM information, Id: cdrom.c 3.12 2000/10/18
-  info.readLine(line,80); //
+  if( info.open(IO_ReadOnly) ) {
+    info.readLine(line,80); // CD-ROM information, Id: cdrom.c 3.12 2000/10/18
+    info.readLine(line,80); //
 
-  while (info.readLine(line,80) > 0)
-  {
-    if (line.contains("drive name") > 0)
-    {
-      int i = 1;
-      QString dev;
-      QRegExp re("[\t\n:]+");
-      while ( !(dev = line.section(re, i, i)).isEmpty() )
-      {
-        if( addDevice(QString("/dev/%1").arg(dev)) ) {
-          devstring += dev + "|";
-          m_foundDevices++;
-        }
-// according to the LINUX ALLOCATED DEVICES document (http://www.lanana.org/docs/device-list/),
-// the official device names for SCSI-CDROM's (block major 11) are /dev/sr*, the
-// prefix /dev/scd instead of /dev/sr has been used as well, and might make more sense.
-// Since there should be one and only one device node (and maybe several symbolic links) for
-// each physical device the next line should be better
-//      else if ( dev.startsWith("sr") )
-        if ( dev.startsWith("sr") )
-          if( addDevice(QString("/dev/%1").arg(dev.replace(QRegExp("r"),"cd"))) ) {
-            devstring += dev + "|";
-            m_foundDevices++;
-        }
-        ++i;
+    QRegExp re("[\t\n:]+");
+    while( info.readLine( line, 80 ) > 0 ) {
+      if( line.contains("drive name") > 0 ) {
+	int i = 1;
+	QString dev;
+	while( !(dev = line.section(re, i, i)).isEmpty() ) {
+	  if( addDevice( QString("/dev/%1").arg(dev) ) ) {
+	    devstring += dev + "|";
+	  }
+	  // according to the LINUX ALLOCATED DEVICES document (http://www.lanana.org/docs/device-list/),
+	  // the official device names for SCSI-CDROM's (block major 11) are /dev/sr*, the
+	  // prefix /dev/scd instead of /dev/sr has been used as well, and might make more sense.
+	  // Since there should be one and only one device node (and maybe several symbolic links) for
+	  // each physical device the next line should be better
+	  //      else if ( dev.startsWith("sr") )
+	  if ( dev.startsWith("sr") ) {
+	    if( addDevice(QString("/dev/%1").arg(dev.replace(QRegExp("r"),"cd"))) )
+	      devstring += dev + "|";
+	  }
+	  ++i;
+	}
       }
+      break;
     }
-    break;
+    info.close();
   }
-  info.close();
-
-#ifdef HAVE_RESMGR
-  int havenormaldevs = d->allDevices.count();
-#endif
-
-  // try to find symlinks
-  QString cmd = QString("find /dev -type l -printf \"%p\t%l\n\" | egrep '%1cdrom|dvd|cdwriter|cdrecorder' | cut -f1").arg(devstring);
-  FILE *fd = popen(QFile::encodeName(cmd),"r");
-  if (fd) {
-     QFile links;
-     QString device;
-     links.open(IO_ReadOnly,fd);
-     while ( links.readLine(device,80) > 0) {
-       device = device.stripWhiteSpace();
-       K3bDevice::Device *d = findDevice(resolveSymLink(device));
-       if (d) {
-         d->addDeviceNode(device);
-         kdDebug() << "(K3bDevice::DeviceManager) Link: " << device << " -> " << d->devicename() << endl;
-       }
-#ifdef HAVE_RESMGR
-       // if we had no initial devices, add the symlinked devices.
-       if (!d) {
-         if (!havenormaldevs)
-           addDevice(device);
-       }
-#endif
-     }
+  else {
+    kdError() << "(K3bDevice::DeviceManager) could not open /proc/sys/dev/cdrom/info" << endl;
   }
-  pclose(fd);
 
-
-#ifdef Q_OS_LINUX
   //
   // Scan the generic devices if we have scsi devices
   //
-  kdDebug() << "(K3bDevice::DeviceManager) SCANNING FOR GENERIC DEVICES." << endl;
+  k3bDebug() << "(K3bDevice::DeviceManager) SCANNING FOR GENERIC DEVICES." << endl;
   for( int i = 0; i < 16; i++ ) {
     QString sgDev = resolveSymLink( QString("/dev/sg%1").arg(i) );
-    int bus, id, lun;
+    int bus = -1, id = -1, lun = -1;
     if( determineBusIdLun( sgDev, bus, id, lun ) ) {
       if( Device* dev = findDevice( bus, id, lun ) ) {
 	dev->m_genericDevice = sgDev;
@@ -339,7 +313,6 @@ void K3bDevice::DeviceManager::LinuxDeviceScan()
     }
   }
   // FIXME: also scan /dev/scsi/hostX.... for devfs without symlinks
-#endif
 }
 
 
@@ -355,9 +328,9 @@ void K3bDevice::DeviceManager::NetBSDDeviceScan()
   // 'd' as whole-disk partition, the rest uses 'c'.)
 
 #if defined(__i386__) || defined (__amd64__) || defined (__bebox__)
-  char   slicename = 'd';
+  static const char slicename = 'd';
 #else
-  char   slicename = 'c';
+  static const char slicename = 'c';
 #endif
 
   char devicename[11]; // /dev/rcdXd + trailing zero
@@ -365,10 +338,7 @@ void K3bDevice::DeviceManager::NetBSDDeviceScan()
   for (i = 0; i < 10; i++ ) // cd(4) claims there are max. 10 CD devices.
   {
     snprintf(devicename,11,"/dev/rcd%d%c",i, slicename);
-    if (addDevice(QString(devicename))) // let addDevice figure it out.
-    {
-      m_foundDevices++;
-    }
+    addDevice(QString(devicename));
   }
 }
 
@@ -377,8 +347,8 @@ void K3bDevice::DeviceManager::BSDDeviceScan()
 {
   // Unfortunately uses lots of FBSD-specific data structures
 #ifndef Q_OS_FREEBSD
-  bool bsdspecificcode = false;
-  assert(bsdspecificcode);
+  // bool bsdspecificcode = false;
+  // assert(bsdspecificcode);
 #endif
 
 #ifdef Q_OS_FREEBSD
@@ -391,7 +361,7 @@ void K3bDevice::DeviceManager::BSDDeviceScan()
 
   if ((fd = open(XPT_DEVICE, O_RDWR)) == -1)
     {
-      kdDebug() << "couldn't open %s " << XPT_DEVICE << endl;
+      k3bDebug() << "couldn't open %s " << XPT_DEVICE << endl;
       return;
     }
 
@@ -406,16 +376,16 @@ void K3bDevice::DeviceManager::BSDDeviceScan()
   ccb.cdm.pattern_buf_len = 0;
   do {
     if (ioctl(fd, CAMIOCOMMAND, &ccb) == -1) {
-      kdDebug() << "(BSDDeviceScan) error sending CAMIOCOMMAND ioctl: " << errno << endl;
+      k3bDebug() << "(BSDDeviceScan) error sending CAMIOCOMMAND ioctl: " << errno << endl;
       break;
     }
 
     if ((ccb.ccb_h.status != CAM_REQ_CMP)
 	|| ((ccb.cdm.status != CAM_DEV_MATCH_LAST) && (ccb.cdm.status != CAM_DEV_MATCH_MORE))) {
-      kdDebug() << "(BSDDeviceScan) got CAM error " << ccb.ccb_h.status << ", CDM error %d" << ccb.cdm.status << endl;
+      k3bDebug() << "(BSDDeviceScan) got CAM error " << ccb.ccb_h.status << ", CDM error %d" << ccb.cdm.status << endl;
       break;
     }
-    kdDebug() << "(BSDDeviceScan) number of matches " << (int)ccb.cdm.num_matches << endl;
+    k3bDebug() << "(BSDDeviceScan) number of matches " << (int)ccb.cdm.num_matches << endl;
     for (int i = 0; i < (int)ccb.cdm.num_matches; i++) {
       switch (ccb.cdm.matches[i].type) {
       case DEV_MATCH_DEVICE: {
@@ -440,14 +410,14 @@ void K3bDevice::DeviceManager::BSDDeviceScan()
 #if __FreeBSD_version < 500100
 	    dev += "c";
 #endif
-	    if (dev1 != "" && dev2 != "" && dev.startsWith("/dev/cd"))
+	    if (!dev1.isEmpty() && !dev2.isEmpty() && dev.startsWith("/dev/cd"))
 	    {
 	      Device* device = new Device(dev.latin1());
 	      device->m_bus = bus;
 	      device->m_target = target;
 	      device->m_lun = lun;
 	      device->m_passDevice = "/dev/" + pass;
-	      kdDebug() << "(BSDDeviceScan) add device " << dev << ":" << bus << ":" << target << ":" << lun << endl;
+	      k3bDebug() << "(BSDDeviceScan) add device " << dev << ":" << bus << ":" << target << ":" << lun << endl;
 	      addDevice(device);
 	    }
 	    need_close = 0;
@@ -499,14 +469,14 @@ void K3bDevice::DeviceManager::BSDDeviceScan()
 #if __FreeBSD_version < 500100
       dev += "c";
 #endif
-      if (dev1 != "" && dev2 != "" && dev.startsWith("/dev/cd"))
+      if (!dev1.isEmpty() && !dev2.isEmpty() && dev.startsWith("/dev/cd"))
       {
         Device* device = new Device(dev.latin1());
         device->m_bus = bus;
         device->m_target = target;
         device->m_lun = lun;
         device->m_passDevice = "/dev/" + pass;
-        kdDebug() << "(BSDDeviceScan) add device " << dev << ":" << bus << ":" << target << ":" << lun << endl;
+        k3bDebug() << "(BSDDeviceScan) add device " << dev << ":" << bus << ":" << target << ":" << lun << endl;
         addDevice(device);
       }
     }
@@ -517,21 +487,20 @@ void K3bDevice::DeviceManager::BSDDeviceScan()
 
 void K3bDevice::DeviceManager::printDevices()
 {
-  kdDebug() << "Devices:" << endl
+  k3bDebug() << "Devices:" << endl
 	    << "------------------------------" << endl;
   QPtrListIterator<Device> it( allDevices() );
   for( ; *it; ++it ) {
     Device* dev = *it;
-    kdDebug() << "Blockdevice:    " << dev->blockDeviceName() << endl
+    k3bDebug() << "Blockdevice:    " << dev->blockDeviceName() << endl
 	      << "Generic device: " << dev->genericDevice() << endl
 	      << "Vendor:         " << dev->vendor() << endl
 	      << "Description:    " << dev->description() << endl
 	      << "Version:        " << dev->version() << endl
-	      << "MountDevice:    " << dev->mountDevice() << endl
-	      << "Mountpoint:     " << dev->mountPoint() << endl
 	      << "Write speed:    " << dev->maxWriteSpeed() << endl
 	      << "Profiles:       " << mediaTypeString( dev->supportedProfiles() ) << endl
-	      << "Devicetype:     " << deviceTypeString( dev->type() ) << endl
+	      << "Read Cap:       " << mediaTypeString( dev->readCapabilities() ) << endl
+	      << "Write Cap:      " << mediaTypeString( dev->writeCapabilities() ) << endl
 	      << "Writing modes:  " << writingModeString( dev->writingModes() ) << endl
 	      << "Reader aliases: " << dev->deviceNodes().join(", ") << endl
 	      << "------------------------------" << endl;
@@ -546,10 +515,18 @@ void K3bDevice::DeviceManager::clear()
   d->cdWriter.clear();
   d->dvdReader.clear();
   d->dvdWriter.clear();
+  d->bdReader.clear();
+  d->bdWriter.clear();
+
+  // to make sure no one crashes lets keep the devices around until the changed
+  // signals return
+  QPtrList<K3bDevice::Device> tmp = d->allDevices;
+  tmp.setAutoDelete( true );
+
   d->allDevices.clear();
 
-  emit changed();
   emit changed( this );
+  emit changed();
 }
 
 
@@ -560,16 +537,14 @@ bool K3bDevice::DeviceManager::readConfig( KConfig* c )
   // for details see saveConfig()
   //
 
-  m_foundDevices = 0;
-
   if( !c->hasGroup( "Devices" ) )
     return false;
 
   c->setGroup( "Devices" );
 
   QStringList deviceSearchPath = c->readListEntry( "device_search_path" );
-  for( QStringList::iterator it = deviceSearchPath.begin();
-       it != deviceSearchPath.end(); ++it )
+  for( QStringList::const_iterator it = deviceSearchPath.constBegin();
+       it != deviceSearchPath.constEnd(); ++it )
     addDevice( *it );
 
   //
@@ -581,7 +556,7 @@ bool K3bDevice::DeviceManager::readConfig( KConfig* c )
     QString configEntryName = dev->vendor() + " " + dev->description();
     QStringList list = c->readListEntry( configEntryName );
     if( !list.isEmpty() ) {
-      kdDebug() << "(K3bDevice::DeviceManager) found config entry for devicetype: " << configEntryName << endl;
+      k3bDebug() << "(K3bDevice::DeviceManager) found config entry for devicetype: " << configEntryName << endl;
 
       dev->setMaxReadSpeed( list[0].toInt() );
       if( list.count() > 1 )
@@ -593,8 +568,6 @@ bool K3bDevice::DeviceManager::readConfig( KConfig* c )
     }
   }
 
-  scanFstab();
-
   return true;
 }
 
@@ -617,7 +590,7 @@ bool K3bDevice::DeviceManager::saveConfig( KConfig* c )
   QStringList deviceSearchPath = c->readListEntry( "device_search_path" );
   // remove duplicate entries (caused by buggy old implementations)
   QStringList saveDeviceSearchPath;
-  for( QStringList::iterator it = deviceSearchPath.begin(); it != deviceSearchPath.end(); ++it )
+  for( QStringList::const_iterator it = deviceSearchPath.constBegin(); it != deviceSearchPath.constEnd(); ++it )
     if( !saveDeviceSearchPath.contains( *it ) )
       saveDeviceSearchPath.append( *it );
 
@@ -651,7 +624,7 @@ bool K3bDevice::DeviceManager::saveConfig( KConfig* c )
 }
 
 
-bool K3bDevice::DeviceManager::testForCdrom(const QString& devicename)
+bool K3bDevice::DeviceManager::testForCdrom( const QString& devicename )
 {
 #ifdef Q_OS_FREEBSD
   Q_UNUSED(devicename);
@@ -661,19 +634,20 @@ bool K3bDevice::DeviceManager::testForCdrom(const QString& devicename)
   bool ret = false;
   int cdromfd = K3bDevice::openDevice( devicename.ascii() );
   if (cdromfd < 0) {
-    kdDebug() << "could not open device " << devicename << " (" << strerror(errno) << ")" << endl;
+    k3bDebug() << "could not open device " << devicename << " (" << strerror(errno) << ")" << endl;
     return ret;
   }
 
   // stat the device
   struct stat cdromStat;
-  ::fstat( cdromfd, &cdromStat );
+  if( ::fstat( cdromfd, &cdromStat ) )
+    return false;
 
   if( !S_ISBLK( cdromStat.st_mode) ) {
-    kdDebug() << devicename << " is no block device" << endl;
+    k3bDebug() << devicename << " is no block device" << endl;
   }
   else {
-    kdDebug() << devicename << " is block device (" << (int)(cdromStat.st_rdev & 0xFF) << ")" << endl;
+    k3bDebug() << devicename << " is block device (" << (int)(cdromStat.st_rdev & 0xFF) << ")" << endl;
 #if defined(Q_OS_NETBSD)
   }
   {
@@ -690,14 +664,14 @@ bool K3bDevice::DeviceManager::testForCdrom(const QString& devicename)
     cmd[5] = 0;
 
     if( cmd.transport( TR_DIR_READ, buf, sizeof(buf) ) ) {
-      kdDebug() << "(K3bDevice::Device) Unable to do inquiry. " << devicename << " is not a cdrom device" << endl;
+      k3bDebug() << "(K3bDevice::Device) Unable to do inquiry. " << devicename << " is not a cdrom device" << endl;
     }
-    else if( inq->p_device_type != 0x5 ) {
-      kdDebug() << devicename << " seems not to be a cdrom device: " << (int)inq->p_device_type << endl;
+    else if( (inq->p_device_type&0x1f) != 0x5 ) {
+      k3bDebug() << devicename << " seems not to be a cdrom device: " << strerror(errno) << endl;
     }
     else {
       ret = true;
-      kdDebug() << devicename << " seems to be cdrom" << endl;
+      k3bDebug() << devicename << " seems to be cdrom" << endl;
     }
   }
 
@@ -716,14 +690,20 @@ K3bDevice::Device* K3bDevice::DeviceManager::addDevice( const QString& devicenam
 
   // resolve all symlinks
   QString resolved = resolveSymLink( devicename );
-  kdDebug() << devicename << " resolved to " << resolved << endl;
+  k3bDebug() << devicename << " resolved to " << resolved << endl;
+
+  if ( K3bDevice::Device* oldDev = findDevice(resolved) ) {
+    k3bDebug() << "(K3bDevice::DeviceManager) dev " << resolved  << " already found" << endl;
+    oldDev->addDeviceNode( devicename );
+    return 0;
+  }
 
   if( !testForCdrom(resolved) ) {
 #ifdef HAVE_RESMGR
     // With resmgr we might only be able to open the symlink name.
     if( testForCdrom(devicename) ) {
       resolved = devicename;
-    } 
+    }
     else {
       return 0;
     }
@@ -732,17 +712,11 @@ K3bDevice::Device* K3bDevice::DeviceManager::addDevice( const QString& devicenam
 #endif
   }
 
-  if ( K3bDevice::Device* oldDev = findDevice(resolved) ) {
-    kdDebug() << "(K3bDevice::DeviceManager) dev " << resolved  << " already found" << endl;
-    oldDev->addDeviceNode( devicename );
-    return 0;
-  }
-
   int bus = -1, target = -1, lun = -1;
   bool scsi = determineBusIdLun( resolved, bus, target, lun );
   if(scsi) {
     if ( K3bDevice::Device* oldDev = findDevice(bus, target, lun) ) {
-      kdDebug() << "(K3bDevice::DeviceManager) dev " << resolved  << " already found" << endl;
+      k3bDebug() << "(K3bDevice::DeviceManager) dev " << resolved  << " already found" << endl;
       oldDev->addDeviceNode( devicename );
       return 0;
     }
@@ -764,7 +738,7 @@ K3bDevice::Device* K3bDevice::DeviceManager::addDevice( K3bDevice::Device* devic
   const QString devicename = device->devicename();
 
   if( !device->init() ) {
-    kdDebug() << "Could not initialize device " << devicename << endl;
+    k3bDebug() << "Could not initialize device " << devicename << endl;
     delete device;
     return 0;
   }
@@ -782,17 +756,21 @@ K3bDevice::Device* K3bDevice::DeviceManager::addDevice( K3bDevice::Device* devic
       d->cdWriter.append( device );
     if( device->writesDvd() )
       d->dvdWriter.append( device );
+    if( device->readCapabilities() & MEDIA_BD_ALL )
+      d->bdReader.append( device );
+    if( device->writeCapabilities() & MEDIA_BD_ALL )
+      d->bdWriter.append( device );
 
     if( device->writesCd() ) {
       // default to max write speed
-      kdDebug() << "(K3bDevice::DeviceManager) setting current write speed of device "
+      k3bDebug() << "(K3bDevice::DeviceManager) setting current write speed of device "
 		<< device->blockDeviceName()
 		<< " to " << device->maxWriteSpeed() << endl;
       device->setCurrentWriteSpeed( device->maxWriteSpeed() );
     }
 
-    emit changed();
     emit changed( this );
+    emit changed();
   }
 
   return device;
@@ -804,113 +782,20 @@ void K3bDevice::DeviceManager::removeDevice( const QString& dev )
   if( Device* device = findDevice( dev ) ) {
     d->cdReader.removeRef( device );
     d->dvdReader.removeRef( device );
+    d->bdReader.removeRef( device );
     d->cdWriter.removeRef( device );
     d->dvdWriter.removeRef( device );
+    d->bdWriter.removeRef( device );
     d->allDevices.removeRef( device );
 
-    emit changed();
     emit changed( this );
+    emit changed();
 
     delete device;
   }
 }
 
 
-void K3bDevice::DeviceManager::scanFstab()
-{
-  ::setfsent();
-
-  // clear all mount-Infos
-  for( QPtrListIterator<K3bDevice::Device> it( d->allDevices ); it.current(); ++it ) {
-    it.current()->setMountPoint( QString::null );
-    it.current()->setMountDevice( QString::null );
-  }
-
-  struct fstab * mountInfo = 0;
-  while( (mountInfo = ::getfsent()) )
-  {
-    // check if the entry corresponds to a device
-    QString md = QFile::decodeName( mountInfo->fs_spec );
-    QString type = QFile::decodeName( mountInfo->fs_vfstype );
-
-    bool automount = false;
-
-    if( type == "supermount" || type == "subfs" ) {
-      automount = true;
-
-      // parse the device
-      QStringList opts = QStringList::split( ",", QString::fromLocal8Bit(mountInfo->fs_mntops) );
-      for( QStringList::const_iterator it = opts.begin(); it != opts.end(); ++it ) {
-	if( (*it).startsWith("dev=") ) {
-	  md = (*it).mid( 4 );
-	  break;
-	}
-      }
-    }
-
-    if( md == "none" )
-      continue;
-
-    kdDebug() << "(K3bDevice::DeviceManager) scanning fstab: " << md << endl;
-
-
-    //
-    // Try finding the device
-    //
-    // compare bus, id, lun since the same device can for example be
-    // determined as /dev/srX or /dev/scdX
-    //
-    int bus = -1, id = -1, lun = -1;
-    K3bDevice::Device* dev = findDevice( resolveSymLink(md) );
-    if( !dev && determineBusIdLun( mountInfo->fs_spec, bus, id, lun ) )
-      dev = findDevice( bus, id, lun );
-
-    // FIXME: is this nessessary? Don't we resolve all symlinks on bsd, too?
-    //        and shouldn't we do an addDevice anywhere here in case the fstab
-    //        contains a device which we did not find before?
-    if( !dev )
-      dev = findDevice( md );
-
-    //
-    // Maybe the fstab contains a device we did not find before?
-    //
-    if( !dev )
-      dev = addDevice( md );
-
-    //
-    // Did we find a device?
-    //
-    if( dev ) {
-      bool isPreferredMountPoint = false;
-      kdDebug() << "(K3bDevice::DeviceManager) found device for " << md << ": " << resolveSymLink(md) << endl;
-
-#ifdef Q_OS_FREEBSD
-      // Several mount points for one device might exist. If more than one are found, the one with
-      // user permission should have a higher priority.
-      struct stat filestat;
-      if (mountInfo->fs_file &&
-	  !stat(mountInfo->fs_file, &filestat) &&
-	  filestat.st_uid == geteuid())	{
-	isPreferredMountPoint = true;
-      }
-#else
-      if( mountInfo->fs_file &&
-	  QString::fromLocal8Bit(mountInfo->fs_mntops).contains("users") )
-	isPreferredMountPoint = true;
-#endif
-
-      if( isPreferredMountPoint || dev->mountDevice().isEmpty() ) {
-        dev->setMountPoint( mountInfo->fs_file );
-        dev->setMountDevice( md );
-	dev->m_automount = automount;
-      }
-    }
-  } // while mountInfo
-
-  ::endfsent();
-}
-
-
 bool K3bDevice::DeviceManager::determineBusIdLun( const QString& dev, int& bus, int& id, int& lun )
 {
 #ifdef Q_OS_FREEBSD
@@ -925,8 +810,8 @@ bool K3bDevice::DeviceManager::determineBusIdLun( const QString& dev, int& bus,
 #ifdef Q_OS_NETBSD
   int cdromfd = K3bDevice::openDevice ( dev.ascii() );
   if (cdromfd < 0) {
-    int local_errno = errno; // For all we know, kdDebug() destroys errno
-    kdDebug() << "could not open device " << dev << " (" << strerror(local_errno) << ")" << endl;
+    int local_errno = errno; // For all we know, k3bDebug() destroys errno
+    k3bDebug() << "could not open device " << dev << " (" << strerror(local_errno) << ")" << endl;
     return false;
   }
 
@@ -934,8 +819,8 @@ bool K3bDevice::DeviceManager::determineBusIdLun( const QString& dev, int& bus,
 
   if (::ioctl(cdromfd, SCIOCIDENTIFY, &my_addr))
   {
-    int local_errno = errno; // For all we know, kdDebug() destroys errno
-    kdDebug() << "ioctl(SCIOCIDENTIFY) failed on device " << dev << " (" << strerror(local_errno) << ")" << endl;
+    int local_errno = errno; // For all we know, k3bDebug() destroys errno
+    k3bDebug() << "ioctl(SCIOCIDENTIFY) failed on device " << dev << " (" << strerror(local_errno) << ")" << endl;
 
     ::close(cdromfd);
     return false;
@@ -966,12 +851,12 @@ bool K3bDevice::DeviceManager::determineBusIdLun( const QString& dev, int& bus,
   int ret = false;
   int cdromfd = K3bDevice::openDevice( dev.ascii() );
   if (cdromfd < 0) {
-    kdDebug() << "could not open device " << dev << " (" << strerror(errno) << ")" << endl;
     return false;
   }
 
   struct stat cdromStat;
-  ::fstat( cdromfd, &cdromStat );
+  if ( ::fstat( cdromfd, &cdromStat ) )
+      return false;
 
   if( SCSI_BLK_MAJOR( cdromStat.st_rdev>>8 ) ||
       SCSI_GENERIC_MAJOR == (cdromStat.st_rdev>>8) ) {
@@ -985,13 +870,13 @@ bool K3bDevice::DeviceManager::determineBusIdLun( const QString& dev, int& bus,
     // in kernel 2.2 SCSI_IOCTL_GET_IDLUN does not contain the bus id
     if ( (::ioctl( cdromfd, SCSI_IOCTL_GET_IDLUN, &idLun ) < 0) ||
          (::ioctl( cdromfd, SCSI_IOCTL_GET_BUS_NUMBER, &bus ) < 0) ) {
-      kdDebug() << "Need a filename that resolves to a SCSI device" << endl;
+      k3bDebug() << "Need a filename that resolves to a SCSI device" << endl;
       ret = false;
     }
     else {
       id  = idLun.id & 0xff;
       lun = (idLun.id >> 8) & 0xff;
-      kdDebug() << "bus: " << bus << ", id: " << id << ", lun: " << lun << endl;
+      k3bDebug() << "bus: " << bus << ", id: " << id << ", lun: " << lun << endl;
       ret = true;
     }
   }
@@ -1007,7 +892,7 @@ QString K3bDevice::DeviceManager::resolveSymLink( const QString& path )
   char resolved[PATH_MAX];
   if( !realpath( QFile::encodeName(path), resolved ) )
   {
-    kdDebug() << "Could not resolve " << path << endl;
+    k3bDebug() << "Could not resolve " << path << endl;
     return path;
   }
 
