@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdiskinfo.cpp 619556 2007-01-03 17:38:12Z trueg $
+ * $Id: k3bdiskinfo.cpp 654649 2007-04-16 17:55:50Z trueg $
  * Copyright (C) 2003-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -199,7 +199,8 @@ void K3bDevice::DiskInfo::debug() const
 					    "incomplete" :
 					    ( bgFormatState() == BG_FORMAT_IN_PROGRESS ?
 					      "in progress" :
-					      "complete" ) ) ) << endl;
+					      ( bgFormatState() == BG_FORMAT_COMPLETE ?
+                                                "complete" : "unknown" ) ) ) ) << endl;
 }
 
 
