@@ -4,7 +4,7 @@
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,6 +13,8 @@
  * See the file "COPYING" for the exact licensing terms.
  */
 
+#include <config.h>
+
 #include "k3baudiometainforenamerplugin.h"
 
 // the k3b stuff we need
@@ -264,7 +266,7 @@ QString K3bAudioMetainfoRenamerPluginWidget::createNewName( K3bFileItem* item )
   if( mimetype != 0 && 
       ( mimetype->name().contains( "audio" ) || mimetype->name().contains("ogg") ) ) {
 
-    QString artist, title,track;
+    QString artist, title, track;
 
     KFileMetaInfo metaInfo( item->localPath() );
     if( metaInfo.isValid() ) {
@@ -328,11 +330,11 @@ QString K3bAudioMetainfoRenamerPluginWidget::createNewName( K3bFileItem* item )
       //
       // Check if files with that name exists and if so append number
       //
-      if( find( item->parent(), newName + extension ) ) {
+      if( existsOtherItemWithSameName( item, newName + extension ) ) {
 	kdDebug() << "(K3bAudioMetainfoRenamerPluginWidget) file with name " 
 		  << newName << extension << " already exists" << endl;
 	int i = 1;
-	while( find( item->parent(), newName + QString( " (%1)").arg(i) + extension ) )
+	while( existsOtherItemWithSameName( item, newName + QString( " (%1)").arg(i) + extension ) )
 	  i++;
 	newName.append( QString( " (%1)").arg(i) );
       }
@@ -348,12 +350,14 @@ QString K3bAudioMetainfoRenamerPluginWidget::createNewName( K3bFileItem* item )
 }
 
 
-bool K3bAudioMetainfoRenamerPluginWidget::find( K3bDirItem* item, const QString& name )
+bool K3bAudioMetainfoRenamerPluginWidget::existsOtherItemWithSameName( K3bFileItem* item, const QString& name )
 {
-  if( item->find( name ) )
+  K3bDirItem* dir = item->parent();
+  K3bDataItem* otherItem = dir->find( name );
+  if( otherItem && otherItem != item )
     return true;
 
-  QListViewItem* dirViewItem = d->dirItemDict[item];
+  QListViewItem* dirViewItem = d->dirItemDict[dir];
   QListViewItem* current = dirViewItem->firstChild();
   while( current && current->parent() == dirViewItem ) {
     if( current->text(0) == name )
