@@ -4,7 +4,7 @@
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,12 +38,15 @@ class K3bAudioProjectCddbPlugin : public K3bProjectPlugin
 
  private slots:
   void slotCddbQueryFinished( int result );
+  void slotCancelClicked();
 
  private:
   K3bCddb* m_cddb;
   K3bAudioDoc* m_doc;
   K3bProgressDialog* m_progress;
   QWidget* m_parentWidget;
+
+  bool m_canceled;
 };
 
 
