@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3b.cpp 458229 2005-09-07 15:11:58Z trueg $
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * $Id: k3b.cpp 642063 2007-03-13 09:40:13Z trueg $
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include <qfont.h>
 #include <qpalette.h>
 #include <qwidgetstack.h>
+#include <qtimer.h>
 
 #include <kdockwidget.h>
 #include <kkeydialog.h>
@@ -58,6 +59,8 @@
 #include <kxmlguifactory.h>
 #include <kstdguiitem.h>
 #include <kio/global.h>
+#include <kio/netaccess.h>
+#include <krecentdocument.h>
 
 #include <stdlib.h>
 
@@ -69,7 +72,7 @@
 #include "k3bdirview.h"
 #include <k3baudiodoc.h>
 #include "k3baudioview.h"
-#include <k3bdevicemanager.h>
+#include "k3bappdevicemanager.h"
 #include "k3baudiotrackdialog.h"
 #include "option/k3boptiondialog.h"
 #include "k3bprojectburndialog.h"
@@ -93,9 +96,7 @@
 #include <k3bexternalbinmanager.h>
 #include "k3bprojecttabwidget.h"
 #include "misc/k3bcdcopydialog.h"
-#include "videoEncoding/k3bdivxview.h"
 #include "k3btempdirselectionwidget.h"
-#include <k3bbusywidget.h>
 #include "k3bstatusbarmanager.h"
 #include "k3bfiletreecombobox.h"
 #include "k3bfiletreeview.h"
@@ -116,6 +117,13 @@
 #include <k3bdeviceselectiondialog.h>
 #include <k3bjob.h>
 #include <k3bsignalwaiter.h>
+#include "k3bmediaselectiondialog.h"
+#include "k3bmediacache.h"
+#include "k3bmedium.h"
+#include "projects/k3bdatasessionimportdialog.h"
+#include "k3bpassivepopup.h"
+#include "k3bthemedheader.h"
+#include <k3baudioserver.h>
 
 
 class K3bMainWindow::Private
@@ -148,8 +156,6 @@ K3bMainWindow::K3bMainWindow()
 
   m_config = kapp->config();
 
-  resize(780,520);  // default optimized for 800x600
-
   ///////////////////////////////////////////////////////////////////
   // call inits to invoke all other construction parts
   initActions();
@@ -165,17 +171,20 @@ K3bMainWindow::K3bMainWindow()
   m_documentTab->insertAction( actionFileSaveAs );
   m_documentTab->insertAction( actionFileClose );
 
-  readOptions();
-
   // /////////////////////////////////////////////////////////////////
   // disable actions at startup
   slotStateChanged( "state_project_active", KXMLGUIClient::StateReverse );
 
-  // connect to the busy signals
-  connect( k3bcore, SIGNAL(busyInfoRequested(const QString&)), this, SLOT(showBusyInfo(const QString&)) );
-  connect( k3bcore, SIGNAL(busyFinishRequested()), this, SLOT(endBusy()) );
   connect( k3bappcore->projectManager(), SIGNAL(newProject(K3bDoc*)), this, SLOT(createClient(K3bDoc*)) );
-  connect( k3bappcore->themeManager(), SIGNAL(themeChanged()), this, SLOT(slotThemeChanged()) );
+  connect( k3bcore->deviceManager(), SIGNAL(changed()), this, SLOT(slotCheckSystemTimed()) );
+  connect( K3bAudioServer::instance(), SIGNAL(error(const QString&)), this, SLOT(slotAudioServerError(const QString&)) );
+
+  // FIXME: now make sure the welcome screen is displayed completely
+  resize( 780, 550 );
+//   getMainDockWidget()->resize( getMainDockWidget()->size().expandedTo( d->welcomeWidget->sizeHint() ) );
+//   m_dirTreeDock->resize( QSize( m_dirTreeDock->sizeHint().width(), m_dirTreeDock->height() ) );
+
+  readOptions();
 }
 
 K3bMainWindow::~K3bMainWindow()
@@ -196,6 +205,12 @@ void K3bMainWindow::showEvent( QShowEvent* e )
 
 void K3bMainWindow::initActions()
 {
+  // merge in the device actions from the device manager
+  // operator+= is deprecated but I know no other way to do this. Why does the KDE app framework
+  // need to have all actions in the mainwindow's actioncollection anyway (or am I just to stupid to
+  // see the correct solution?)
+  *actionCollection() += *k3bappcore->appDeviceManager()->actionCollection();
+
   actionFileOpen = KStdAction::open(this, SLOT(slotFileOpen()), actionCollection());
   actionFileOpenRecent = KStdAction::openRecent(this, SLOT(slotFileOpenRecent(const KURL&)), actionCollection());
   actionFileSave = KStdAction::save(this, SLOT(slotFileSave()), actionCollection());
@@ -215,29 +230,32 @@ void K3bMainWindow::initActions()
 
   KStdAction::configureToolbars(this, SLOT(slotEditToolbars()), actionCollection());
   setStandardToolBarMenuEnabled(true);
+  KStdAction::showMenubar( this, SLOT(slotShowMenuBar()), actionCollection() );
 
   actionFileNewMenu = new KActionMenu( i18n("&New Project"), "filenew", actionCollection(), "file_new" );
-  actionFileNewAudio = new KAction(i18n("New &Audio CD Project"), "sound", 0, this, SLOT(slotNewAudioDoc()),
+  actionFileNewAudio = new KAction(i18n("New &Audio CD Project"), "audiocd", 0, this, SLOT(slotNewAudioDoc()),
 			     actionCollection(), "file_new_audio");
-  actionFileNewData = new KAction(i18n("New Data &CD Project"),"tar", 0, this, SLOT(slotNewDataDoc()),
+  actionFileNewData = new KAction(i18n("New Data &CD Project"), "datacd", 0, this, SLOT(slotNewDataDoc()),
 			    actionCollection(), "file_new_data");
-  actionFileNewMixed = new KAction(i18n("New &Mixed Mode CD Project"),"tar", 0, this, SLOT(slotNewMixedDoc()),
+  actionFileNewMixed = new KAction(i18n("New &Mixed Mode CD Project"), "mixedcd", 0, this, SLOT(slotNewMixedDoc()),
 				   actionCollection(), "file_new_mixed");
-  actionFileNewVcd = new KAction(i18n("New &Video CD Project"),"video", 0, this, SLOT(slotNewVcdDoc()),
+  actionFileNewVcd = new KAction(i18n("New &Video CD Project"), "videocd", 0, this, SLOT(slotNewVcdDoc()),
 				   actionCollection(), "file_new_vcd");
-  actionFileNewMovix = new KAction(i18n("New &eMovix CD Project"),"video", 0, this, SLOT(slotNewMovixDoc()),
+  actionFileNewMovix = new KAction(i18n("New &eMovix CD Project"), "emovix", 0, this, SLOT(slotNewMovixDoc()),
 				   actionCollection(), "file_new_movix");
-  actionFileNewMovixDvd = new KAction(i18n("New &eMovix DVD Project"),"video", 0, this, SLOT(slotNewMovixDvdDoc()),
+  actionFileNewMovixDvd = new KAction(i18n("New &eMovix DVD Project"), "emovix", 0, this, SLOT(slotNewMovixDvdDoc()),
 				      actionCollection(), "file_new_movix_dvd");
-  actionFileNewDvd = new KAction(i18n("New Data &DVD Project"), "dvd_unmount", 0, this, SLOT(slotNewDvdDoc()),
+  actionFileNewDvd = new KAction(i18n("New Data &DVD Project"), "datadvd", 0, this, SLOT(slotNewDvdDoc()),
 				 actionCollection(), "file_new_dvd");
-  actionFileNewVideoDvd = new KAction(i18n("New V&ideo DVD Project"), "video", 0, this, SLOT(slotNewVideoDvdDoc()),
+  actionFileNewVideoDvd = new KAction(i18n("New V&ideo DVD Project"), "videodvd", 0, this, SLOT(slotNewVideoDvdDoc()),
 				      actionCollection(), "file_new_video_dvd");
-
+  actionFileContinueMultisession = new KAction( i18n("Continue Multisession Project"), "datacd", 0, this, SLOT(slotContinueMultisession()),
+						actionCollection(), "file_continue_multisession" );
 
   actionFileNewMenu->setDelayed( false );
   actionFileNewMenu->insert( actionFileNewData );
   actionFileNewMenu->insert( actionFileNewDvd );
+  actionFileNewMenu->insert( actionFileContinueMultisession );
   actionFileNewMenu->insert( new KActionSeparator( this ) );
   actionFileNewMenu->insert( actionFileNewAudio );
   actionFileNewMenu->insert( new KActionSeparator( this ) );
@@ -250,11 +268,14 @@ void K3bMainWindow::initActions()
   actionFileNewMenu->insert( actionFileNewMovixDvd );
 
 
+
+
+
   actionProjectAddFiles = new KAction( i18n("&Add Files..."), "filenew", 0, this, SLOT(slotProjectAddFiles()),
 				       actionCollection(), "project_add_files");
 
-  (void)new KAction( i18n("&Clear Project"), QApplication::reverseLayout() ? "clear_left" : "locationbar_erase", 0, this, SLOT(slotClearProject()),
-		     actionCollection(), "project_clear_project" );
+  KAction* actionClearProject = new KAction( i18n("&Clear Project"), QApplication::reverseLayout() ? "clear_left" : "locationbar_erase", 0, 
+					     this, SLOT(slotClearProject()), actionCollection(), "project_clear_project" );
 
   actionViewDirTreeView = new KToggleAction(i18n("Show Directories"), 0, this, SLOT(slotShowDirTreeView()),
 					    actionCollection(), "view_dir_tree");
@@ -265,38 +286,41 @@ void K3bMainWindow::initActions()
   actionViewDocumentHeader = new KToggleAction(i18n("Show Document Header"), 0, this, SLOT(slotViewDocumentHeader()),
 					       actionCollection(), "view_document_header");
 
-  actionToolsBlankCdrw = new KAction( i18n("&Erase CD-RW..."), "cdrwblank", 0, this, SLOT(slotBlankCdrw()),
+  actionToolsBlankCdrw = new KAction( i18n("&Erase CD-RW..."), "erasecd", 0, this, SLOT(slotBlankCdrw()),
 				      actionCollection(), "tools_blank_cdrw" );
-  /*KAction* actionToolsFormatDVD = */(void)new KAction( i18n("&Format DVD±RW..."), "cdrwblank", 0, this, SLOT(slotFormatDvd()),
-							 actionCollection(), "tools_format_dvd" );
-  actionToolsDivxEncoding = new KAction(i18n("&Encode Video..."),"gear", 0, this, SLOT( slotDivxEncoding() ),
-			    actionCollection(), "tools_encode_video");
-  actionToolsWriteCdImage = new KAction(i18n("&Burn CD Image..."), "gear", 0, this, SLOT(slotWriteCdImage()),
+  KAction* actionToolsFormatDVD = new KAction( i18n("&Format DVD%1RW...").arg(""), "formatdvd", 0, this, 
+					       SLOT(slotFormatDvd()), actionCollection(), "tools_format_dvd" );
+  actionToolsWriteCdImage = new KAction(i18n("&Burn CD Image..."), "burn_cdimage", 0, this, SLOT(slotWriteCdImage()),
 					 actionCollection(), "tools_write_cd_image" );
-  (void)new KAction(i18n("&Burn DVD ISO Image..."), "gear", 0, this, SLOT(slotWriteDvdIsoImage()),
-		    actionCollection(), "tools_write_dvd_iso" );
+  KAction* actionToolsWriteDvdImage = new KAction(i18n("&Burn DVD ISO Image..."), "burn_dvdimage", 0, this, SLOT(slotWriteDvdIsoImage()),
+						 actionCollection(), "tools_write_dvd_iso" );
 
   actionCdCopy = new KAction(i18n("&Copy CD..."), "cdcopy", 0, this, SLOT(slotCdCopy()),
 			     actionCollection(), "tools_copy_cd" );
 
-  KAction* actionToolsDvdCopy = new KAction(i18n("Copy &DVD..."), "cdcopy", 0, this, SLOT(slotDvdCopy()),
+  KAction* actionToolsDvdCopy = new KAction(i18n("Copy &DVD..."), "dvdcopy", 0, this, SLOT(slotDvdCopy()),
 					    actionCollection(), "tools_copy_dvd" );
 
-//   KAction* actionToolsVideoDvdCopy = new KAction(i18n("Copy &VideoDVD..."), "cdcopy", 0, this, SLOT(slotVideoDvdCopy()),
-// 						 actionCollection(), "tools_copy_video_dvd" );
+  actionToolsCddaRip = new KAction( i18n("Rip Audio CD..."), "cddarip", 0, this, SLOT(slotCddaRip()),
+				    actionCollection(), "tools_cdda_rip" );
+  actionToolsVideoDvdRip = new KAction( i18n("Rip Video DVD..."), "videodvd", 0, this, SLOT(slotVideoDvdRip()),
+				    actionCollection(), "tools_videodvd_rip" );
+  actionToolsVideoCdRip = new KAction( i18n("Rip Video CD..."), "videocd", 0, this, SLOT(slotVideoCdRip()),
+				       actionCollection(), "tools_videocd_rip" );
 
   (void)new KAction( i18n("System Check"), 0, 0, this, SLOT(slotCheckSystem()),
 		     actionCollection(), "help_check_system" );
 
-  KAction* actionToolsDiskInfo = new KAction( i18n("Diskinfo"), 0, 0, this, SLOT(slotToolsDiskInfo()),
-					      actionCollection(), "tools_disk_info" );
-
 #ifdef HAVE_K3BSETUP
-  actionSettingsK3bSetup = new KAction(i18n("K3b &Setup"), "configure", 0, this, SLOT(slotK3bSetup()),
+  actionSettingsK3bSetup = new KAction(i18n("&Setup System Permissions..."), "configure", 0, this, SLOT(slotK3bSetup()),
 				       actionCollection(), "settings_k3bsetup" );
 #endif
 
-
+#ifdef K3B_DEBUG
+  (void)new KAction( "Test Media Selection ComboBox", 0, 0, this, 
+		     SLOT(slotMediaSelectionTester()), actionCollection(),
+		     "test_media_selection" );
+#endif
 
   actionFileNewMenu->setToolTip(i18n("Creates a new project"));
   actionFileNewData->setToolTip( i18n("Creates a new data CD project") );
@@ -305,18 +329,29 @@ void K3bMainWindow::initActions()
   actionFileNewDvd->setToolTip( i18n("Creates a new data DVD project") );
   actionFileNewMovix->setToolTip( i18n("Creates a new eMovix CD project") );
   actionFileNewVcd->setToolTip( i18n("Creates a new Video CD project") );
-  actionToolsBlankCdrw->setToolTip( i18n("Opens CD-blanking dialog") );
-  actionCdCopy->setToolTip( i18n("Open the CD Copy dialog") );
-  actionToolsWriteCdImage->setToolTip( i18n("Write an Iso9660, cue/bin, or cdrecord clone image") );
-  actionToolsDvdCopy->setToolTip( i18n("Open the DVD Copy dialog") );
-  //  actionToolsVideoDvdCopy->setToolTip( i18n("Open the VideoDVD Copy dialog") );
+  actionToolsBlankCdrw->setToolTip( i18n("Open the CD-RW erasing dialog") );
+  actionToolsFormatDVD->setToolTip( i18n("Open the DVD%1RW formatting dialog").arg("") );
+  actionCdCopy->setToolTip( i18n("Open the CD copy dialog") );
+  actionToolsWriteCdImage->setToolTip( i18n("Write an Iso9660, cue/bin, or cdrecord clone image to CD") );
+  actionToolsWriteDvdImage->setToolTip( i18n("Write an Iso9660 image to DVD") );
+  actionToolsDvdCopy->setToolTip( i18n("Open the DVD copy dialog") );
   actionFileOpen->setToolTip(i18n("Opens an existing project"));
   actionFileOpenRecent->setToolTip(i18n("Opens a recently used file"));
-  actionFileSave->setToolTip(i18n("Saves the actual project"));
-  actionFileSaveAs->setToolTip(i18n("Saves the actual project as..."));
-  actionFileClose->setToolTip(i18n("Closes the actual project"));
+  actionFileSave->setToolTip(i18n("Saves the current project"));
+  actionFileSaveAs->setToolTip(i18n("Saves the current project to a new url"));
+  actionFileSaveAll->setToolTip(i18n("Saves all open projects"));
+  actionFileClose->setToolTip(i18n("Closes the current project"));
+  actionFileCloseAll->setToolTip(i18n("Closes all open projects"));
   actionFileQuit->setToolTip(i18n("Quits the application"));
-  actionToolsDiskInfo->setToolTip( i18n("Retrieve information about inserted media") );
+  actionSettingsConfigure->setToolTip( i18n("Configure K3b settings") );
+#ifdef HAVE_K3BSETUP
+  actionSettingsK3bSetup->setToolTip( i18n("Setup the system permissions (requires root privileges)") );
+#endif
+  actionToolsCddaRip->setToolTip( i18n("Digitally extract tracks from an audio CD") );
+  actionToolsVideoDvdRip->setToolTip( i18n("Transcode Video DVD titles") );
+  actionToolsVideoCdRip->setToolTip( i18n("Extract tracks from a Video CD") );
+  actionProjectAddFiles->setToolTip( i18n("Add files to the current project") );
+  actionClearProject->setToolTip( i18n("Clear the current project") );
 
   // make sure the tooltips are used for the menu
   actionCollection()->setHighlightingEnabled( true );
@@ -341,18 +376,6 @@ void K3bMainWindow::initStatusBar()
 }
 
 
-void K3bMainWindow::showBusyInfo( const QString& str )
-{
-  m_statusBarManager->showBusyInfo(str);
-}
-
-
-void K3bMainWindow::endBusy()
-{
-  m_statusBarManager->endBusy();
-}
-
-
 void K3bMainWindow::initView()
 {
   // setup main docking things
@@ -373,26 +396,11 @@ void K3bMainWindow::initView()
   documentHullLayout->setMargin( 2 );
   documentHullLayout->setSpacing( 0 );
 
-  m_documentHeader = K3bStdGuiItems::purpleFrame( d->documentHull );
-  QGridLayout* documentHeaderLayout = new QGridLayout( m_documentHeader );
-  documentHeaderLayout->setMargin( 2 );
-  documentHeaderLayout->setSpacing( 0 );
-
-  d->leftDocPicLabel = new QLabel( m_documentHeader );
-  d->centerDocLabel = new QLabel( m_documentHeader );
-  d->rightDocPicLabel = new QLabel( m_documentHeader );
-
-  d->centerDocLabel->setText( i18n("Current Projects") );
-  d->centerDocLabel->setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
-  QFont f(d->centerDocLabel->font());
-  f.setBold(true);
-  f.setPointSize( 12 );
-  d->centerDocLabel->setFont(f);
-
-  documentHeaderLayout->addWidget( d->leftDocPicLabel, 0, 0 );
-  documentHeaderLayout->addWidget( d->centerDocLabel, 0, 1 );
-  documentHeaderLayout->addWidget( d->rightDocPicLabel, 0, 2 );
-  documentHeaderLayout->setColStretch( 1, 1 );
+  m_documentHeader = new K3bThemedHeader( d->documentHull );
+  m_documentHeader->setTitle( i18n("Current Projects") );
+  m_documentHeader->setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
+  m_documentHeader->setLeftPixmap( K3bTheme::PROJECT_LEFT );
+  m_documentHeader->setRightPixmap( K3bTheme::PROJECT_RIGHT );
 
   // add the document tab to the styled document box
   m_documentTab = new K3bProjectTabWidget( d->documentHull );
@@ -402,10 +410,11 @@ void K3bMainWindow::initView()
 
   connect( m_documentTab, SIGNAL(currentChanged(QWidget*)), this, SLOT(slotCurrentDocChanged()) );
 
-  d->welcomeWidget = new K3bWelcomeWidget( this, d->documentStack );
+  d->welcomeWidget = new K3bWelcomeWidget( this, m_documentTab );
+  m_documentTab->addTab( d->welcomeWidget, i18n("Quickstart") );
 
-  d->documentStack->addWidget( d->welcomeWidget );
-  d->documentStack->raiseWidget( d->welcomeWidget );
+//   d->documentStack->addWidget( d->welcomeWidget );
+//   d->documentStack->raiseWidget( d->welcomeWidget );
   // ---------------------------------------------------------------------------------------------
 
   // --- Directory Dock --------------------------------------------------------------------------
@@ -440,6 +449,7 @@ void K3bMainWindow::initView()
   connect( m_fileTreeComboBox, SIGNAL(deviceExecuted(K3bDevice::Device*)), m_dirView,
 	   SLOT(showDevice(K3bDevice::Device* )) );
   connect( m_dirView, SIGNAL(urlEntered(const KURL&)), m_fileTreeComboBox, SLOT(setUrl(const KURL&)) );
+  connect( m_dirView, SIGNAL(deviceSelected(K3bDevice::Device*)), m_fileTreeComboBox, SLOT(setDevice(K3bDevice::Device*)) );
 
   KWidgetAction* fileTreeComboAction = new KWidgetAction( m_fileTreeComboBox,
 							  i18n("&Quick Dir Selector"),
@@ -559,49 +569,47 @@ K3bDoc* K3bMainWindow::openDocument(const KURL& url)
 
 void K3bMainWindow::saveOptions()
 {
-  m_config->setGroup( "General Options" );
-
-  m_config->writeEntry( "Show Document Header", actionViewDocumentHeader->isChecked() );
-  actionFileOpenRecent->saveEntries( m_config, "Recent Files" );
+  actionFileOpenRecent->saveEntries( config(), "Recent Files" );
 
   // save dock positions!
-  manager()->writeConfig( m_config, "Docking Config" );
+  manager()->writeConfig( config(), "Docking Config" );
 
   m_dirView->saveConfig( config() );
 
-  saveMainWindowSettings( m_config, "main_window_settings" );
+  saveMainWindowSettings( config(), "main_window_settings" );
 
   k3bcore->saveSettings( config() );
 
   d->welcomeWidget->saveConfig( config() );
+
+  KConfigGroup grp( m_config, "General Options" );
+  grp.writeEntry( "Show Document Header", actionViewDocumentHeader->isChecked() );
 }
 
 
 void K3bMainWindow::readOptions()
 {
-  m_config->setGroup("General Options");
+  KConfigGroup grp( m_config, "General Options" );
 
-  bool bViewDocumentHeader = m_config->readBoolEntry("Show Document Header", true);
+  bool bViewDocumentHeader = grp.readBoolEntry("Show Document Header", true);
   actionViewDocumentHeader->setChecked(bViewDocumentHeader);
 
   // initialize the recent file list
-  actionFileOpenRecent->loadEntries(m_config,"Recent Files");
+  actionFileOpenRecent->loadEntries( config(), "Recent Files" );
 
   // do not read dock-positions from a config that has been saved by an old version
-  K3bVersion configVersion( m_config->readEntry( "config version", "0.1" ) );
+  K3bVersion configVersion( grp.readEntry( "config version", "0.1" ) );
   if( configVersion >= K3bVersion("0.12") )
-    manager()->readConfig( m_config, "Docking Config" );
+    manager()->readConfig( config(), "Docking Config" );
   else
     kdDebug() << "(K3bMainWindow) ignoring docking config from K3b version " << configVersion << endl;
 
-  applyMainWindowSettings( m_config, "main_window_settings" );
+  applyMainWindowSettings( config(), "main_window_settings" );
 
   m_dirView->readConfig( config() );
 
   slotViewDocumentHeader();
   slotCheckDockWidgetStatus();
-
-  slotThemeChanged();
 }
 
 
@@ -614,6 +622,13 @@ void K3bMainWindow::saveProperties( KConfig* c )
 
   QString saveDir = KGlobal::dirs()->saveLocation( "appdata", "sessions/" + qApp->sessionId() + "/", true );
 
+  // FIXME: for some reason the config entries are not properly stored when using the default
+  //        KMainWindow session config. Since I was not able to find the bug I use another config object
+  // ----------------------------------------------------------
+  c = new KSimpleConfig( saveDir + "list", false );
+  c->setGroup( "Saved Session" );
+  // ----------------------------------------------------------
+
   const QPtrList<K3bDoc>& docs = k3bappcore->projectManager()->projects();
   c->writeEntry( "Number of projects", docs.count() );
 
@@ -640,6 +655,12 @@ void K3bMainWindow::saveProperties( KConfig* c )
 
     ++cnt;
   }
+
+  // FIXME: for some reason the config entries are not properly stored when using the default
+  //        KMainWindow session config. Since I was not able to find the bug I use another config object
+  // ----------------------------------------------------------
+  delete c;
+  // ----------------------------------------------------------
 }
 
 
@@ -650,15 +671,22 @@ void K3bMainWindow::readProperties( KConfig* c )
   //        since that's when we can be sure we never need the session stuff again.
 
   // 1. read all projects from the config
-  // 2. simply open all of them
+  // 2. simply open all of themg
   // 3. reset the saved urls and the modified state
   // 4. delete "~/.kde/share/apps/k3b/sessions/" + KApp->sessionId()
 
   QString saveDir = KGlobal::dirs()->saveLocation( "appdata", "sessions/" + qApp->sessionId() + "/", true );
-  kdDebug() << "(K3bMainWindow::readProperties) saveDir: " << saveDir << endl;
+
+  // FIXME: for some reason the config entries are not properly stored when using the default
+  //        KMainWindow session config. Since I was not able to find the bug I use another config object
+  // ----------------------------------------------------------
+  c = new KSimpleConfig( saveDir + "list", true );
+  c->setGroup( "Saved Session" );
+  // ----------------------------------------------------------
 
   int cnt = c->readNumEntry( "Number of projects", 0 );
-  kdDebug() << "(K3bMainWindow::readProperties) num: " << cnt << endl;
+  kdDebug() << "(K3bMainWindow::readProperties) number of projects from last session in " << saveDir << ": " << cnt << endl
+	    << "                                read from config group " << c->group() << endl;
 
   for( int i = 1; i <= cnt; ++i ) {
     // in this case the constructor works since we saved as url()
@@ -688,6 +716,12 @@ void K3bMainWindow::readProperties( KConfig* c )
 
   // and now remove the temp dir
   KIO::del( KURL::fromPathOrURL(saveDir), false, false );
+
+  // FIXME: for some reason the config entries are not properly stored when using the default
+  //        KMainWindow session config. Since I was not able to find the bug I use another config object
+  // ----------------------------------------------------------
+  delete c;
+  // ----------------------------------------------------------
 }
 
 
@@ -728,7 +762,7 @@ bool K3bMainWindow::queryClose()
 // 				      i18n("Do you really want to cancel?"), 
 // 				      i18n("Cancel") ) == KMessageBox::Yes ) {
 // 	// cancel the job
-// 	kdDebug() << "(K3bMainWindow::queryClose) cancelling job." << endl;
+// 	kdDebug() << "(K3bMainWindow::queryClose) canceling job." << endl;
 // 	job->cancel();
 
 // 	// wait for the job to finish
@@ -788,14 +822,13 @@ bool K3bMainWindow::canCloseDocument( K3bDoc* doc )
   if( !doc->isModified() )
     return true;
 
-  m_config->setGroup( "General Options" );
-  if( !m_config->readBoolEntry( "ask_for_saving_changes_on_exit", true ) )
+  if( !KConfigGroup( config(), "General Options" ).readBoolEntry( "ask_for_saving_changes_on_exit", true ) )
     return true;
 
   switch ( KMessageBox::warningYesNoCancel( this, 
 					    i18n("%1 has unsaved data.").arg( doc->URL().fileName() ),
 					    i18n("Closing Project"), 
-					    KGuiItem( i18n("&Save"), "filesave" ),
+					    KStdGuiItem::save(),
 					    KGuiItem( i18n("&Discard"), "editshred" ) ) )
     {
     case KMessageBox::Yes:
@@ -826,7 +859,7 @@ void K3bMainWindow::slotFileOpen()
 {
   slotStatusMsg(i18n("Opening file..."));
 
-  KURL::List urls = KFileDialog::getOpenURLs( QString::null,
+  KURL::List urls = KFileDialog::getOpenURLs( ":k3b-projects-folder",
 					      i18n("*.k3b|K3b Projects"),
 					      this,
 					      i18n("Open Files") );
@@ -893,33 +926,30 @@ void K3bMainWindow::fileSaveAs( K3bDoc* doc )
   }
 
   if( doc != 0 ) {
+    // we do not use the static KFileDialog method here to be able to specify a filename suggestion
+    KFileDialog dlg( ":k3b-projects-folder", i18n("*.k3b|K3b Projects"), this, "filedialog", true );
+    dlg.setCaption( i18n("Save As") );
+    dlg.setOperationMode( KFileDialog::Saving );
+    dlg.setSelection( doc->name() );
+    dlg.exec();
+    KURL url = dlg.selectedURL();
 
-    QString file = KFileDialog::getSaveFileName(QDir::currentDirPath(),
-					       i18n("*.k3b|K3b Projects"), this, i18n("Save As"));
+    if( url.isValid() ) {
+      KRecentDocument::add( url );
 
+      bool exists = KIO::NetAccess::exists( url, false, 0 );
+      if( !exists ||
+	  ( exists &&
+	    KMessageBox::warningContinueCancel( this, i18n("Do you want to overwrite %1?").arg( url.prettyURL() ), 
+						i18n("File Exists"), i18n("Overwrite") )
+	    == KMessageBox::Continue ) ) {
 
-    if( !file.isEmpty() ) {
-
-      // default to ending ".k3b"
-      if( file.mid( file.findRev('.')+1 ) != "k3b" ) {
-	if( file[ file.length()-1 ] != '.' )
-	  file += ".";
-	file += "k3b";
-      }
-
-      if( !QFile::exists(file) ||
-	  ( QFile::exists(file) &&
-	    KMessageBox::questionYesNo( this, i18n("Do you want to overwrite %1?").arg(file), i18n("File Exists") )
-	    == KMessageBox::Yes ) ) {
-
-        KURL url;
-        url.setPath(file);
 	if( !k3bappcore->projectManager()->saveProject( doc, url ) ) {
 	  KMessageBox::error (this,i18n("Could not save the current document!"), i18n("I/O Error"));
 	  return;
 	}
-
-	actionFileOpenRecent->addURL(url);
+	else
+	  actionFileOpenRecent->addURL(url);
       }
     }
   }
@@ -949,9 +979,10 @@ void K3bMainWindow::slotFileCloseAll()
     if( pView ) {
       K3bDoc* pDoc = pView->doc();
 
-      if( canCloseDocument(pDoc) ) {
+      if( canCloseDocument(pDoc) )
 	closeProject(pDoc);
-      }
+      else
+	break;
     }
   }
 
@@ -1065,6 +1096,12 @@ K3bDoc* K3bMainWindow::slotNewDvdDoc()
 }
 
 
+K3bDoc* K3bMainWindow::slotContinueMultisession()
+{
+  return K3bDataSessionImportDialog::importSession( 0, this );
+}
+
+
 K3bDoc* K3bMainWindow::slotNewVideoDvdDoc()
 {
   slotStatusMsg(i18n("Creating new VideoDVD Project."));
@@ -1114,14 +1151,6 @@ K3bDoc* K3bMainWindow::slotNewMovixDvdDoc()
 }
 
 
-void K3bMainWindow::slotDivxEncoding()
-{
-  slotStatusMsg(i18n("Creating new video encoding project."));
-  K3bDivxView d( this, "divx");
-  d.exec();
-}
-
-
 void K3bMainWindow::slotCurrentDocChanged()
 {
   // check the doctype
@@ -1157,15 +1186,15 @@ void K3bMainWindow::slotCurrentDocChanged()
     k3bappcore->projectManager()->setActive( 0L );
 
   if( k3bappcore->projectManager()->isEmpty() ) {
-    d->documentStack->raiseWidget( d->welcomeWidget );
     slotStateChanged( "state_project_active", KXMLGUIClient::StateReverse );
   }
   else {
     d->documentStack->raiseWidget( d->documentHull );
-    // make sure the document header is shown (or not)
-    slotViewDocumentHeader();
     slotStateChanged( "state_project_active", KXMLGUIClient::StateNoReverse );
   }
+
+  // make sure the document header is shown (or not)
+  slotViewDocumentHeader();
 }
 
 
@@ -1203,20 +1232,6 @@ void K3bMainWindow::slotWarningMessage(const QString& message)
 }
 
 
-void K3bMainWindow::slotBlankCdrw()
-{
-  K3bBlankingDialog d( this, "blankingdialog" );
-  d.exec(false);
-}
-
-
-void K3bMainWindow::slotFormatDvd()
-{
-  K3bDvdFormattingDialog d( this );
-  d.exec(false);
-}
-
-
 void K3bMainWindow::slotWriteCdImage()
 {
   K3bCdImageWritingDialog d( this );
@@ -1252,8 +1267,8 @@ void K3bMainWindow::slotProjectAddFiles()
   K3bView* view = activeView();
 
   if( view ) {
-    QStringList files = KFileDialog::getOpenFileNames( ".", 
-						       "*|All Files", 
+    QStringList files = KFileDialog::getOpenFileNames( ":k3b-project-add-files", 
+						       i18n("*|All Files"), 
 						       this, 
 						       i18n("Select Files to Add to Project") );
 
@@ -1283,17 +1298,59 @@ void K3bMainWindow::slotK3bSetup()
 }
 
 
-void K3bMainWindow::slotCdCopy()
+void K3bMainWindow::blankCdrw( K3bDevice::Device* dev )
+{
+  K3bBlankingDialog dlg( this, "blankingdialog" );
+  dlg.setDevice( dev );
+  dlg.exec(false);
+}
+
+
+void K3bMainWindow::slotBlankCdrw()
+{
+  blankCdrw( 0 );
+}
+
+
+void K3bMainWindow::formatDvd( K3bDevice::Device* dev )
+{
+  K3bDvdFormattingDialog d( this );
+  d.setDevice( dev );
+  d.exec(false);
+}
+
+
+void K3bMainWindow::slotFormatDvd()
+{
+  formatDvd( 0 );
+}
+
+
+void K3bMainWindow::cdCopy( K3bDevice::Device* dev )
 {
   K3bCdCopyDialog d( this );
+  d.setReadingDevice( dev );
+  d.exec(false);
+}
+
+
+void K3bMainWindow::slotCdCopy()
+{
+  cdCopy( 0 );
+}
+
+
+void K3bMainWindow::dvdCopy( K3bDevice::Device* dev )
+{
+  K3bDvdCopyDialog d( this );
+  d.setReadingDevice( dev );
   d.exec(false);
 }
 
 
 void K3bMainWindow::slotDvdCopy()
 {
-  K3bDvdCopyDialog d( this );
-  d.exec(false);
+  dvdCopy( 0 );
 }
 
 
@@ -1318,6 +1375,15 @@ void K3bMainWindow::slotShowContentsView()
 }
 
 
+void K3bMainWindow::slotShowMenuBar() 
+{ 
+  if( menuBar()->isVisible() ) 
+    menuBar()->hide(); 
+  else 
+    menuBar()->show(); 
+}
+
+
 void K3bMainWindow::slotShowTips()
 {
   KTipDialog::showTip( this, QString::null, true );
@@ -1345,7 +1411,8 @@ void K3bMainWindow::slotCheckDockWidgetStatus()
 
 void K3bMainWindow::slotViewDocumentHeader()
 {
-  if(actionViewDocumentHeader->isChecked()) {
+  if( actionViewDocumentHeader->isChecked() &&
+      !k3bappcore->projectManager()->isEmpty() ) {
     m_documentHeader->show();
   }
   else {
@@ -1396,6 +1463,15 @@ void K3bMainWindow::slotEditBootImages()
 }
 
 
+void K3bMainWindow::slotCheckSystemTimed()
+{
+  // run the system check from the event queue so we do not
+  // mess with the device state resetting throughout the app
+  // when called from K3bDeviceManager::changed
+  QTimer::singleShot( 0, this, SLOT(slotCheckSystem()) );
+}
+
+
 void K3bMainWindow::slotCheckSystem()
 {
   K3bSystemProblemDialog::checkSystem( this );
@@ -1404,14 +1480,6 @@ void K3bMainWindow::slotCheckSystem()
 
 void K3bMainWindow::addUrls( const KURL::List& urls )
 {
-  //
-  // A lot of users try to write an iso image with a data project
-  //
-  if( urls.count() == 1 ) {
-    if( isCdDvdImageAndIfSoOpenDialog( urls.first() ) )
-      return;
-  }
-
   if( K3bView* view = activeView() ) {
     view->addUrls( urls );
   }
@@ -1450,7 +1518,7 @@ void K3bMainWindow::addUrls( const KURL::List& urls )
 
     if( audio )
       static_cast<K3bView*>(slotNewAudioDoc()->view())->addUrls( urls );
-    else
+    else if( urls.count() > 1 || !isCdDvdImageAndIfSoOpenDialog( urls.first() ) )
       static_cast<K3bView*>(slotNewDataDoc()->view())->addUrls( urls );
   }
 }
@@ -1460,12 +1528,11 @@ void K3bMainWindow::slotClearProject()
 {
   K3bDoc* doc = k3bappcore->projectManager()->activeDoc();
   if( doc ) {
-    if( KMessageBox::questionYesNo( this,
+    if( KMessageBox::warningContinueCancel( this,
 				    i18n("Do you really want to clear the current project?"),
 				    i18n("Clear Project"),
-				    KStdGuiItem::yes(),
-				    KStdGuiItem::no(),
-				    "clear_current_project_dontAskAgain" ) == KMessageBox::Yes ) {
+				    i18n("Clear"),
+				    "clear_current_project_dontAskAgain" ) == KMessageBox::Continue ) {
       doc->newDocument();
       k3bappcore->projectManager()->loadDefaults( doc );
     }
@@ -1473,17 +1540,6 @@ void K3bMainWindow::slotClearProject()
 }
 
 
-void K3bMainWindow::slotThemeChanged()
-{
-  if( K3bTheme* theme = k3bappcore->themeManager()->currentTheme() ) {
-    d->leftDocPicLabel->setPixmap( theme->pixmap( K3bTheme::PROJECT_LEFT ) );
-    d->rightDocPicLabel->setPixmap( theme->pixmap( K3bTheme::PROJECT_RIGHT ) );
-    d->centerDocLabel->setPaletteBackgroundColor( theme->backgroundColor() );
-    d->centerDocLabel->setPaletteForegroundColor( theme->foregroundColor() );
-  }
-}
-
-
 bool K3bMainWindow::isCdDvdImageAndIfSoOpenDialog( const KURL& url )
 {
   K3bIso9660 iso( url.path() );
@@ -1502,12 +1558,73 @@ bool K3bMainWindow::isCdDvdImageAndIfSoOpenDialog( const KURL& url )
 }
 
 
-void K3bMainWindow::slotToolsDiskInfo()
+void K3bMainWindow::slotCddaRip()
 {
-  K3bDevice::Device* dev = K3bDeviceSelectionDialog::selectDevice( this, i18n("Please select a CD/DVD device") );
-  if( dev ) {
-    m_dirView->showDiskInfo( dev );
-  }
+  cddaRip( 0 );
+}
+
+
+void K3bMainWindow::cddaRip( K3bDevice::Device* dev )
+{
+  if( !dev ||
+      !(k3bappcore->mediaCache()->medium( dev ).content() & K3bMedium::CONTENT_AUDIO ) )
+    dev = K3bMediaSelectionDialog::selectMedium( K3bDevice::MEDIA_CD_ALL, 
+						 K3bDevice::STATE_COMPLETE|K3bDevice::STATE_INCOMPLETE,
+						 K3bMedium::CONTENT_AUDIO, 
+						 this,
+						 i18n("Audio CD Rip") );
+
+  if( dev )
+    m_dirView->showDevice( dev );
+}
+
+
+void K3bMainWindow::videoDvdRip( K3bDevice::Device* dev )
+{
+  if( !dev ||
+      !(k3bappcore->mediaCache()->medium( dev ).content() & K3bMedium::CONTENT_VIDEO_DVD ) )
+    dev = K3bMediaSelectionDialog::selectMedium( K3bDevice::MEDIA_DVD_ALL, 
+						 K3bDevice::STATE_COMPLETE,
+						 K3bMedium::CONTENT_VIDEO_DVD, 
+						 this,
+						 i18n("Video DVD Rip") );
+
+  if( dev )
+    m_dirView->showDevice( dev );
+}
+
+
+void K3bMainWindow::slotVideoDvdRip()
+{
+  videoDvdRip( 0 );
+}
+
+
+void K3bMainWindow::videoCdRip( K3bDevice::Device* dev )
+{
+  if( !dev ||
+      !(k3bappcore->mediaCache()->medium( dev ).content() & K3bMedium::CONTENT_VIDEO_CD ) )
+    dev = K3bMediaSelectionDialog::selectMedium( K3bDevice::MEDIA_CD_ALL, 
+						 K3bDevice::STATE_COMPLETE,
+						 K3bMedium::CONTENT_VIDEO_CD, 
+						 this,
+						 i18n("Video CD Rip") );
+
+  if( dev )
+    m_dirView->showDevice( dev );
+}
+
+
+void K3bMainWindow::slotVideoCdRip()
+{
+  videoCdRip( 0 );
+}
+
+
+void K3bMainWindow::slotAudioServerError( const QString& error )
+{
+  K3bPassivePopup::showPopup( error, i18n("Audio Output Problem") );
 }
 
 #include "k3b.moc"
+
