@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bdataprojectinterface.cpp 501295 2006-01-22 15:18:46Z trueg $
+ * $Id: k3bdataprojectinterface.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,47 +32,58 @@ K3bDataProjectInterface::~K3bDataProjectInterface()
 }
 
 
-void K3bDataProjectInterface::createFolder( const QString& name )
+bool K3bDataProjectInterface::createFolder( const QString& name )
 {
-  createFolder( name, "/" );
+  return createFolder( name, "/" );
 }
 
 
-void K3bDataProjectInterface::createFolder( const QString& name, const QString& parent )
+bool K3bDataProjectInterface::createFolder( const QString& name, const QString& parent )
 {
   K3bDataItem* p = m_dataDoc->root()->findByPath( parent );
-  if( p && p->isDir() && !static_cast<K3bDirItem*>(p)->find( name ) )
+  if( p && p->isDir() && !static_cast<K3bDirItem*>(p)->find( name ) ) {
     m_dataDoc->addEmptyDir( name, static_cast<K3bDirItem*>(p) );
+    return true;
+  }
+  return false;
 }
 
 
-void K3bDataProjectInterface::addUrl( const KURL& url, const QString& parent )
+void K3bDataProjectInterface::addUrl( const QString& url, const QString& parent )
 {
-  addUrls( KURL::List(url), parent );
+  addUrls( QStringList(url), parent );
 }
 
 
-void K3bDataProjectInterface::addUrls( const KURL::List& urls, const QString& parent )
+void K3bDataProjectInterface::addUrls( const QStringList& urls, const QString& parent )
 {
   K3bDataItem* p = m_dataDoc->root()->findByPath( parent );
   if( p && p->isDir() )
-    m_dataDoc->addUrls( urls, static_cast<K3bDirItem*>(p) );
+    m_dataDoc->addUrls( KURL::List(urls), static_cast<K3bDirItem*>(p) );
 }
 
 
-void K3bDataProjectInterface::removeItem( const QString& path )
+bool K3bDataProjectInterface::removeItem( const QString& path )
 {
   K3bDataItem* p = m_dataDoc->root()->findByPath( path );
-  if( p )
+  if( p && p->isRemoveable() ) {
     m_dataDoc->removeItem( p );
+    return true;
+  }
+  else
+    return false;
 }
 
 
-void K3bDataProjectInterface::renameItem( const QString& path, const QString& newName )
+bool K3bDataProjectInterface::renameItem( const QString& path, const QString& newName )
 {
   K3bDataItem* p = m_dataDoc->root()->findByPath( path );
-  if( p && !newName.isEmpty() )
+  if( p && p->isRenameable() && !newName.isEmpty() ) {
     p->setK3bName( newName );
+    return true;
+  }
+  else
+    return false;
 }
 
 
@@ -105,13 +116,13 @@ QStringList K3bDataProjectInterface::children( const QString& path ) const
 }
 
 
-bool K3bDataProjectInterface::setSortWeight( const QString& path, int weight ) const
+bool K3bDataProjectInterface::setSortWeight( const QString& path, long weight ) const
 {
   K3bDataItem* item =  m_dataDoc->root()->findByPath( path );
   if( item ) {
-    item->setSortWeigth( weight );
+    item->setSortWeight( weight );
     return true;
   }
   else
     return false;
-}
\ No newline at end of file
+}
