@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bfiletreecombobox.cpp 403289 2005-04-05 12:42:55Z trueg $
+ * $Id: k3bfiletreecombobox.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include <k3bdevicemanager.h>
 #include <k3bdevice.h>
 #include <k3bcore.h>
+#include <k3bglobals.h>
 
 #include <qrect.h>
 #include <qapplication.h>
@@ -35,6 +36,7 @@
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <kurlcompletion.h>
+#include <kuser.h>
 
 
 class K3bFileTreeComboBox::Private
@@ -61,7 +63,7 @@ K3bFileTreeComboBox::K3bFileTreeComboBox( QWidget* parent, const char* name )
 
   m_fileTreeView = new K3bFileTreeView( this );
   m_fileTreeView->hide();
-  m_fileTreeView->reparent( this, WType_Popup, QPoint(0,0), FALSE );
+  m_fileTreeView->reparent( this, WType_Popup, QPoint(0,0), false );
   m_fileTreeView->header()->hide();
   m_fileTreeView->installEventFilter(this);
 
@@ -92,7 +94,7 @@ K3bFileTreeComboBox::~K3bFileTreeComboBox()
 
 void K3bFileTreeComboBox::slotDeviceExecuted( K3bDevice::Device* dev )
 {
-  setEditText( SmallIcon("cdrom_unmount"), dev->vendor() + " " + dev->description() + " (" + dev->blockDeviceName() + ")" );
+  setDevice( dev );
   popdown();
   emit deviceExecuted( dev );
 }
@@ -107,11 +109,17 @@ void K3bFileTreeComboBox::slotUrlExecuted( const KURL& url )
 
 void K3bFileTreeComboBox::setUrl( const KURL& url )
 {
-  setEditText( SmallIcon("folder"), url.path() );
+  setEditText( SmallIcon("folder"), K3b::convertToLocalUrl(url).path() );
   popdown();
 }
 
 
+void K3bFileTreeComboBox::setDevice( K3bDevice::Device* dev )
+{
+  setEditText( SmallIcon("cdrom_unmount"), dev->vendor() + " " + dev->description() + " (" + dev->blockDeviceName() + ")" );
+}
+
+
 void K3bFileTreeComboBox::setEditText( const QPixmap& pix, const QString& t )
 {
   // QComboBox::changeItem() doesn't honor the pixmap when
@@ -197,24 +205,49 @@ void K3bFileTreeComboBox::popdown()
 void K3bFileTreeComboBox::slotGoUrl()
 {
   QString p = currentText();
-  if( p.startsWith("/dev/") ) {
-    if( K3bDevice::Device* dev = k3bcore->deviceManager()->findDevice( p ) ) {
+
+  // check for a media url or a device string
+  if( K3bDevice::Device* dev = K3b::urlToDevice( p ) ) {
+    emit deviceExecuted( dev );
+    return;
+  }
+
+  // check for our own internal format
+  else if( p.contains("/dev/") ) {
+    int pos1 = p.findRev('(');
+    int pos2 = p.findRev(')');
+    QString devStr = p.mid( pos1+1, pos2-pos1-1  );
+    if( K3bDevice::Device* dev = k3bcore->deviceManager()->findDevice( devStr ) ) {
       emit deviceExecuted( dev );
       return;
     }
   }
 
   // no device -> select url
-  if( p.startsWith( "~/" ) || p == "~" )
-    p.replace( "~", QDir::homeDirPath() );
-  else if( p.startsWith( "~" ) ) {
-    int i = p.find( '/' );
-    if( i < 0 )
-      i = p.length();
-    QString userName = p.mid( 1, i-1 );
-    p = "/home/" + userName + p.mid( i );
+
+  //
+  // Properly replace home dirs.
+  // a single ~ will be replaced with the current user's home dir 
+  // while for example "~ftp" will be replaced by the home dir of user
+  // ftp
+  //
+  // TODO: move this to k3bglobals
+
+  // to expand another user's home dir we need a tilde followed by a user name
+  static QRegExp someUsersHomeDir( "\\~([^/]+)" );
+  int pos = 0;
+  while( ( pos = someUsersHomeDir.search( p, pos ) ) != -1 ) {
+    KUser user( someUsersHomeDir.cap(1) );
+    if( user.isValid() )
+      p.replace( pos, someUsersHomeDir.cap(1).length() + 1, user.homeDir() );
+    else
+      ++pos; // skip this ~
   }
 
+  // now replace the unmatched tildes with our home dir
+  p.replace( "~", K3b::prepareDir( QDir::homeDirPath() ) );
+
+
   lineEdit()->setText( p );
   KURL url;
   url.setPath( p );
