@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3bfiletreeview.cpp 527717 2006-04-09 08:45:21Z trueg $
+ * $Id: k3bfiletreeview.cpp 657858 2007-04-25 08:25:11Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,12 +15,15 @@
 
 
 #include "k3bfiletreeview.h"
-//#include "k3b.h"
-//#include "k3bdirview.h"
+#include "k3bappdevicemanager.h"
+#include "k3bapplication.h"
+#include "k3bmediacache.h"
+#include "k3btooltip.h"
+#include "k3bthememanager.h"
 
-#include <k3bdevicemanager.h>
 #include <k3bdevice.h>
 #include <k3bdiskinfo.h>
+#include <k3bglobals.h>
 
 #include <kiconloader.h>
 #include <klocale.h>
@@ -39,36 +42,46 @@
 #include <qnamespace.h>
 #include <qmap.h>
 #include <qptrdict.h>
-
+#include <qpainter.h>
+#include <qfont.h>
+#include <qstyle.h>
+#include <qlabel.h>
+#include <qlayout.h>
 
 
 K3bDeviceBranch::K3bDeviceBranch( KFileTreeView* view, K3bDevice::Device* dev, KFileTreeViewItem* item )
-  : KFileTreeBranch( view, 
-		     KURL(dev->mountPoint()), 
+  : KFileTreeBranch( view,
+		     KURL( "media:/" + dev->blockDeviceName() ),
 		     QString("%1 - %2").arg(dev->vendor()).arg(dev->description()),
 		     ( dev->burner()
 		       ? SmallIcon("cdwriter_unmount")
 		       : SmallIcon("cdrom_unmount") ),
-		     false, 
-		     item == 0 
-		     ? new K3bDeviceBranchViewItem( view,
-						    new KFileItem( KURL(dev->mountPoint()), "inode/directory",
-								   S_IFDIR  ),
-						    this )
-		     : item ), 
-    m_device( dev )
+		     false,
+		     item == 0
+		     ? new K3bDeviceBranchViewItem( view, dev, this )
+		     : item ),
+    m_device( dev ),
+    m_showBlockDeviceName( false )
 {
   setAutoUpdate(true);
   root()->setExpandable(false);
-}
+  updateLabel();
 
+  connect( k3bappcore->mediaCache(), SIGNAL(mediumChanged(K3bDevice::Device*)),
+	   this, SLOT(slotMediumChanged(K3bDevice::Device*)) );
+}
 
 
 bool K3bDeviceBranch::populate( const KURL& url,  KFileTreeViewItem *currItem )
 {
+  // FIXME: we somehow need to "unpopulate" once the medium is unmounted
+
   // make sure we do not try to populate in case we are not mounted
-  if( !KIO::findDeviceMountPoint( m_device->mountDevice() ).isEmpty() )
-    return KFileTreeBranch::populate( url, currItem );
+  if( K3b::isMounted( m_device ) ) {
+    bool b = KFileTreeBranch::populate( url, currItem );
+    populateFinished( currItem );
+    return b;
+  }
   else
     populateFinished( currItem );
 
@@ -76,81 +89,47 @@ bool K3bDeviceBranch::populate( const KURL& url,  KFileTreeViewItem *currItem )
 }
 
 
-void K3bDeviceBranch::showBlockDeviceName( bool b )
+void K3bDeviceBranch::setCurrent( bool c )
 {
-  if( b )
-    setName( QString("%1 - %2 (%3)")
+  static_cast<K3bDeviceBranchViewItem*>( root() )->setCurrent( c );
+}
+
+
+void K3bDeviceBranch::updateLabel()
+{
+  if( m_showBlockDeviceName )
+    setName( QString("%1 %2 (%3)")
 	     .arg(m_device->vendor())
 	     .arg(m_device->description())
 	     .arg(m_device->blockDeviceName()) );
   else
-    setName( QString("%1 - %2")
+    setName( QString("%1 %2")
 	     .arg(m_device->vendor())
 	     .arg(m_device->description()) );
 
-  root()->setText( 0, name() );
-}
-
-
-void K3bDeviceBranch::mount()
-{
-  if( !m_device->mountPoint().isEmpty() ) {
-    QString mp = KIO::findDeviceMountPoint( m_device->mountDevice() );
-    if( mp.isEmpty() )
-      connect( KIO::mount( true, 0, m_device->mountDevice(), m_device->mountPoint(), false ), SIGNAL(result(KIO::Job*)),
-	       this, SLOT( slotMountFinished(KIO::Job*) ) );
-    else {
-      kdDebug() << "(K3bDeviceBranch) device already mounted on " << mp << endl;
-      emit clear();
-      populate( KURL::fromPathOrURL(mp), root() );
-      emit mountFinished( this, mp );
-    }
-  }
-  else
-    emit mountFinished( this, QString::null );
-}
-
-
-void K3bDeviceBranch::unmount()
-{
-  QString mp = KIO::findDeviceMountPoint( m_device->mountDevice() );
-  if( mp.isEmpty() ) {
-    emit unmountFinished( this, true );   
+  if( k3bappcore->mediaCache() ) {
+    root()->setMultiLinesEnabled( true );
+    root()->setText( 0, name() + "\n" + k3bappcore->mediaCache()->mediumString( m_device ) );
+    static_cast<K3bFileTreeView*>( root()->listView() )->updateMinimumWidth();
   }
   else {
-    setAutoUpdate(false);
-    connect( KIO::unmount( device()->mountPoint(), false ), SIGNAL(result(KIO::Job*)),
-	     this, SLOT( slotUnmountFinished(KIO::Job*) ) );
+    root()->setMultiLinesEnabled( false );
+    root()->setText( 0, name() );
   }
 }
 
 
-void K3bDeviceBranch::slotMountFinished( KIO::Job* job )
+void K3bDeviceBranch::slotMediumChanged( K3bDevice::Device* dev )
 {
-  if( job->error() && !m_device->automount() ) {
-    job->showErrorDialog();
-    emit mountFinished( this, QString::null );
-  }
-  else {
-    emit clear();
-    populate( KURL::fromPathOrURL(m_device->mountPoint()), root() );
-    emit mountFinished( this, m_device->mountPoint() );
-  }
+  if( dev == m_device )
+    updateLabel();
 }
 
 
-void K3bDeviceBranch::slotUnmountFinished( KIO::Job* job )
+void K3bDeviceBranch::showBlockDeviceName( bool b )
 {
-  if( job->error() ) {
-    job->showErrorDialog();
-    emit unmountFinished( this, false );
-  }
-  else {
-    emit clear();
-    emit unmountFinished( this, true );
-  }
-
-  setAutoUpdate(true);
+  m_showBlockDeviceName = b;
+  updateLabel();
 }
 
 
@@ -172,24 +151,134 @@ K3bFileTreeBranch::K3bFileTreeBranch( KFileTreeView* view,
 
 
 
-K3bDeviceBranchViewItem::K3bDeviceBranchViewItem( KFileTreeViewItem* parent, KFileItem* item, KFileTreeBranch* branch )
-  : KFileTreeViewItem( parent, item, branch )
+K3bDeviceBranchViewItem::K3bDeviceBranchViewItem( KFileTreeViewItem* parent,
+						  K3bDevice::Device* dev,
+						  K3bDeviceBranch* branch )
+  : KFileTreeViewItem( parent,
+		       new KFileItem( KURL( "media:/" + dev->blockDeviceName() ),
+				      "inode/directory",
+				      S_IFDIR  ),
+		       branch ),
+    m_bCurrent( false ),
+    m_device( dev )
 {
 }
 
 
-K3bDeviceBranchViewItem::K3bDeviceBranchViewItem( KFileTreeView* parent, KFileItem* item, KFileTreeBranch* branch )
-  : KFileTreeViewItem( parent, item, branch )
+K3bDeviceBranchViewItem::K3bDeviceBranchViewItem( KFileTreeView* parent,
+						  K3bDevice::Device* dev,
+						  K3bDeviceBranch* branch )
+  : KFileTreeViewItem( parent,
+		       new KFileItem( KURL( "media:/" + dev->blockDeviceName() ),
+				      "inode/directory",
+				      S_IFDIR  ),
+		       branch ),
+    m_bCurrent( false ),
+    m_device( dev )
 {
 }
 
 
+void K3bDeviceBranchViewItem::setCurrent( bool c )
+{
+  m_bCurrent = c;
+  repaint();
+}
+
+
+void K3bDeviceBranchViewItem::paintCell( QPainter* p, const QColorGroup& cg, int /* col */, int width, int align )
+{
+  p->save();
+
+  int xpos = 1;
+  int ypos = 1;
+  QFontMetrics fm( p->fontMetrics() );
+
+  if( isSelected() ) {
+    p->fillRect( 0, 0, width, height(),
+		 cg.brush( QColorGroup::Highlight ) );
+    p->setPen( cg.highlightedText() );
+  }
+  else {
+    p->fillRect( 0, 0, width, height(), cg.base() );
+    p->setPen( cg.text() );
+  }
+
+  if( pixmap(0) ) {
+    p->drawPixmap( xpos, ypos, *pixmap(0) );
+    xpos += pixmap(0)->width() + 5;
+  }
+
+  if( m_bCurrent ) {
+    QFont f( listView()->font() );
+    f.setBold( true );
+    p->setFont( f );
+  }
+
+  ypos += fm.ascent();
+  QString line1 = text(0).left( text(0).find('\n') );
+  p->drawText( xpos, ypos, line1 );
+
+  QFont f( listView()->font() );
+  f.setItalic( true );
+  f.setBold( false );
+  f.setPointSize( f.pointSize() - 2 );
+  p->setFont( f );
+
+  ypos += p->fontMetrics().height() + 1;
+  QString line2 = text(0).mid( text(0).find('\n')+1 );
+  p->drawText( xpos - p->fontMetrics().leftBearing( line2[0] ), ypos, line2 );
+
+
+  // from QListViewItem
+  if( isOpen() && childCount() ) {
+    int textheight = fm.size( align, text(0) ).height() + 2 * listView()->itemMargin();
+    textheight = QMAX( textheight, QApplication::globalStrut().height() );
+    if ( textheight % 2 > 0 )
+      textheight++;
+    if ( textheight < height() ) {
+      int w = listView()->treeStepSize() / 2;
+      listView()->style().drawComplexControl( QStyle::CC_ListView, p, listView(),
+					      QRect( 0, textheight, w + 1, height() - textheight + 1 ), cg,
+					      QStyle::Style_Enabled,
+					      QStyle::SC_ListViewExpand,
+					      (uint)QStyle::SC_All, QStyleOption( this ) );
+    }
+  }
+
+  p->restore();
+}
+
+
+int K3bDeviceBranchViewItem::widthHint() const
+{
+  QFont f( listView()->font() );
+  if ( m_bCurrent ) {
+      f.setBold( true );
+  }
+  int w = QFontMetrics(f).width( text(0).left( text(0).find('\n') ) );
+
+  f.setItalic( true );
+  f.setBold( false );
+  f.setPointSize( f.pointSize() - 2 );
+  w = QMAX( w, QFontMetrics(f).width( text(0).mid( text(0).find('\n')+1 ) ) );
+
+  w++; // see paintCell
+
+  if( pixmap(0) )
+    w += pixmap(0)->width() + 5;
+
+  return w;
+}
+
+
 QString K3bDeviceBranchViewItem::key( int column, bool ascending ) const
 {
   return "0" + KFileTreeViewItem::key( column, ascending );
 }
 
 
+
 K3bFileTreeViewItem::K3bFileTreeViewItem( KFileTreeViewItem* parent, KFileItem* item, KFileTreeBranch* branch )
   : KFileTreeViewItem( parent, item, branch )
 {
@@ -208,18 +297,103 @@ QString K3bFileTreeViewItem::key( int column, bool ascending ) const
 }
 
 
+class K3bDeviceTreeToolTip : public K3bToolTip
+{
+public:
+  K3bDeviceTreeToolTip( QWidget* parent, K3bFileTreeView* lv );
+
+  void maybeTip( const QPoint &pos );
+
+private:
+  K3bFileTreeView* m_view;
+};
+
+
+K3bDeviceTreeToolTip::K3bDeviceTreeToolTip( QWidget* parent, K3bFileTreeView* lv )
+  : K3bToolTip( parent ),
+    m_view( lv )
+{
+  setTipTimeout( 500 );
+}
+
+
+void K3bDeviceTreeToolTip::maybeTip( const QPoint& pos )
+{
+  if( !parentWidget() || !m_view )
+    return;
+
+  K3bDeviceBranchViewItem* item = dynamic_cast<K3bDeviceBranchViewItem*>( m_view->itemAt( pos ) );
+  if( !item )
+    return;
+
+  K3bDevice::Device* dev = static_cast<K3bDeviceBranch*>( item->branch() )->device();
+
+  QFrame* tooltip = new QFrame( parentWidget() );
+  tooltip->setFrameStyle( QFrame::Panel | QFrame::Raised );
+  tooltip->setFrameShape( QFrame::StyledPanel );
+  QGridLayout* lay = new QGridLayout( tooltip, 2, 2, tooltip->frameWidth()*2 /*margin*/, 6 /*spacing*/ );
+
+  QString text = k3bappcore->mediaCache()->medium( dev ).longString();
+  int detailsStart = text.find( "<p>", 3 );
+  QString details = text.mid( detailsStart );
+  text.truncate( detailsStart );
+
+  QLabel* label = new QLabel( text, tooltip );
+  label->setMargin( 9 );
+  lay->addMultiCellWidget( label, 0, 0, 0, 1 );
+  label = new QLabel( details, tooltip );
+  label->setMargin( 9 );
+  label->setAlignment( Qt::Vertical );
+  lay->addMultiCellWidget( label, 1, 2, 0, 0 );
+  label = new QLabel( tooltip );
+  lay->addWidget( label, 2, 1 );
+  lay->setColStretch( 0, 1 );
+
+  if( K3bTheme* theme = k3bappcore->themeManager()->currentTheme() ) {
+    tooltip->setPaletteBackgroundColor( theme->backgroundColor() );
+    tooltip->setPaletteForegroundColor( theme->foregroundColor() );
+    K3bTheme::PixmapType pm;
+    int c = k3bappcore->mediaCache()->medium( dev ).content();
+    if( c & (K3bMedium::CONTENT_VIDEO_CD|K3bMedium::CONTENT_VIDEO_DVD) )
+      pm = K3bTheme::MEDIA_VIDEO;
+    else if( c & K3bMedium::CONTENT_AUDIO &&
+	      c & K3bMedium::CONTENT_DATA )
+      pm = K3bTheme::MEDIA_MIXED;
+    else if( c & K3bMedium::CONTENT_AUDIO )
+      pm = K3bTheme::MEDIA_AUDIO;
+    else if( c & K3bMedium::CONTENT_DATA )
+      pm = K3bTheme::MEDIA_DATA;
+    else {
+      K3bDevice::DiskInfo di = k3bappcore->mediaCache()->diskInfo( dev );
+      if( di.diskState() == K3bDevice::STATE_EMPTY )
+	pm = K3bTheme::MEDIA_EMPTY;
+      else
+	pm = K3bTheme::MEDIA_NONE;
+    }
+    label->setPixmap( theme->pixmap( pm ) );
+  }
+
+  // the tooltip will take care of deleting the widget
+  tip( m_view->itemRect( item ), tooltip );
+}
+
+
 
 class K3bFileTreeView::Private
 {
 public:
   Private()
-    : deviceManager(0) {
+    : deviceManager(0),
+      currentDeviceBranch(0) {
   }
 
   QPtrDict<K3bDeviceBranch> deviceBranchDict;
   QMap<KFileTreeBranch*, K3bDevice::Device*> branchDeviceMap;
 
   K3bDevice::DeviceManager* deviceManager;
+  K3bDeviceBranch* currentDeviceBranch;
+
+  K3bDeviceTreeToolTip* toolTip;
 };
 
 K3bFileTreeView::K3bFileTreeView( QWidget *parent, const char *name )
@@ -227,23 +401,26 @@ K3bFileTreeView::K3bFileTreeView( QWidget *parent, const char *name )
 {
   d = new Private();
 
+  d->toolTip = new K3bDeviceTreeToolTip( viewport(), this );
+
   addColumn( i18n("Directories") );
   setDragEnabled( true );
   setAlternateBackground( QColor() );
-  setFullWidth();
-  setRootIsDecorated(true);
+  setFullWidth(true);
+  //  setRootIsDecorated(true);
   setSorting(0);
 
   m_dirOnlyMode = true;
   m_menuEnabled = false;
 
   connect( this, SIGNAL(executed(QListViewItem*)), this, SLOT(slotItemExecuted(QListViewItem*)) );
+  connect( this, SIGNAL(returnPressed(QListViewItem*)), this, SLOT(slotItemExecuted(QListViewItem*)) );
   connect( this, SIGNAL(contextMenu(KListView*, QListViewItem* , const QPoint& )),
 	   this, SLOT(slotContextMenu(KListView*, QListViewItem* , const QPoint& )) );
 
   // we always simulate the single click
   slotSettingsChangedK3b(KApplication::SETTINGS_MOUSE);
-  if (kapp)
+  if( kapp )
     connect( kapp, SIGNAL(settingsChanged(int)), SLOT(slotSettingsChangedK3b(int)) );
 
   initActions();
@@ -289,8 +466,8 @@ void K3bFileTreeView::initActions()
 
 void K3bFileTreeView::addDefaultBranches()
 {
-  KURL home = KURL( QDir::homeDirPath() );
-  KURL root = KURL( "/" );
+  KURL home = KURL::fromPathOrURL( QDir::homeDirPath() );
+  KURL root = KURL( "file:/" );
 
   KFileTreeBranch* treeBranch = addBranch( new K3bFileTreeBranch( this, root, i18n("Root"), SmallIcon("folder_red") ) );
   treeBranch = addBranch( new K3bFileTreeBranch( this, home, i18n("Home"), SmallIcon("folder_home") ) );
@@ -312,9 +489,8 @@ void K3bFileTreeView::addCdDeviceBranches( K3bDevice::DeviceManager* dm )
   d->branchDeviceMap.clear();
   d->deviceBranchDict.clear();
 
-  QPtrList<K3bDevice::Device>& devices = dm->allDevices();
-  for ( K3bDevice::Device* dev = devices.first(); dev != 0; dev = devices.next() )
-    addDeviceBranch( dev );
+  for( QPtrListIterator<K3bDevice::Device> it( dm->allDevices() ); *it; ++it )
+    addDeviceBranch( *it );
 
   if( dm != d->deviceManager ) {
     if( d->deviceManager )
@@ -324,6 +500,20 @@ void K3bFileTreeView::addCdDeviceBranches( K3bDevice::DeviceManager* dm )
     // make sure we get changes to the config
     connect( dm, SIGNAL(changed(K3bDevice::DeviceManager*)),
 	     this, SLOT(addCdDeviceBranches(K3bDevice::DeviceManager*)) );
+
+    if( K3bAppDeviceManager* appDevM = dynamic_cast<K3bAppDeviceManager*>( dm ) )
+      connect( appDevM, SIGNAL(currentDeviceChanged(K3bDevice::Device*)),
+	       this, SLOT(setCurrentDevice(K3bDevice::Device*)) );
+  }
+
+  K3bDevice::Device* currentDevice = k3bappcore->appDeviceManager()->currentDevice();
+  if ( !currentDevice && !k3bappcore->appDeviceManager()->allDevices().isEmpty() ) {
+      k3bappcore->appDeviceManager()->setCurrentDevice( k3bappcore->appDeviceManager()->allDevices().getFirst() );
+  }
+
+  d->currentDeviceBranch = d->deviceBranchDict[currentDevice];
+  if( d->currentDeviceBranch ) {
+    d->currentDeviceBranch->setCurrent( true );
   }
 
   kdDebug() << "(K3bFileTreeView::addCdDeviceBranches) done" << endl;
@@ -334,12 +524,7 @@ void K3bFileTreeView::addDeviceBranch( K3bDevice::Device* dev )
 {
   K3bDeviceBranch* newBranch = new K3bDeviceBranch( this, dev );
   addBranch( newBranch );
-  
-  connect( newBranch, SIGNAL(mountFinished(K3bDeviceBranch*, const QString&)),
-	   this, SIGNAL(mountFinished(K3bDeviceBranch*, const QString&)) );
-  connect( newBranch, SIGNAL(unmountFinished(K3bDeviceBranch*, bool)),
-	   this, SIGNAL(unmountFinished(K3bDeviceBranch*, bool)) );
-  
+
   // search for an equal device
   int equalCnt = 0;
   K3bDeviceBranch* equalBranch = 0;
@@ -366,12 +551,15 @@ void K3bFileTreeView::addDeviceBranch( K3bDevice::Device* dev )
   // add to maps
   d->branchDeviceMap.insert( newBranch, dev );
   d->deviceBranchDict.insert( (void*)dev, newBranch );
+
+  updateMinimumWidth();
 }
 
 
 KFileTreeBranch* K3bFileTreeView::addBranch( KFileTreeBranch* branch )
 {
   KFileTreeBranch* newBranch = KFileTreeView::addBranch( branch );
+  newBranch->setChildRecurse( false );
   setDirOnlyMode( newBranch, m_dirOnlyMode );
 
   return newBranch;
@@ -381,6 +569,7 @@ KFileTreeBranch* K3bFileTreeView::addBranch( KFileTreeBranch* branch )
 KFileTreeBranch* K3bFileTreeView::addBranch( const KURL& url, const QString& name, const QPixmap& pix, bool showHidden )
 {
   KFileTreeBranch* newBranch = KFileTreeView::addBranch( url, name, pix, showHidden );
+  newBranch->setChildRecurse( false );
   setDirOnlyMode( newBranch, m_dirOnlyMode );
 
   return newBranch;
@@ -391,8 +580,11 @@ void K3bFileTreeView::slotItemExecuted( QListViewItem* item )
 {
   KFileTreeViewItem* treeItem = static_cast<KFileTreeViewItem*>(item);
   if( d->branchDeviceMap.contains( treeItem->branch() ) &&
-      treeItem == treeItem->branch()->root() )
-    emit deviceExecuted( d->branchDeviceMap[treeItem->branch()] );
+      treeItem == treeItem->branch()->root() ) {
+    K3bDevice::Device* dev = d->branchDeviceMap[treeItem->branch()];
+      k3bappcore->appDeviceManager()->setCurrentDevice( dev );
+    emit deviceExecuted( dev );
+  }
   else
     emit urlExecuted( treeItem->url() );
 }
@@ -424,22 +616,21 @@ void K3bFileTreeView::slotContextMenu( KListView*, QListViewItem* item, const QP
 {
   KFileTreeViewItem* treeItem = dynamic_cast<KFileTreeViewItem*>(item);
   if( treeItem ) {
-    bool device = d->branchDeviceMap.contains( treeItem->branch() );
+    K3bDevice::Device* device = 0;
+    QMap<KFileTreeBranch*, K3bDevice::Device*>::iterator devIt =
+      d->branchDeviceMap.find( treeItem->branch() );
+    if( devIt != d->branchDeviceMap.end() )
+      device = devIt.data();
 
-//     if( m_menuEnabled ) {
-//       if( device )
-// 	m_devicePopupMenu->popup(p);
-//       else
-// 	m_urlPopupMenu->popup(p);
-//     }
-//     else {
-      setCurrentItem( treeItem );
-      setSelected( treeItem, true);
-      if( device )
-	emit contextMenu( d->branchDeviceMap[treeItem->branch()], p );
-      else
-	emit contextMenu( treeItem->url(), p );
-      //    }
+    setCurrentItem( treeItem );
+    setSelected( treeItem, true);
+
+    if( device ) {
+      k3bappcore->appDeviceManager()->setCurrentDevice( device );
+      emit contextMenu( device, p );
+    }
+    else
+      emit contextMenu( treeItem->url(), p );
   }
   else
     kdWarning() << "(K3bFileTreeView) found viewItem that is no KFileTreeViewItem!" << endl;
@@ -467,18 +658,27 @@ KURL K3bFileTreeView::selectedUrl() const
   return KURL();
 }
 
-void K3bFileTreeView::setSelectedDevice(K3bDevice::Device* dev)
+
+void K3bFileTreeView::setCurrentDevice( K3bDevice::Device* dev )
 {
-  for(QMap<KFileTreeBranch*, K3bDevice::Device*>::iterator it = d->branchDeviceMap.begin();
-      it != d->branchDeviceMap.end(); ++it)
-  {
-    kdDebug() << "Select " << dev->devicename() << endl;
-    if ( *it == dev ) {
-      setCurrentItem( it.key()->root() );
-      setSelected( it.key()->root(), true);
-      return;
-    }
+  if( d->currentDeviceBranch )
+    d->currentDeviceBranch->setCurrent( false );
+
+  if( dev ) {
+    if ( ( d->currentDeviceBranch = branch( dev ) ) )
+        d->currentDeviceBranch->setCurrent( true );
   }
+
+  updateMinimumWidth();
+}
+
+
+void K3bFileTreeView::setSelectedDevice( K3bDevice::Device* dev )
+{
+  setCurrentDevice( dev );
+  K3bDeviceBranch* b = branch( dev );
+  setCurrentItem( b->root() );
+  setSelected( b->root(), true );
 }
 
 
@@ -509,4 +709,20 @@ void K3bFileTreeView::slotMouseButtonClickedK3b( int btn, QListViewItem *item, c
     emitExecute(item, pos, c);
 }
 
+
+void K3bFileTreeView::updateMinimumWidth()
+{
+  //
+  // only handle the device branches, we don't care about the folders.
+  //
+  int w = 0;
+  for( QMap<KFileTreeBranch*, K3bDevice::Device*>::Iterator it = d->branchDeviceMap.begin();
+       it != d->branchDeviceMap.end(); ++it ) {
+    w = QMAX( w, static_cast<K3bDeviceBranchViewItem*>( it.key()->root() )->widthHint() );
+  }
+
+  // width of the items + scrollbar width + the frame + a little eyecandy spacing
+  setMinimumWidth( w + verticalScrollBar()->sizeHint().width() + 2*frameWidth() + 2 );
+}
+
 #include "k3bfiletreeview.moc"
