@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3bfileview.cpp 467572 2005-10-05 16:42:24Z trueg $
+ * $Id: k3bfileview.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 
 
 K3bFileView::K3bFileView(QWidget *parent, const char *name ) 
-  : K3bCdContentsView(false, parent,name) 
+  : K3bContentsView( false, parent, name)
 {
   setupGUI();
 }
@@ -67,9 +67,6 @@ void K3bFileView::setupGUI()
   //  layout->setAutoAdd( true );
 
   m_dirOp = new K3bDirOperator( KURL::fromPathOrURL(QDir::home().absPath()), this );
-  m_dirOp->setViewConfig( k3bcore->config(), "file view" );
-  m_dirOp->setMode( KFile::Files );
-
   m_toolBox = new K3bToolBox( this );
 
   layout->addWidget( m_toolBox );
@@ -87,12 +84,16 @@ void K3bFileView::setupGUI()
   m_toolBox->addButton( actionHome );
   m_toolBox->addButton( actionReload );
   m_toolBox->addSpacing();
+  m_toolBox->addButton( m_dirOp->actionCollection()->action("short view") );
+  m_toolBox->addButton( m_dirOp->actionCollection()->action("detailed view") );
+  m_toolBox->addSpacing();
   m_toolBox->addButton( m_dirOp->bookmarkMenu() );
   m_toolBox->addSpacing();
 
   // create filter selection combobox
   m_toolBox->addSpacing();
   m_toolBox->addLabel( i18n("Filter:") );
+  m_toolBox->addSpacing();
   m_filterWidget = new KFileFilterCombo( m_toolBox, "filterwidget" );
   m_toolBox->addWidget( m_filterWidget );
   m_toolBox->addStretch();
