@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bprojectinterface.cpp 488458 2005-12-14 15:37:23Z trueg $
+ * $Id: k3bprojectinterface.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,14 +48,14 @@ K3bProjectInterface::~K3bProjectInterface()
 {
 }
 
-void K3bProjectInterface::addUrls( const KURL::List& urls )
+void K3bProjectInterface::addUrls( const QStringList& urls )
 {
-  m_doc->addUrls( urls );
+  m_doc->addUrls( KURL::List(urls) );
 }
 
-void K3bProjectInterface::addUrl( const KURL& url )
+void K3bProjectInterface::addUrl( const QString& url )
 {
-  m_doc->addUrl( url );
+  m_doc->addUrl( KURL(url) );
 }
 
 void K3bProjectInterface::burn()
@@ -65,7 +65,7 @@ void K3bProjectInterface::burn()
 }
 
 
-void K3bProjectInterface::directBurn()
+bool K3bProjectInterface::directBurn()
 {
   if( m_doc->burner() ) {
     K3bJobProgressDialog* dlg = 0;
@@ -80,7 +80,11 @@ void K3bProjectInterface::directBurn()
     
     delete job;
     delete dlg;
+
+    return true;
   }
+  else
+    return false;
 }
 
 
