@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bstatusbarmanager.h 317459 2004-06-03 20:20:22Z trueg $
+ * $Id: k3bstatusbarmanager.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,10 +21,10 @@
 #include <qobject.h>
 
 class QLabel;
-class K3bBusyWidget;
 class K3bMainWindow;
 class QEvent;
-
+class K3bDoc;
+class QTimer;
 
 class K3bStatusBarManager : public QObject
 {
@@ -36,13 +36,13 @@ class K3bStatusBarManager : public QObject
 
  public slots:
   void update();
-  void showBusyInfo( const QString& );
-  void endBusy();
 
  private slots:
   void slotFreeTempSpace( const QString&, unsigned long, unsigned long, unsigned long );
   void showActionStatusText( const QString& text );
   void clearActionStatusText();
+  void slotActiveProjectChanged( K3bDoc* doc );
+  void slotUpdateProjectStats();
 
  private:
   bool eventFilter( QObject* o, QEvent* e );
@@ -51,9 +51,11 @@ class K3bStatusBarManager : public QObject
   QLabel* m_pixFreeTemp;
   QLabel* m_labelFreeTemp;
   QLabel* m_versionBox;
-  K3bBusyWidget* m_busyWidget;
+  QLabel* m_labelProjectInfo;
 
   K3bMainWindow* m_mainWindow;
+
+  QTimer* m_updateTimer;
 };
 
 #endif
