@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bwriterselectionwidget.h 619556 2007-01-03 17:38:12Z trueg $
+ * $Id: k3bwriterselectionwidget.h 690635 2007-07-21 16:47:29Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -101,6 +101,11 @@ class K3bWriterSelectionWidget : public QWidget
    */
   void setOverrideDevice( K3bDevice::Device* dev, const QString& overrideString = QString::null, const QString& tooltip = QString::null );
 
+  /**
+   * Compare K3bMediaSelectionComboBox::setIgnoreDevice
+   */
+  void setIgnoreDevice( K3bDevice::Device* dev );
+
  signals:
   void writerChanged();
   void writerChanged( K3bDevice::Device* );
