@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3bcdimagewritingdialog.cpp 442330 2005-08-02 10:39:06Z trueg $
+ * $Id: k3bcdimagewritingdialog.cpp 630454 2007-02-05 13:06:45Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,6 +13,7 @@
  * See the file "COPYING" for the exact licensing terms.
  */
 
+#include <config.h>
 
 #include "k3bcdimagewritingdialog.h"
 #include "k3biso9660imagewritingjob.h"
@@ -72,6 +73,8 @@
 #include <qspinbox.h>
 #include <qmap.h>
 #include <qptrqueue.h>
+#include <qpopupmenu.h>
+#include <qclipboard.h>
 
 
 class K3bCdImageWritingDialog::Private
@@ -79,6 +82,8 @@ class K3bCdImageWritingDialog::Private
 public:
   Private()
     : md5SumItem(0),
+      haveMd5Sum( false ),
+      foundImageType( IMAGE_UNKNOWN ),
       imageForced( false ) {
   }
 
@@ -86,6 +91,7 @@ public:
   QString lastCheckedFile;
 
   K3bMd5Job* md5Job;
+  bool haveMd5Sum;
 
   int foundImageType;
 
@@ -130,6 +136,8 @@ K3bCdImageWritingDialog::K3bCdImageWritingDialog( QWidget* parent, const char* n
 	   this, SLOT(slotToggleAll()) );
   connect( m_writerSelectionWidget, SIGNAL(writingAppChanged(int)),
 	   this, SLOT(slotToggleAll()) );
+  connect( m_writerSelectionWidget, SIGNAL(writerChanged(K3bDevice::Device*)), 
+	   m_writingModeWidget, SLOT(setDevice(K3bDevice::Device*)) );
   connect( m_comboImageType, SIGNAL(activated(int)),
 	   this, SLOT(slotToggleAll()) );
   connect( m_writingModeWidget, SIGNAL(writingModeChanged(int)),
@@ -138,13 +146,14 @@ K3bCdImageWritingDialog::K3bCdImageWritingDialog( QWidget* parent, const char* n
 	   this, SLOT(slotUpdateImage(const QString&)) );
   connect( m_checkDummy, SIGNAL(toggled(bool)),
 	   this, SLOT(slotToggleAll()) );
-  connect( m_checkOnTheFly, SIGNAL(toggled(bool)),
+  connect( m_checkCacheImage, SIGNAL(toggled(bool)),
 	   this, SLOT(slotToggleAll()) );
 }
 
 
 K3bCdImageWritingDialog::~K3bCdImageWritingDialog()
 {
+  d->md5Job->cancel();
   delete d;
 }
 
@@ -171,6 +180,7 @@ void K3bCdImageWritingDialog::setupGui()
   // -----------------------------------------------------------------------
   QGroupBox* groupImageUrl = new QGroupBox( 1, Qt::Horizontal, i18n("Image to Burn"), frame );
   m_editImagePath = new KURLRequester( groupImageUrl );
+  m_editImagePath->setMode( KFile::File|KFile::ExistingOnly );
   m_editImagePath->setCaption( i18n("Choose Image File") );
   m_editImagePath->setFilter( i18n("*.iso *.toc *.ISO *.TOC *.cue *.CUE|Image Files") 
 			      + "\n"
@@ -213,12 +223,15 @@ void K3bCdImageWritingDialog::setupGui()
   m_infoView->setAlternateBackground( QColor() );
   m_infoView->setFullWidth(true);
   m_infoView->setSelectionMode( QListView::NoSelection );
-  m_infoView->setDoubleClickForEdit( false ); // just for the md5 button
 
-  connect( m_infoView, SIGNAL(editorButtonClicked( K3bListViewItem*, int )),
-	   this, SLOT(slotMd5SumCompare()) );
+  connect( m_infoView, SIGNAL(contextMenu(KListView*, QListViewItem*, const QPoint&)),
+	   this, SLOT(slotContextMenu(KListView*, QListViewItem*, const QPoint&)) );
 
 
+  m_writerSelectionWidget = new K3bWriterSelectionWidget( frame );
+  m_writerSelectionWidget->setWantedMediumType( K3bDevice::MEDIA_WRITABLE_CD );
+  m_writerSelectionWidget->setWantedMediumState( K3bDevice::STATE_EMPTY );
+
   // options
   // -----------------------------------------------------------------------
   d->optionTabbed = new QTabWidget( frame );
@@ -229,8 +242,6 @@ void K3bCdImageWritingDialog::setupGui()
   optionTabLayout->setSpacing( spacingHint() );
   optionTabLayout->setMargin( marginHint() );
 
-  m_writerSelectionWidget = new K3bWriterSelectionWidget( false, optionTab );
-
   QGroupBox* writingModeGroup = new QGroupBox( 1, Vertical, i18n("Writing Mode"), optionTab );
   writingModeGroup->setInsideMargin( marginHint() );
   m_writingModeWidget = new K3bWritingModeWidget( writingModeGroup );
@@ -248,21 +259,20 @@ void K3bCdImageWritingDialog::setupGui()
   m_spinCopies->setMaxValue( 999 );
   // -------- copies
 
-  QGroupBox* optionGroup = new QGroupBox( 3, Vertical, i18n("Options"), optionTab );
+  QGroupBox* optionGroup = new QGroupBox( 3, Vertical, i18n("Settings"), optionTab );
   optionGroup->setInsideMargin( marginHint() );
   optionGroup->setInsideSpacing( spacingHint() );
   m_checkDummy = K3bStdGuiItems::simulateCheckbox( optionGroup );
-  m_checkOnTheFly = K3bStdGuiItems::onTheFlyCheckbox( optionGroup );
+  m_checkCacheImage = K3bStdGuiItems::createCacheImageCheckbox( optionGroup );
   m_checkVerify = K3bStdGuiItems::verifyCheckBox( optionGroup );
 
-  optionTabLayout->addMultiCellWidget( m_writerSelectionWidget, 0, 0, 0, 1 );
-  optionTabLayout->addWidget( writingModeGroup, 1, 0 );
-  optionTabLayout->addWidget( groupCopies, 2, 0 );
-  optionTabLayout->addMultiCellWidget( optionGroup, 1, 2, 1, 1 );
-  optionTabLayout->setRowStretch( 2, 1 );
+  optionTabLayout->addWidget( writingModeGroup, 0, 0 );
+  optionTabLayout->addWidget( groupCopies, 1, 0 );
+  optionTabLayout->addMultiCellWidget( optionGroup, 0, 1, 1, 1 );
+  optionTabLayout->setRowStretch( 1, 1 );
   optionTabLayout->setColStretch( 1, 1 );
 
-  d->optionTabbed->addTab( optionTab, i18n("Options") );
+  d->optionTabbed->addTab( optionTab, i18n("Settings") );
 
 
   // image tab ------------------------------------
@@ -310,7 +320,8 @@ void K3bCdImageWritingDialog::setupGui()
   grid->addWidget( groupImageUrl, 0, 0 );
   grid->addWidget( groupImageType, 0, 1 );
   grid->addMultiCellWidget( m_infoView, 1, 1, 0, 1 );
-  grid->addMultiCellWidget( d->optionTabbed, 2, 2, 0, 1 );
+  grid->addMultiCellWidget( m_writerSelectionWidget, 2, 2, 0, 1 );
+  grid->addMultiCellWidget( d->optionTabbed, 3, 3, 0, 1 );
 
   grid->setRowStretch( 1, 1 );
 }
@@ -365,7 +376,7 @@ void K3bCdImageWritingDialog::slotStartClicked()
       job_->setWritingMode( m_writingModeWidget->writingMode() );
       job_->setCueFile( d->tocFile );
       job_->setCopies( m_checkDummy->isChecked() ? 1 : m_spinCopies->value() );
-      job_->setOnTheFly( m_checkOnTheFly->isChecked() );
+      job_->setOnTheFly( !m_checkCacheImage->isChecked() );
       job_->setTempDir( m_tempDirSelectionWidget->tempPath() );
 
       job = job_;
@@ -382,7 +393,7 @@ void K3bCdImageWritingDialog::slotStartClicked()
       job_->setSpeed( m_writerSelectionWidget->writerSpeed() );
       job_->setTocFile( d->tocFile );
       job_->setSimulate(m_checkDummy->isChecked());
-      job_->setMulti(m_checkNoFix->isChecked());
+      job_->setMulti( false /*m_checkNoFix->isChecked()*/ );
       job_->setCopies( m_checkDummy->isChecked() ? 1 : m_spinCopies->value() );
       
       job = job_;
@@ -391,6 +402,20 @@ void K3bCdImageWritingDialog::slotStartClicked()
 
   case IMAGE_ISO:
     {
+      K3bIso9660 isoFs( d->imageFile );
+      if( isoFs.open() ) {
+	if( K3b::filesize( KURL::fromPathOrURL(d->imageFile) ) < (KIO::filesize_t)(isoFs.primaryDescriptor().volumeSpaceSize*2048) ) {
+	  if( KMessageBox::questionYesNo( this, 
+					  i18n("<p>This image has an invalid file size."
+					       "If it has been downloaded make sure the download is complete."
+					       "<p>Only continue if you know what you are doing."),
+					  i18n("Warning"),
+					  i18n("Continue"),
+					  i18n("Cancel") ) == KMessageBox::No )
+	    return;
+	}
+      }
+
       K3bIso9660ImageWritingJob* job_ = new K3bIso9660ImageWritingJob( &dlg );
       
       job_->setBurnDevice( m_writerSelectionWidget->writerDevice() );
@@ -415,13 +440,18 @@ void K3bCdImageWritingDialog::slotStartClicked()
   if( job ) {
     job->setWritingApp( m_writerSelectionWidget->writingApp() );
 
-    hide();
+    if( !exitLoopOnHide() )
+      hide();
     
     dlg.startJob(job);
     
-    show();
-
     delete job;
+
+    if( KConfigGroup( k3bcore->config(), "General Options" ).readBoolEntry( "keep action dialogs open", false ) &&
+	!exitLoopOnHide() )
+      show();
+    else
+      close();
   }
 }
 
@@ -432,6 +462,7 @@ void K3bCdImageWritingDialog::slotUpdateImage( const QString& )
 
   // check the image types
 
+  d->haveMd5Sum = false;
   d->md5Job->cancel();
   m_infoView->clear();
   m_infoView->header()->resizeSection( 0, 20 );
@@ -448,6 +479,10 @@ void K3bCdImageWritingDialog::slotUpdateImage( const QString& )
     // ------------------------------------------------
     K3bIso9660 isoF( path );
     if( isoF.open() ) {
+#ifdef K3B_DEBUG
+      isoF.debug();
+#endif
+
       createIso9660InfoItems( &isoF );
       isoF.close();
       calculateMd5Sum( path );
@@ -553,12 +588,14 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
   K3bListViewItem* isoRootItem = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 						      i18n("Detected:"),
 						      i18n("Iso9660 image") );
-  isoRootItem->setForegroundColor( 0, Qt::gray );
+  isoRootItem->setForegroundColor( 0, palette().disabled().foreground() );
   isoRootItem->setPixmap( 0, SmallIcon( "cdimage") );
 
+  KIO::filesize_t size = K3b::filesize( KURL::fromPathOrURL(isoF->fileName()) );
   K3bListViewItem* item = new K3bListViewItem( isoRootItem, m_infoView->lastItem(),
-					       i18n("Filesize:"), KIO::convertSize( K3b::filesize(KURL::fromPathOrURL(isoF->fileName())) ) );
-  item->setForegroundColor( 0, Qt::gray );
+					       i18n("Filesize:"), 
+					       KIO::convertSize( size ) );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
@@ -566,7 +603,7 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 			      isoF->primaryDescriptor().systemId.isEmpty()
 			      ? QString("-") 
 			      : isoF->primaryDescriptor().systemId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
@@ -574,7 +611,7 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 			      isoF->primaryDescriptor().volumeId.isEmpty() 
 			      ? QString("-") 
 			      : isoF->primaryDescriptor().volumeId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
@@ -582,7 +619,7 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 			      isoF->primaryDescriptor().volumeSetId.isEmpty()
 			      ? QString("-")
 			      : isoF->primaryDescriptor().volumeSetId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
@@ -590,14 +627,14 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 			      isoF->primaryDescriptor().publisherId.isEmpty() 
 			      ? QString("-") 
 			      : isoF->primaryDescriptor().publisherId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
 			      i18n("Preparer Id:"), 
 			      isoF->primaryDescriptor().preparerId.isEmpty() 
 			      ? QString("-") : isoF->primaryDescriptor().preparerId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
@@ -605,7 +642,7 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 			      isoF->primaryDescriptor().applicationId.isEmpty()
 			      ? QString("-") 
 			      : isoF->primaryDescriptor().applicationId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   isoRootItem->setOpen( true );
 }
@@ -616,24 +653,24 @@ void K3bCdImageWritingDialog::createCdrecordCloneItems( const QString& tocFile,
   K3bListViewItem* isoRootItem = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 						      i18n("Detected:"),
 						      i18n("Cdrecord clone image") );
-  isoRootItem->setForegroundColor( 0, Qt::gray );
+  isoRootItem->setForegroundColor( 0, palette().disabled().foreground() );
   isoRootItem->setPixmap( 0, SmallIcon( "cdimage") );
 
   K3bListViewItem* item = new K3bListViewItem( isoRootItem, m_infoView->lastItem(),
 					       i18n("Filesize:"), KIO::convertSize( K3b::filesize(KURL::fromPathOrURL(imageFile)) ) );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
 			      i18n("Image file:"), 
 			      imageFile );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
 			      i18n("TOC file:"), 
 			      tocFile );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   isoRootItem->setOpen( true );
 }
@@ -644,24 +681,24 @@ void K3bCdImageWritingDialog::createCueBinItems( const QString& cueFile, const Q
   K3bListViewItem* isoRootItem = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 						      i18n("Detected:"),
 						      i18n("Cue/bin image") );
-  isoRootItem->setForegroundColor( 0, Qt::gray );
+  isoRootItem->setForegroundColor( 0, palette().disabled().foreground() );
   isoRootItem->setPixmap( 0, SmallIcon( "cdimage") );
 
   K3bListViewItem* item = new K3bListViewItem( isoRootItem, m_infoView->lastItem(),
 					       i18n("Filesize:"), KIO::convertSize( K3b::filesize(KURL::fromPathOrURL(imageFile)) ) );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
 			      i18n("Image file:"), 
 			      imageFile );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
 			      i18n("Cue file:"), 
 			      cueFile );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   isoRootItem->setOpen( true );
 }
@@ -672,7 +709,7 @@ void K3bCdImageWritingDialog::createAudioCueItems( const K3bCueFileParser& cp )
   K3bListViewItem* rootItem = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 						   i18n("Detected:"),
 						   i18n("Audio Cue Image") );
-  rootItem->setForegroundColor( 0, Qt::gray );
+  rootItem->setForegroundColor( 0, palette().disabled().foreground() );
   rootItem->setPixmap( 0, SmallIcon( "sound") );
 
   K3bListViewItem* trackParent = new K3bListViewItem( rootItem,
@@ -685,7 +722,7 @@ void K3bCdImageWritingDialog::createAudioCueItems( const K3bCueFileParser& cp )
 			  .arg(cp.cdText().performer())
 			  .arg(cp.cdText().title()) );
 
-  int i = 1;
+  unsigned int i = 1;
   for( K3bDevice::Toc::const_iterator it = cp.toc().begin();
        it != cp.toc().end(); ++it ) {
 
@@ -711,63 +748,56 @@ void K3bCdImageWritingDialog::createAudioCueItems( const K3bCueFileParser& cp )
 }
 
 
-void K3bCdImageWritingDialog::slotToggleAll()
+void K3bCdImageWritingDialog::toggleAll()
 {
-  kdDebug() << "(K3bCdImageWritingDialog) slotToggleAll() " << endl;
-
-  if (m_writerSelectionWidget->writerDevice()) {
-
-    // enable the Write-Button if we found a valid image or the user forced an image type
-    m_buttonStart->setEnabled( currentImageType() != IMAGE_UNKNOWN 
-			       && QFile::exists( imagePath() ) );
-
-    // cdrecord clone and cue both need DAO
-    if( m_writerSelectionWidget->writingApp() != K3b::CDRDAO 
-	&& ( currentImageType() == IMAGE_ISO ||
-	     currentImageType() == IMAGE_AUDIO_CUE ) )
-      m_writingModeWidget->setSupportedModes( K3b::TAO|K3b::DAO|K3b::RAW ); // stuff supported by cdrecord
+  // enable the Write-Button if we found a valid image or the user forced an image type
+  setButtonEnabled( START_BUTTON, m_writerSelectionWidget->writerDevice() 
+		    && currentImageType() != IMAGE_UNKNOWN 
+		    && QFile::exists( imagePath() ) );
+  
+  // cdrecord clone and cue both need DAO
+  if( m_writerSelectionWidget->writingApp() != K3b::CDRDAO 
+      && ( currentImageType() == IMAGE_ISO ||
+	   currentImageType() == IMAGE_AUDIO_CUE ) )
+    m_writingModeWidget->setSupportedModes( K3b::TAO|K3b::DAO|K3b::RAW ); // stuff supported by cdrecord
+  else
+    m_writingModeWidget->setSupportedModes( K3b::DAO );
+  
+  // some stuff is only available for iso images
+  if( currentImageType() == IMAGE_ISO ) {
+    m_checkVerify->show();
+    if( !d->advancedTabVisible )
+      d->optionTabbed->addTab( d->advancedTab, i18n("Advanced") );
+    d->advancedTabVisible = true;
+    if( m_checkDummy->isChecked() ) {
+      m_checkVerify->setEnabled( false );
+      m_checkVerify->setChecked( false );
+    }
     else
-      m_writingModeWidget->setSupportedModes( K3b::DAO );
-
-    // some stuff is only available for iso images
-    if( currentImageType() == IMAGE_ISO ) {
-      m_checkVerify->show();
-      if( !d->advancedTabVisible )
-	d->optionTabbed->addTab( d->advancedTab, i18n("Advanced") );
-      d->advancedTabVisible = true;
-      if( m_checkDummy->isChecked() ) {
-	m_checkVerify->setEnabled( false );
-	m_checkVerify->setChecked( false );
-      }
-      else
-	m_checkVerify->setEnabled( true );	
-    }
-    else {
-      if( d->advancedTabVisible )
-	d->optionTabbed->removePage( d->advancedTab );
-      d->advancedTabVisible = false;
-      m_checkVerify->hide();
-    }
-
-    // and some other stuff only makes sense for audio cues
-    if( currentImageType() == IMAGE_AUDIO_CUE ) {
-      if( !d->tempPathTabVisible )
-	d->optionTabbed->addTab( d->tempPathTab, i18n("&Image") );
-      d->tempPathTabVisible = true;
-      m_tempDirSelectionWidget->setDisabled( m_checkOnTheFly->isChecked() );
-    }
-    else {
-      if( d->tempPathTabVisible )
-	d->optionTabbed->removePage( d->tempPathTab );
-      d->tempPathTabVisible = false;
-    }
-    m_checkOnTheFly->setShown( currentImageType() == IMAGE_AUDIO_CUE );
-
-    m_spinCopies->setEnabled( !m_checkDummy->isChecked() );
+      m_checkVerify->setEnabled( true );	
   }
   else {
-    m_buttonStart->setEnabled( false );
+    if( d->advancedTabVisible )
+      d->optionTabbed->removePage( d->advancedTab );
+    d->advancedTabVisible = false;
+    m_checkVerify->hide();
   }
+  
+  // and some other stuff only makes sense for audio cues
+  if( currentImageType() == IMAGE_AUDIO_CUE ) {
+    if( !d->tempPathTabVisible )
+      d->optionTabbed->addTab( d->tempPathTab, i18n("&Image") );
+    d->tempPathTabVisible = true;
+    m_tempDirSelectionWidget->setDisabled( !m_checkCacheImage->isChecked() );
+  }
+  else {
+    if( d->tempPathTabVisible )
+      d->optionTabbed->removePage( d->tempPathTab );
+    d->tempPathTabVisible = false;
+  }
+  m_checkCacheImage->setShown( currentImageType() == IMAGE_AUDIO_CUE );
+  
+  m_spinCopies->setEnabled( !m_checkDummy->isChecked() );
 
   switch( currentImageType() ) {
   case IMAGE_CDRDAO_TOC:
@@ -793,20 +823,25 @@ void K3bCdImageWritingDialog::slotToggleAll()
 void K3bCdImageWritingDialog::setImage( const KURL& url )
 {
   d->imageForced = true;
+#if KDE_IS_VERSION(3,4,0)
+  m_editImagePath->setKURL( url );
+#else
   m_editImagePath->setURL( url.path() );
+#endif
 }
 
 
 void K3bCdImageWritingDialog::calculateMd5Sum( const QString& file )
 {
+  d->haveMd5Sum = false;
+
   if( !d->md5SumItem )
     d->md5SumItem = new K3bListViewItem( m_infoView, m_infoView->firstChild() );
 
   d->md5SumItem->setText( 0, i18n("Md5 Sum:") );
-  d->md5SumItem->setForegroundColor( 0, Qt::gray );
+  d->md5SumItem->setForegroundColor( 0, palette().disabled().foreground() );
   d->md5SumItem->setProgress( 1, 0 );
   d->md5SumItem->setPixmap( 0, SmallIcon( "exec") );
-  d->md5SumItem->setButton( 1, false );
 
   if( file != d->lastCheckedFile ) {
     d->lastCheckedFile = file;
@@ -827,36 +862,52 @@ void K3bCdImageWritingDialog::slotMd5JobPercent( int p )
 void K3bCdImageWritingDialog::slotMd5JobFinished( bool success )
 {
   if( success ) {
-    d->md5SumItem->setPixmap( 0, SmallIcon( "ok") );
     d->md5SumItem->setText( 1, d->md5Job->hexDigest() );
+    d->haveMd5Sum = true;
   }
   else {
     d->md5SumItem->setForegroundColor( 1, Qt::red );
-    d->md5SumItem->setText( 1, i18n("Calculation failed") );
+    if( d->md5Job->hasBeenCanceled() )
+      d->md5SumItem->setText( 1, i18n("Calculation cancelled") );
+    else
+      d->md5SumItem->setText( 1, i18n("Calculation failed") );
     d->md5SumItem->setPixmap( 0, SmallIcon( "stop") );
-    d->lastCheckedFile = "";
+    d->lastCheckedFile.truncate(0);
   }
 
-  d->md5SumItem->setButton( 1, success );
   d->md5SumItem->setDisplayProgressBar( 1, false );
 }
 
 
-void K3bCdImageWritingDialog::slotMd5SumCompare()
+void K3bCdImageWritingDialog::slotContextMenu( KListView*, QListViewItem*, const QPoint& pos )
 {
-  bool ok;
-  QString md5sumToCompare = KInputDialog::getText( i18n("MD5 Sum Check"),
-						   i18n("Please insert the MD5 Sum to compare:"),
-						   QString::null,
-						   &ok,
-						   this );
-  if( ok ) {
-    if( md5sumToCompare.utf8() == d->md5Job->hexDigest() )
-      KMessageBox::information( this, i18n("The MD5 Sum of %1 equals the specified.").arg(imagePath()),
-				i18n("MD5 Sums Equal") );
-    else
-      KMessageBox::sorry( this, i18n("The MD5 Sum of %1 differs from the specified.").arg(imagePath()),
-			  i18n("MD5 Sums Differ") );
+  if( !d->haveMd5Sum )
+    return;
+
+  QPopupMenu popup;
+  int copyItem = popup.insertItem( i18n("Copy checksum to clipboard") );
+  int compareItem = popup.insertItem( i18n("Compare checksum...") );
+
+  int r = popup.exec( pos );
+
+  if( r == compareItem ) {
+    bool ok;
+    QString md5sumToCompare = KInputDialog::getText( i18n("MD5 Sum Check"),
+						     i18n("Please insert the MD5 Sum to compare:"),
+						     QString::null,
+						     &ok,
+						     this );
+    if( ok ) {
+      if( md5sumToCompare.lower().utf8() == d->md5Job->hexDigest().lower() )
+	KMessageBox::information( this, i18n("The MD5 Sum of %1 equals the specified.").arg(imagePath()),
+				  i18n("MD5 Sums Equal") );
+      else
+	KMessageBox::sorry( this, i18n("The MD5 Sum of %1 differs from the specified.").arg(imagePath()),
+			    i18n("MD5 Sums Differ") );
+    }
+  }
+  else if( r == copyItem ) {
+    QApplication::clipboard()->setText( d->md5Job->hexDigest().lower(), QClipboard::Clipboard );
   }
 }
 
@@ -866,9 +917,11 @@ void K3bCdImageWritingDialog::loadUserDefaults( KConfigBase* c )
   m_writingModeWidget->loadConfig( c );
   m_checkDummy->setChecked( c->readBoolEntry("simulate", false ) );
   m_checkNoFix->setChecked( c->readBoolEntry("multisession", false ) );
-  m_checkOnTheFly->setChecked( c->readBoolEntry("on_the_fly", true ) );
+  m_checkCacheImage->setChecked( !c->readBoolEntry("on_the_fly", true ) );
 
   m_dataModeWidget->loadConfig(c);
+
+  m_spinCopies->setValue( c->readNumEntry( "copies", 1 ) );
  
   m_checkVerify->setChecked( c->readBoolEntry( "verify_data", false ) );
 
@@ -906,7 +959,7 @@ void K3bCdImageWritingDialog::saveUserDefaults( KConfigBase* c )
   m_writingModeWidget->saveConfig( c ),
   c->writeEntry( "simulate", m_checkDummy->isChecked() );
   c->writeEntry( "multisession", m_checkNoFix->isChecked() );
-  c->writeEntry( "on_the_fly", m_checkOnTheFly->isChecked() );
+  c->writeEntry( "on_the_fly", !m_checkCacheImage->isChecked() );
   m_dataModeWidget->saveConfig(c);
   
   c->writeEntry( "verify_data", m_checkVerify->isChecked() );
@@ -915,6 +968,8 @@ void K3bCdImageWritingDialog::saveUserDefaults( KConfigBase* c )
 
   c->writePathEntry( "image path", imagePath() );
 
+  c->writeEntry( "copies", m_spinCopies->value() );
+
   QString imageType;
   if( m_comboImageType->currentItem() == 0 )
     imageType = "auto";
@@ -950,9 +1005,10 @@ void K3bCdImageWritingDialog::loadK3bDefaults()
   m_checkDummy->setChecked( false );
   m_checkVerify->setChecked( false );
   m_checkNoFix->setChecked( false );
-  m_checkOnTheFly->setChecked( true );
+  m_checkCacheImage->setChecked( false );
   m_dataModeWidget->setDataMode( K3b::DATA_MODE_AUTO );
   m_comboImageType->setCurrentItem(0);
+  m_spinCopies->setValue( 1 );
 
   slotToggleAll();
 }
@@ -969,7 +1025,7 @@ int K3bCdImageWritingDialog::currentImageType()
 
 QString K3bCdImageWritingDialog::imagePath() const
 {
-  return KURL::fromPathOrURL( m_editImagePath->url() ).path();
+  return K3b::convertToLocalUrl( KURL::fromPathOrURL( m_editImagePath->url() ) ).path();
 }
 
 
@@ -983,7 +1039,11 @@ void K3bCdImageWritingDialog::dropEvent( QDropEvent* e )
 {
   KURL::List urls;
   KURLDrag::decode( e, urls );
+#if KDE_IS_VERSION(3,4,0)
+  m_editImagePath->setKURL( urls.first() );
+#else
   m_editImagePath->setURL( urls.first().path() );
+#endif
 }
 
 #include "k3bcdimagewritingdialog.moc"
