@@ -4,7 +4,7 @@
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@
 #include <k3bcore.h>
 #include <k3blistview.h>
 #include <k3biso9660.h>
+#include <k3bapplication.h>
+#include <k3bmediacache.h>
 
 #include <kapplication.h>
 #include <klocale.h>
@@ -59,6 +61,8 @@
 #include <qwhatsthis.h>
 #include <qspinbox.h>
 #include <qevent.h>
+#include <qpopupmenu.h>
+#include <qclipboard.h>
 
 
 class K3bIsoImageWritingDialog::Private
@@ -66,10 +70,12 @@ class K3bIsoImageWritingDialog::Private
 public:
   Private()
     : md5SumItem(0),
+      haveMd5Sum( false ),
       imageForced( false ) {
   }
 
   K3bListViewItem* md5SumItem;
+  bool haveMd5Sum;
   QString lastCheckedFile;
   bool isIsoImage;
 
@@ -78,8 +84,8 @@ public:
 
 
 K3bIsoImageWritingDialog::K3bIsoImageWritingDialog( QWidget* parent, const char* name, bool modal )
-  : K3bInteractionDialog( parent, name, 
-			  i18n("Burn Iso9660 Image"), 
+  : K3bInteractionDialog( parent, name,
+			  i18n("Burn Iso9660 Image"),
 			  i18n("to DVD"),
 			  START_BUTTON|CANCEL_BUTTON,
 			  START_BUTTON,
@@ -91,6 +97,8 @@ K3bIsoImageWritingDialog::K3bIsoImageWritingDialog( QWidget* parent, const char*
   setAcceptDrops(true);
   setupGui();
 
+  m_writerSelectionWidget->setWantedMediumType( K3bDevice::MEDIA_WRITABLE_DVD );
+  m_writerSelectionWidget->setWantedMediumState( K3bDevice::STATE_EMPTY );
   m_writerSelectionWidget->setSupportedWritingApps( K3b::GROWISOFS );
   m_writingModeWidget->setSupportedModes( K3b::DAO|K3b::WRITING_MODE_INCR_SEQ|K3b::WRITING_MODE_RES_OVWR );
 
@@ -108,7 +116,7 @@ K3bIsoImageWritingDialog::K3bIsoImageWritingDialog( QWidget* parent, const char*
 	   this, SLOT(slotWriterChanged()) );
   connect( m_writingModeWidget, SIGNAL(writingModeChanged(int)),
 	   this, SLOT(slotWriterChanged()) );
-  connect( m_editImagePath, SIGNAL(textChanged(const QString&)), 
+  connect( m_editImagePath, SIGNAL(textChanged(const QString&)),
 	   this, SLOT(updateImageSize(const QString&)) );
   connect( m_checkDummy, SIGNAL(toggled(bool)),
 	   this, SLOT(slotWriterChanged()) );
@@ -124,7 +132,7 @@ K3bIsoImageWritingDialog::~K3bIsoImageWritingDialog()
 void K3bIsoImageWritingDialog::init()
 {
   if( !d->imageForced ) {
-    // when opening the dialog first the default settings are loaded and afterwards we set the 
+    // when opening the dialog first the default settings are loaded and afterwards we set the
     // last written image because that's what most users want
     KConfig* c = k3bcore->config();
     c->setGroup( configGroup() );
@@ -149,6 +157,7 @@ void K3bIsoImageWritingDialog::setupGui()
 			      + i18n("*|All Files") );
 
   connect( m_editImagePath->lineEdit(), SIGNAL( textChanged ( const QString & ) ), this,  SLOT( slotWriterChanged() ) );
+
   // image info
   // -----------------------------------------------------------------------
   m_infoView = new K3bListView( frame );
@@ -160,11 +169,11 @@ void K3bIsoImageWritingDialog::setupGui()
   m_infoView->setAlternateBackground( QColor() );
   m_infoView->setFullWidth(true);
   m_infoView->setSelectionMode( QListView::NoSelection );
-  m_infoView->setDoubleClickForEdit( false ); // just for the md5 button
 
-  connect( m_infoView, SIGNAL(editorButtonClicked( K3bListViewItem*, int )),
-	   this, SLOT(slotMd5SumCompare()) );
+  connect( m_infoView, SIGNAL(contextMenu(KListView*, QListViewItem*, const QPoint&)),
+	   this, SLOT(slotContextMenu(KListView*, QListViewItem*, const QPoint&)) );
 
+  m_writerSelectionWidget = new K3bWriterSelectionWidget( frame );
 
   // options
   // -----------------------------------------------------------------------
@@ -176,8 +185,6 @@ void K3bIsoImageWritingDialog::setupGui()
   optionTabLayout->setSpacing( spacingHint() );
   optionTabLayout->setMargin( marginHint() );
 
-  m_writerSelectionWidget = new K3bWriterSelectionWidget( true, optionTab );
-
   QGroupBox* writingModeGroup = new QGroupBox( 1, Vertical, i18n("Writing Mode"), optionTab );
   writingModeGroup->setInsideMargin( marginHint() );
   m_writingModeWidget = new K3bWritingModeWidget( writingModeGroup );
@@ -195,21 +202,20 @@ void K3bIsoImageWritingDialog::setupGui()
   m_spinCopies->setMaxValue( 999 );
   // -------- copies
 
-  QGroupBox* optionGroup = new QGroupBox( 3, Vertical, i18n("Options"), optionTab );
+  QGroupBox* optionGroup = new QGroupBox( 3, Vertical, i18n("Settings"), optionTab );
   optionGroup->setInsideMargin( marginHint() );
   optionGroup->setInsideSpacing( spacingHint() );
   m_checkDummy = K3bStdGuiItems::simulateCheckbox( optionGroup );
   m_checkVerify = K3bStdGuiItems::verifyCheckBox( optionGroup );
 
 
-  optionTabLayout->addMultiCellWidget( m_writerSelectionWidget, 0, 0, 0, 1 );
-  optionTabLayout->addWidget( writingModeGroup, 1, 0 );
-  optionTabLayout->addWidget( groupCopies, 2, 0 );
-  optionTabLayout->addMultiCellWidget( optionGroup, 1, 2, 1, 1 );
-  optionTabLayout->setRowStretch( 2, 1 );
+  optionTabLayout->addWidget( writingModeGroup, 0, 0 );
+  optionTabLayout->addWidget( groupCopies, 1, 0 );
+  optionTabLayout->addMultiCellWidget( optionGroup, 0, 1, 1, 1 );
+  optionTabLayout->setRowStretch( 1, 1 );
   optionTabLayout->setColStretch( 1, 1 );
 
-  optionTabbed->addTab( optionTab, i18n("Options") );
+  optionTabbed->addTab( optionTab, i18n("Settings") );
 
 
   QGridLayout* grid = new QGridLayout( frame );
@@ -218,7 +224,8 @@ void K3bIsoImageWritingDialog::setupGui()
 
   grid->addWidget( groupImageUrl, 0, 0 );
   grid->addWidget( m_infoView, 1, 0 );
-  grid->addWidget( optionTabbed, 2, 0 );
+  grid->addWidget( m_writerSelectionWidget, 2, 0 );
+  grid->addWidget( optionTabbed, 3, 0 );
 
   grid->setRowStretch( 1, 1 );
 }
@@ -227,14 +234,28 @@ void K3bIsoImageWritingDialog::setupGui()
 void K3bIsoImageWritingDialog::slotStartClicked()
 {
   if( !d->isIsoImage ) {
-    if( KMessageBox::warningYesNo( this,
+    if( KMessageBox::warningContinueCancel( this,
 				   i18n("The image you selected is not a valid ISO9660 image. "
 					"Are you sure you want to burn it anyway? "
-					"(There are other valid image types that are not detected by K3b but "
-					"will work fine.)") ) == KMessageBox::No )
+					"(There may exist other valid image types that are not detected by K3b but "
+					"will work fine.)"), i18n("Burn") ) == KMessageBox::Cancel )
       return;
   }
 
+  K3bIso9660 isoFs( imagePath() );
+  if( isoFs.open() ) {
+    if( K3b::imageFilesize( KURL::fromPathOrURL( imagePath() ) ) < (KIO::filesize_t)(isoFs.primaryDescriptor().volumeSpaceSize*2048) ) {
+      if( KMessageBox::questionYesNo( this, 
+				      i18n("<p>This image has an invalid file size."
+					   "If it has been downloaded make sure the download is complete."
+					   "<p>Only continue if you know what you are doing."),
+				      i18n("Warning"),
+				      i18n("Continue"),
+				      i18n("Cancel") ) == KMessageBox::No )
+	return;
+    }
+  }
+
   m_md5Job->cancel();
 
   // save the path
@@ -260,13 +281,18 @@ void K3bIsoImageWritingDialog::slotStartClicked()
   // HACK (needed since if the medium is forced the stupid K3bIso9660ImageWritingJob defaults to cd writing)
   job->setWritingApp( K3b::GROWISOFS );
 
-  hide();
+  if( !exitLoopOnHide() )
+    hide();
 
   dlg.startJob( job );
 
   delete job;
 
-  show();
+  if( KConfigGroup( k3bcore->config(), "General Options" ).readBoolEntry( "keep action dialogs open", false ) &&
+      !exitLoopOnHide() )
+    show();
+  else
+    close();
 }
 
 
@@ -275,7 +301,7 @@ void K3bIsoImageWritingDialog::updateImageSize( const QString& path )
   m_md5Job->cancel();
   m_infoView->clear();
   d->md5SumItem = 0;
-
+  d->haveMd5Sum = false;
   d->isIsoImage = false;
 
   QFileInfo info( path );
@@ -300,50 +326,50 @@ void K3bIsoImageWritingDialog::updateImageSize( const QString& path )
 						   i18n("Filesize:"), KIO::convertSize( imageSize ) );
       item->setForegroundColor( 0, palette().disabled().foreground() );
 
-      item = new K3bListViewItem( isoRootItem, 
+      item = new K3bListViewItem( isoRootItem,
 				  m_infoView->lastItem(),
-				  i18n("System Id:"), 
+				  i18n("System Id:"),
 				  isoF.primaryDescriptor().systemId.isEmpty()
-				  ? QString("-") 
+				  ? QString("-")
 				  : isoF.primaryDescriptor().systemId );
       item->setForegroundColor( 0, palette().disabled().foreground() );
 
-      item = new K3bListViewItem( isoRootItem, 
+      item = new K3bListViewItem( isoRootItem,
 				  m_infoView->lastItem(),
-				  i18n("Volume Id:"), 
-				  isoF.primaryDescriptor().volumeId.isEmpty() 
-				  ? QString("-") 
+				  i18n("Volume Id:"),
+				  isoF.primaryDescriptor().volumeId.isEmpty()
+				  ? QString("-")
 				  : isoF.primaryDescriptor().volumeId );
       item->setForegroundColor( 0, palette().disabled().foreground() );
 
-      item = new K3bListViewItem( isoRootItem, 
+      item = new K3bListViewItem( isoRootItem,
 				  m_infoView->lastItem(),
-				  i18n("Volume Set Id:"), 
+				  i18n("Volume Set Id:"),
 				  isoF.primaryDescriptor().volumeSetId.isEmpty()
 				  ? QString("-")
 				  : isoF.primaryDescriptor().volumeSetId );
       item->setForegroundColor( 0, palette().disabled().foreground() );
 
-      item = new K3bListViewItem( isoRootItem, 
+      item = new K3bListViewItem( isoRootItem,
 				  m_infoView->lastItem(),
-				  i18n("Publisher Id:"), 
-				  isoF.primaryDescriptor().publisherId.isEmpty() 
-				  ? QString("-") 
+				  i18n("Publisher Id:"),
+				  isoF.primaryDescriptor().publisherId.isEmpty()
+				  ? QString("-")
 				  : isoF.primaryDescriptor().publisherId );
       item->setForegroundColor( 0, palette().disabled().foreground() );
 
-      item = new K3bListViewItem( isoRootItem, 
+      item = new K3bListViewItem( isoRootItem,
 				  m_infoView->lastItem(),
-				  i18n("Preparer Id:"), 
-				  isoF.primaryDescriptor().preparerId.isEmpty() 
+				  i18n("Preparer Id:"),
+				  isoF.primaryDescriptor().preparerId.isEmpty()
 				  ? QString("-") : isoF.primaryDescriptor().preparerId );
       item->setForegroundColor( 0, palette().disabled().foreground() );
 
-      item = new K3bListViewItem( isoRootItem, 
+      item = new K3bListViewItem( isoRootItem,
 				  m_infoView->lastItem(),
-				  i18n("Application Id:"), 
+				  i18n("Application Id:"),
 				  isoF.primaryDescriptor().applicationId.isEmpty()
-				  ? QString("-") 
+				  ? QString("-")
 				  : isoF.primaryDescriptor().applicationId );
       item->setForegroundColor( 0, palette().disabled().foreground() );
 
@@ -367,8 +393,19 @@ void K3bIsoImageWritingDialog::updateImageSize( const QString& path )
 
 void K3bIsoImageWritingDialog::slotWriterChanged()
 {
-  if( m_writerSelectionWidget->writerDevice() && !m_editImagePath->lineEdit()->text().isEmpty() ) {
-    m_buttonStart->setEnabled( true );
+  K3bDevice::Device* dev = m_writerSelectionWidget->writerDevice();
+  if( dev ) {
+    K3bMedium medium = k3bappcore->mediaCache()->medium( dev );
+    if( medium.diskInfo().mediaType() & K3bDevice::MEDIA_DVD_PLUS_ALL ) {
+      // no simulation support for DVD+R(W) media
+      m_checkDummy->setChecked(false);
+      m_checkDummy->setEnabled(false);
+    }
+    else {
+      m_checkDummy->setDisabled( false );
+    }
+
+    m_writingModeWidget->determineSupportedModesFromMedium( dev );
 
     if( m_checkDummy->isChecked() ) {
       m_checkVerify->setEnabled( false );
@@ -376,23 +413,30 @@ void K3bIsoImageWritingDialog::slotWriterChanged()
     }
     else
       m_checkVerify->setEnabled( true );
+
     m_spinCopies->setEnabled( !m_checkDummy->isChecked() );
   }
-  else {
-    m_buttonStart->setEnabled( false );
-  }
+
+  setButtonEnabled( START_BUTTON, 
+		    dev && !m_editImagePath->lineEdit()->text().isEmpty() );
 }
 
 
 void K3bIsoImageWritingDialog::setImage( const KURL& url )
 {
   d->imageForced = true;
+#if KDE_IS_VERSION(3,4,0)
+  m_editImagePath->setKURL( url );
+#else
   m_editImagePath->setURL( url.path() );
+#endif
 }
 
 
 void K3bIsoImageWritingDialog::calculateMd5Sum( const QString& file )
 {
+  d->haveMd5Sum = false;
+
   if( !d->md5SumItem )
     d->md5SumItem = new K3bListViewItem( m_infoView, m_infoView->firstChild() );
 
@@ -400,7 +444,6 @@ void K3bIsoImageWritingDialog::calculateMd5Sum( const QString& file )
   d->md5SumItem->setForegroundColor( 0, palette().disabled().foreground() );
   d->md5SumItem->setProgress( 1, 0 );
   d->md5SumItem->setPixmap( 0, SmallIcon( "exec") );
-  d->md5SumItem->setButton( 1, false );
 
   if( file != d->lastCheckedFile ) {
     d->lastCheckedFile = file;
@@ -422,34 +465,51 @@ void K3bIsoImageWritingDialog::slotMd5JobFinished( bool success )
 {
   if( success ) {
     d->md5SumItem->setText( 1, m_md5Job->hexDigest() );
+    d->haveMd5Sum = true;
   }
   else {
     d->md5SumItem->setForegroundColor( 1, Qt::red );
-    d->md5SumItem->setText( 1, i18n("Calculation failed") );
+    if( m_md5Job->hasBeenCanceled() )
+      d->md5SumItem->setText( 1, i18n("Calculation cancelled") );
+    else
+      d->md5SumItem->setText( 1, i18n("Calculation failed") );
     d->md5SumItem->setPixmap( 0, SmallIcon( "stop") );
-    d->lastCheckedFile = "";
+    d->lastCheckedFile.truncate(0);
   }
 
-  d->md5SumItem->setButton( 1, success );
   d->md5SumItem->setDisplayProgressBar( 1, false );
 }
 
 
-void K3bIsoImageWritingDialog::slotMd5SumCompare()
+void K3bIsoImageWritingDialog::slotContextMenu( KListView*, QListViewItem*, const QPoint& pos )
 {
-  bool ok;
-  QString md5sumToCompare = KInputDialog::getText( i18n("MD5 Sum Check"),
-						   i18n("Please insert the MD5 Sum to compare:"),
-						   QString::null,
-						   &ok,
-						   this );
-  if( ok ) {
-    if( md5sumToCompare.lower().utf8() == m_md5Job->hexDigest().lower() )
-      KMessageBox::information( this, i18n("The MD5 Sum of %1 equals the specified.").arg(imagePath()),
-				i18n("MD5 Sums Equal") );
-    else
-      KMessageBox::sorry( this, i18n("The MD5 Sum of %1 differs from the specified.").arg(imagePath()),
-			  i18n("MD5 Sums Differ") );
+  if( !d->haveMd5Sum )
+    return;
+
+  QPopupMenu popup;
+  int copyItem = popup.insertItem( i18n("Copy checksum to clipboard") );
+  int compareItem = popup.insertItem( i18n("Compare checksum...") );
+
+  int r = popup.exec( pos );
+
+  if( r == compareItem ) {
+    bool ok;
+    QString md5sumToCompare = KInputDialog::getText( i18n("MD5 Sum Check"),
+						     i18n("Please insert the MD5 Sum to compare:"),
+						     QString::null,
+						     &ok,
+						     this );
+    if( ok ) {
+      if( md5sumToCompare.lower().utf8() == m_md5Job->hexDigest().lower() )
+	KMessageBox::information( this, i18n("The MD5 Sum of %1 equals the specified.").arg(imagePath()),
+				  i18n("MD5 Sums Equal") );
+      else
+	KMessageBox::sorry( this, i18n("The MD5 Sum of %1 differs from the specified.").arg(imagePath()),
+			    i18n("MD5 Sums Differ") );
+    }
+  }
+  else if( r == copyItem ) {
+    QApplication::clipboard()->setText( m_md5Job->hexDigest().lower(), QClipboard::Clipboard );
   }
 }
 
@@ -459,6 +519,7 @@ void K3bIsoImageWritingDialog::loadUserDefaults( KConfigBase* c )
   m_writingModeWidget->loadConfig( c );
   m_checkDummy->setChecked( c->readBoolEntry("simulate", false ) );
   m_checkVerify->setChecked( c->readBoolEntry( "verify_data", false ) );
+  m_spinCopies->setValue( c->readNumEntry( "copies", 1 ) );
 
   m_writerSelectionWidget->loadConfig( c );
 
@@ -475,6 +536,7 @@ void K3bIsoImageWritingDialog::saveUserDefaults( KConfigBase* c )
   m_writingModeWidget->saveConfig( c ),
   c->writeEntry( "simulate", m_checkDummy->isChecked() );
   c->writeEntry( "verify_data", m_checkVerify->isChecked() );
+  c->writeEntry( "copies", m_spinCopies->value() );
 
   m_writerSelectionWidget->saveConfig( c );
 
@@ -488,6 +550,7 @@ void K3bIsoImageWritingDialog::loadK3bDefaults()
   m_writingModeWidget->setWritingMode( K3b::WRITING_MODE_AUTO );
   m_checkDummy->setChecked( false );
   m_checkVerify->setChecked( false );
+  m_spinCopies->setValue( 1 );
 }
 
 
@@ -507,7 +570,11 @@ void K3bIsoImageWritingDialog::dropEvent( QDropEvent* e )
 {
   KURL::List urls;
   KURLDrag::decode( e, urls );
+#if KDE_IS_VERSION(3,4,0)
+  m_editImagePath->setKURL( urls.first() );
+#else
   m_editImagePath->setURL( urls.first().path() );
+#endif
 }
 
 #include "k3bisoimagewritingdialog.moc"
