@@ -1,10 +1,10 @@
-/* 
+/*
  *
  * $Id$
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -143,7 +143,7 @@ void K3bCddbOptionTab::readSettings()
 
   QStringList localCddbDirs = c->readPathListEntry( "local cddb dirs" );
 
-  m_checkRemoteCddb->setChecked( c->readBoolEntry( "use remote cddb", false ) );
+  m_checkRemoteCddb->setChecked( c->readBoolEntry( "use remote cddb", true ) );
   m_checkUseLocalCddb->setChecked( c->readBoolEntry( "use local cddb query", true ) );
   m_checkSaveLocalEntries->setChecked( c->readBoolEntry( "save cddb entries locally", true ) );
   m_checkManualCgiPath->setChecked( c->readBoolEntry( "use manual cgi path", false ) );
@@ -169,7 +169,7 @@ void K3bCddbOptionTab::readSettings()
   }
 
   if( cddbServer.isEmpty() )
-    cddbServer.append( "Http freedb.org:80" );
+    cddbServer.append( "Http freedb2.org:80" );
 
   for( QStringList::const_iterator it = cddbServer.begin(); it != cddbServer.end(); ++it ) {
     const QString& s = *it;
@@ -237,7 +237,7 @@ void K3bCddbOptionTab::slotLocalDirAdd()
           ++it;
       }
     (void)new KListViewItem( m_viewLocalDir, m_viewLocalDir->lastItem(),
-			    localDir );
+			     localDir );
 
     enDisableButtons();
   }
