@@ -4,7 +4,7 @@
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@
 #include <qheader.h>
 #include <qstring.h>
 #include <qcolor.h>
-
+#include <qptrlist.h>
 
 
 class K3bDeviceWidget::PrivateTempDevice
@@ -49,15 +49,11 @@ public:
   PrivateTempDevice( K3bDevice::Device* d ) {
     device = d;
     cdrdaoDriver = d->cdrdaoDriver();
-    maxReadSpeed = d->maxReadSpeed() / 175;
-    maxWriteSpeed = d->maxWriteSpeed() / 175;
     cdTextCapable = ( d->cdTextCapable() != 2 );
     writer = d->burner();
   }
 
   K3bDevice::Device* device;
-  int maxReadSpeed;
-  int maxWriteSpeed;
   QString cdrdaoDriver;
   bool cdTextCapable;
   bool writer;
@@ -84,12 +80,6 @@ public:
   void setText(int col, const QString& text) {
     if( col == 1 ) {
       switch(m_type) {
-      case t_maxReadSpeed:
-	dev->maxReadSpeed = text.toInt();
-	break;
-      case t_maxWriteSpeed:
-	dev->maxWriteSpeed = text.toInt();
-	break;
       case t_cdrdaoDriver:
 	dev->cdrdaoDriver = text;
 	break;
@@ -103,12 +93,6 @@ public:
 
   QString text( int col ) const {
     switch(m_type) {
-    case t_maxReadSpeed:
-      return (col == 0 ? i18n("Max read speed:") : QString::number(dev->maxReadSpeed) );
-      break;
-    case t_maxWriteSpeed:
-      return (col == 0 ? i18n("Max write speed:") : QString::number(dev->maxWriteSpeed) );
-      break;
     case t_cdrdaoDriver:
       return (col == 0 ? i18n("Cdrdao driver:") : dev->cdrdaoDriver );
       break;
@@ -124,7 +108,7 @@ public:
     return "???";
   }
 
-  enum itemType { t_maxReadSpeed, t_maxWriteSpeed, t_cdrdaoDriver, t_cdTextCapable };
+  enum itemType { t_cdrdaoDriver, t_cdTextCapable };
 
   PrivateTempDevice* dev;
 
@@ -134,12 +118,6 @@ private:
     static QStringList l2;
 
     switch(m_type) {
-    case t_maxReadSpeed:
-      setEditor( 1, SPIN );
-      break;
-    case t_maxWriteSpeed:
-      setEditor( 1, SPIN );
-      break;
     case t_cdrdaoDriver:
       if( l.isEmpty() )
 	for( int i = 0; i < 13; i++ )
@@ -198,7 +176,7 @@ K3bDeviceWidget::K3bDeviceWidget( K3bDevice::DeviceManager* manager, QWidget *pa
   m_viewDevices = new K3bListView( groupDevices, "m_viewDevicesReader" );
   m_viewDevices->addColumn( "V" );
   m_viewDevices->addColumn( "D" );
-  m_viewDevices->setAllColumnsShowFocus( TRUE );
+  m_viewDevices->setAllColumnsShowFocus( true );
   m_viewDevices->header()->hide();
   m_viewDevices->setSorting( -1 );
   m_viewDevices->setDoubleClickForEdit(false);
@@ -240,11 +218,8 @@ void K3bDeviceWidget::init()
   m_tempDevices.clear();
 
   // add the reading devices
-  K3bDevice::Device* dev = m_deviceManager->allDevices().first();
-  while( dev ) {
-    m_tempDevices.append( new PrivateTempDevice( dev ) );
-    dev = m_deviceManager->allDevices().next();
-  }
+  for( QPtrListIterator<K3bDevice::Device> it( m_deviceManager->allDevices() ); *it; ++it )
+    m_tempDevices.append( new PrivateTempDevice( *it ) );
 
   updateDeviceListViews();
 }
@@ -348,26 +323,14 @@ void K3bDeviceWidget::updateDeviceListViews()
       typeItem->setForegroundColor( 1, palette().disabled().foreground() );
     }
 
-    // WE DO NOT USE THE READ SPEED YET SO IT WOULD JUST DISTRACT THE USER
-
-    PrivateDeviceViewItem1* maxReadSpeedItem = static_cast<PrivateDeviceViewItem1 *>( typeItem );
-//                                             new PrivateDeviceViewItem1( PrivateDeviceViewItem1::t_maxReadSpeed,
-// 									   dev,
-// 									   devRoot,
-// 									   typeItem );
     PrivateDeviceViewItem1* cdrdaoDriverItem = new PrivateDeviceViewItem1( PrivateDeviceViewItem1::t_cdrdaoDriver,
 									   dev,
 									   devRoot,
-									   maxReadSpeedItem );
+									   typeItem );
+
 
     // now add the writer specific items
     if( dev->writer ) {
-      // add max write speed item after the maxreadspeed item
-      (void)new PrivateDeviceViewItem1( PrivateDeviceViewItem1::t_maxWriteSpeed,
-					dev,
-					devRoot,
-					maxReadSpeedItem );
-
       PrivateDeviceViewItem1* cdTextItem = new PrivateDeviceViewItem1( PrivateDeviceViewItem1::t_cdTextCapable,
 								       dev,
 								       devRoot,
@@ -430,8 +393,6 @@ void K3bDeviceWidget::apply()
   // update the devices
   PrivateTempDevice* tempDev = m_tempDevices.first();
   while( tempDev != 0 ) {
-    tempDev->device->setMaxReadSpeed( tempDev->maxReadSpeed * 175 );
-    tempDev->device->setMaxWriteSpeed( tempDev->maxWriteSpeed * 175 );
     tempDev->device->setCdrdaoDriver( tempDev->cdrdaoDriver );
     tempDev->device->setCdTextCapability( tempDev->cdTextCapable );
 
