@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bmiscoptiontab.h,v 1.7 2004/01/21 10:20:13 trueg Exp $
+ * $Id: k3bmiscoptiontab.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,9 @@ class K3bMiscOptionTab : public base_K3bMiscOptionTab
 
   void readSettings();
   bool saveSettings();
+
+ private slots:
+  void slotConfigureAudioOutput();
 };
 
 #endif
