@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3baudiotrackwidget.h 392137 2005-02-22 08:01:29Z trueg $
+ * $Id: k3baudiotrackwidget.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2004 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,18 +42,7 @@ class K3bAudioTrackWidget : public base_K3bAudioTrackWidget
   void save();
   void load();
 
- private slots:
-  void slotEditorMouseAt( const K3b::Msf& );
-  void slotIndex0RangeModified( int, const K3b::Msf& start, const K3b::Msf& );
-  void slotIndex0Changed( const K3b::Msf& msf );
-  void slotIndex0Checked( bool b );
-  void slotPostGapChanged( const K3b::Msf& msf );
-
- private:
-  void setIndex0Editors( const K3b::Msf& msf );
-
   QPtrList<K3bAudioTrack> m_tracks;
-  int m_index0Range;
 };
 
 #endif
