@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3bdatadirtreeview.cpp 476670 2005-11-01 19:12:27Z trueg $
+ * $Id: k3bdatadirtreeview.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,6 +52,15 @@ public:
   K3bDataDirViewItem* dropDirItem;
   int animationCounter;
   QPixmap beforeAniPixmap;
+
+  // used for the urladdingdialog hack
+  KURL::List addUrls;
+  K3bDirItem* addParentDir;
+
+  QString lastUpdateVolumeId;
+
+  QValidator* iso9660Validator;
+  QValidator* asciiValidator;
 };
 
 
@@ -75,13 +84,12 @@ K3bDataDirTreeView::K3bDataDirTreeView( K3bView* view, K3bDataDoc* doc, QWidget*
   addColumn( i18n("Directory") );
   header()->hide();
 
-  setValidator( K3bValidators::iso9660Validator( false, this ) );
-
   m_doc = doc;
 
   m_root = new K3bDataRootViewItem( doc, this );
   m_itemMap.insert( doc->root(), m_root );
 
+  connect( m_doc, SIGNAL(changed()), this, SLOT(slotDocChanged()) );
   connect( this, SIGNAL(clicked(QListViewItem*)), this, SLOT(slotExecuted(QListViewItem*)) );
   connect( this, SIGNAL(selectionChanged(QListViewItem*)), this, SLOT(slotExecuted(QListViewItem*)) );
   connect( m_doc, SIGNAL(itemRemoved(K3bDataItem*)), this, SLOT(slotDataItemRemoved(K3bDataItem*)) );
@@ -154,15 +162,14 @@ void K3bDataDirTreeView::slotDropped( QDropEvent* e, QListViewItem*, QListViewIt
     return;
 
   // determine K3bDirItem to add the items to
-  K3bDirItem* parent = 0;
   if( K3bDataDirViewItem* dirViewItem = dynamic_cast<K3bDataDirViewItem*>( itemAt(contentsToViewport(e->pos())) ) ) {
-    parent = dirViewItem->dirItem();
+    d->addParentDir = dirViewItem->dirItem();
   }
   else {
-    parent = m_doc->root();
+    d->addParentDir = m_doc->root();
   }
 
-  if( parent ) {
+  if( d->addParentDir ) {
 
     //    startDropAnimation( parent );
 
@@ -171,7 +178,7 @@ void K3bDataDirTreeView::slotDropped( QDropEvent* e, QListViewItem*, QListViewIt
 	e->source() == m_fileView->viewport() ) {
       // move all selected items
       QPtrList<QListViewItem> selectedViewItems = m_fileView->selectedItems();
-      QPtrList<K3bDataItem> selectedDataItems;
+      QValueList<K3bDataItem*> selectedDataItems;
       QPtrListIterator<QListViewItem> it( selectedViewItems );
       for( ; it.current(); ++it ) {
 	K3bDataViewItem* dataViewItem = dynamic_cast<K3bDataViewItem*>( it.current() );
@@ -181,18 +188,27 @@ void K3bDataDirTreeView::slotDropped( QDropEvent* e, QListViewItem*, QListViewIt
 	  kdDebug() << "no dataviewitem" << endl;
       }
 
-      m_doc->moveItems( selectedDataItems, parent );
+      K3bDataUrlAddingDialog::copyMoveItems( selectedDataItems, d->addParentDir, this, e->action() == QDropEvent::Copy );
     }
     else if( e->source() == viewport() ) {
       // move the selected dir
-      if( K3bDataDirViewItem* dirItem = dynamic_cast<K3bDataDirViewItem*>( selectedItem() ) )
-	m_doc->moveItem( dirItem->dirItem(), parent );
+      if( K3bDataDirViewItem* dirItem = dynamic_cast<K3bDataDirViewItem*>( selectedItem() ) ) {
+	QValueList<K3bDataItem*> selectedDataItems;
+	selectedDataItems.append( dirItem->dirItem() );
+	K3bDataUrlAddingDialog::copyMoveItems( selectedDataItems, d->addParentDir, this, e->action() == QDropEvent::Copy );
+      }
     }
     else {
       // seems that new items have been dropped
-      KURL::List urls;
-      if( KURLDrag::decode( e, urls ) )
-	K3bDataUrlAddingDialog::addUrls( urls, parent, this );
+      d->addUrls.clear();
+      if( KURLDrag::decode( e, d->addUrls ) ) {
+	//
+	// This is a small (not to ugly) hack to circumvent problems with the
+	// event queues: the url adding dialog will be non-modal regardless of
+	// the settings in case we open it directly.
+	//
+	QTimer::singleShot( 0, this, SLOT(slotAddUrls()) );
+      }
     }
   }
 
@@ -201,6 +217,12 @@ void K3bDataDirTreeView::slotDropped( QDropEvent* e, QListViewItem*, QListViewIt
 }
 
 
+void K3bDataDirTreeView::slotAddUrls()
+{
+  K3bDataUrlAddingDialog::addUrls( d->addUrls, d->addParentDir, this );
+}
+
+
 void K3bDataDirTreeView::slotItemAdded( K3bDataItem* item )
 {
   if( item->isDir() ) {
@@ -218,7 +240,8 @@ void K3bDataDirTreeView::slotItemAdded( K3bDataItem* item )
 
 void K3bDataDirTreeView::slotDataItemRemoved( K3bDataItem* item )
 {
-  if( K3bDirItem* dirItem = dynamic_cast<K3bDirItem*>( item ) ) {
+  if( item->isDir() ) {
+    K3bDirItem* dirItem = static_cast<K3bDirItem*>( item );
     QMapIterator<K3bDirItem*, K3bDataDirViewItem*> it = m_itemMap.find( dirItem );
     if( it != m_itemMap.end() ) {
       K3bDataDirViewItem* viewItem = it.data();
@@ -470,4 +493,14 @@ void K3bDataDirTreeView::checkForNewItems()
   m_root->setOpen( true );
 }
 
+
+void K3bDataDirTreeView::slotDocChanged()
+{
+  // avoid flicker
+  if( d->lastUpdateVolumeId != m_doc->isoOptions().volumeID() ) {
+    d->lastUpdateVolumeId = m_doc->isoOptions().volumeID();
+    root()->repaint();
+  }
+}
+
 #include "k3bdatadirtreeview.moc"
