@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bdataimagesettingswidget.h 406814 2005-04-20 20:37:03Z trueg $
+ * $Id: k3bdataimagesettingswidget.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,9 +33,21 @@ class K3bDataImageSettingsWidget : public base_K3bDataImageSettings
   void load( const K3bIsoOptions& );
   void save( K3bIsoOptions& );
 
+  void showFileSystemOptions( bool );
+
  private slots:
-  void slotJolietToggled( bool );
-  void slotRockRidgeToggled( bool );
+  void slotSpaceHandlingChanged( int i );
+  void slotCustomFilesystems();
+  void slotMoreVolDescFields();
+  void slotFilesystemsChanged();
+
+ private:
+  class CustomFilesystemsDialog;
+  class VolumeDescDialog;
+  CustomFilesystemsDialog* m_customFsDlg;
+  VolumeDescDialog* m_volDescDlg;
+
+  bool m_fileSystemOptionsShown;
 };
 
 
