@@ -4,7 +4,7 @@
  * Copyright (C) 2005 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2005 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,14 +23,11 @@
 
 #include <k3bdevice.h>
 
-namespace K3bDevice {
-  class DiskInfoDetector;
-}
 
 class QLabel;
-class K3bBusyWidget;
 class KListBox;
 class K3bDataDoc;
+class K3bMediaSelectionComboBox;
 
 
 class K3bDataSessionImportDialog : public KDialogBase
@@ -38,43 +35,30 @@ class K3bDataSessionImportDialog : public KDialogBase
   Q_OBJECT
 
  public:
-  K3bDataSessionImportDialog( QWidget* parent = 0 );
-  ~K3bDataSessionImportDialog();
-
   /**
    * Import a session into the project.
    * If the project is a DVD data project only DVD media are
    * presented for selection.
+   *
+   * \param doc if 0 a new project will be created.
+   *
+   * \return the project
    */
-  void importSession( K3bDataDoc* doc );
-
-  /**
-   * Convinience method.
-   */
-  static bool importSession( K3bDataDoc* doc, QWidget* parent );
+  static K3bDataDoc* importSession( K3bDataDoc* doc, QWidget* parent );
 
  private slots:
   void slotOk();
   void slotCancel();
 
-  void checkNextDevice();
-  void slotDiskInfoReady( K3bDevice::DiskInfoDetector* );
-
-  void slotSelectionChanged();
+  void importSession( K3bDataDoc* doc );
+  void slotSelectionChanged( K3bDevice::Device* );
 
  private:
-  K3bDevice::DiskInfoDetector* m_diskInfoDetector;
+  K3bDataSessionImportDialog( QWidget* parent = 0 );
+  ~K3bDataSessionImportDialog();
 
   K3bDataDoc* m_doc;
-
-  QLabel* m_processLabel;
-  K3bBusyWidget* m_busyWidget;
-  KListBox* m_selectionBox;
-
-  bool m_alreadySelected;
-
-  QPtrList<K3bDevice::Device> m_devices;
-  QMap<int, K3bDevice::Device*> m_deviceMap;
+  K3bMediaSelectionComboBox* m_comboMedia;
 };
 
 #endif
