@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bmovixburndialog.cpp 619556 2007-01-03 17:38:12Z trueg $
+ * $Id: k3bmovixburndialog.cpp 690207 2007-07-20 10:40:19Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -70,15 +70,17 @@ K3bMovixBurnDialog::K3bMovixBurnDialog( K3bMovixDoc* doc, QWidget* parent, const
   QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
   m_optionGroupLayout->addItem( spacer );
 
+  m_tempDirSelectionWidget->setSelectionMode( K3bTempDirSelectionWidget::FILE );
   QString path = m_doc->tempDir();
-  if( path.isEmpty() ) {
-    path = K3b::defaultTempPath();
-    if( doc->isoOptions().volumeID().isEmpty() )
-      path.append( "image.iso" );
-    else
-      path.append( doc->isoOptions().volumeID() + ".iso" );
+  if( !path.isEmpty() ) {
+      m_tempDirSelectionWidget->setTempPath( path );
   }
-  m_tempDirSelectionWidget->setTempPath( path );
+  if( !m_doc->isoOptions().volumeID().isEmpty() ) {
+      m_tempDirSelectionWidget->setDefaultImageFileName( m_doc->isoOptions().volumeID() + ".iso" );
+  }
+
+  connect( m_imageSettingsWidget->m_editVolumeName, SIGNAL(textChanged(const QString&)),
+           m_tempDirSelectionWidget, SLOT(setDefaultImageFileName(const QString&)) );
 }
 
 
