@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bmovixview.h 392137 2005-02-22 08:01:29Z trueg $
+ * $Id: k3bmovixview.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@ class KAction;
 class KPopupMenu;
 class QListViewItem;
 class QPoint;
+class QLineEdit;
 
 
 class K3bMovixView : public K3bView
@@ -42,6 +43,7 @@ class K3bMovixView : public K3bView
   void slotRemoveSubTitleItems();
   void showPropertiesDialog();
   void slotAddSubTitleFile();
+  void slotDocChanged();
 
  protected:
   virtual K3bProjectBurnDialog* newBurnDialog( QWidget* parent = 0, const char* name = 0 );
@@ -56,6 +58,8 @@ class K3bMovixView : public K3bView
   KAction* m_actionRemoveSubTitle;
   KAction* m_actionAddSubTitle;
   KPopupMenu* m_popupMenu;
+
+  QLineEdit* m_volumeIDEdit;
 };
 
 #endif
