@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3bprojectburndialog.cpp 430262 2005-06-30 17:44:20Z trueg $
+ * $Id: k3bprojectburndialog.cpp 630454 2007-02-05 13:06:45Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,9 +61,25 @@ K3bProjectBurnDialog::K3bProjectBurnDialog( K3bDoc* doc, QWidget *parent, const
 {
   m_doc = doc;
 
-  setSaveButtonText( i18n("Save"), i18n("Save Settings and close"),
-		     i18n("Saves the settings to the project and closes the burn dialog.") );
-  setStartButtonText( i18n("Burn") );
+  /**
+   * There is at least one scenario in which this is useful: change the volume id (or rename a file)
+   * without explicit confirmation (by pressing enter for example). Then click the "burn" button.
+   * The "focus out" event which results in a rename in the listviewitem will be processed after the
+   * initialization of the burn dialog. Thus, the burn dialog will read the old volume id.
+   */
+  setDelayedInitialization( true );
+
+  setButtonGui( SAVE_BUTTON,
+		KStdGuiItem::close() );
+  setButtonText( SAVE_BUTTON,
+		i18n("Close"), 
+		i18n("Save Settings and close"),
+		i18n("Saves the settings to the project and closes the dialog.") );
+  setButtonGui( CANCEL_BUTTON, KStdGuiItem::cancel() );
+  setButtonText( CANCEL_BUTTON, 
+		 i18n("Cancel"),
+		 i18n("Discard all changes and close"),
+		 i18n("Discards all changes made in the dialog and closes it.") );
 
   m_job = 0;
 }
@@ -76,88 +92,86 @@ K3bProjectBurnDialog::~K3bProjectBurnDialog(){
 void K3bProjectBurnDialog::init()
 {
   readSettings();
-  if( !m_writerSelectionWidget->writerDevice() )
-    m_checkOnlyCreateImage->setChecked(true);
+//   if( !m_writerSelectionWidget->writerDevice() )
+//     m_checkOnlyCreateImage->setChecked(true);
 }
 
 
 void K3bProjectBurnDialog::slotWriterChanged()
 {
-  toggleAllOptions();
+  slotToggleAll();
 }
 
 
 void K3bProjectBurnDialog::slotWritingAppChanged( int )
 {
-  toggleAllOptions();
+  slotToggleAll();
 }
 
 
-void K3bProjectBurnDialog::toggleAllOptions()
+void K3bProjectBurnDialog::toggleAll()
 {
-  if( K3bDevice::Device* dev = m_writerSelectionWidget->writerDevice() ) {
+  K3bDevice::Device* dev = m_writerSelectionWidget->writerDevice();
+  if( dev ) {
     if( m_dvd ) {
       if( (dev->type() & (K3bDevice::DVDPR|K3bDevice::DVDPRW)) &&
 	  !(dev->type() & (K3bDevice::DVDR|K3bDevice::DVDRW)) ) {
 	// no simulation support for DVD+R(W) only drives
 	m_checkSimulate->setChecked(false);
 	m_checkSimulate->setEnabled(false);
-
-	// what about the writing mode? We just say "overwrite" for DVD+R(W) for now
-	m_writingModeWidget->setSupportedModes( K3b::WRITING_MODE_RES_OVWR );
       }
       else {
-	// DVD-R(W) supported
-	m_writingModeWidget->setSupportedModes( K3b::WRITING_MODE_RES_OVWR|K3b::WRITING_MODE_INCR_SEQ|K3b::DAO );
 	m_checkSimulate->setEnabled(true);
       }
     }
 
-    m_buttonStart->setDisabled(false);
+    setButtonEnabled( START_BUTTON, true );
   }
   else
-    m_buttonStart->setDisabled(true);
+    setButtonEnabled( START_BUTTON, false );
+
+  m_writingModeWidget->determineSupportedModesFromMedium( dev );
 
   m_writingModeWidget->setDisabled( m_checkOnlyCreateImage->isChecked() );
   m_checkSimulate->setDisabled( m_checkOnlyCreateImage->isChecked() );
-  m_checkOnTheFly->setDisabled( m_checkOnlyCreateImage->isChecked() );
-  m_checkRemoveBufferFiles->setDisabled( m_checkOnlyCreateImage->isChecked() || m_checkOnTheFly->isChecked() );
+  m_checkCacheImage->setDisabled( m_checkOnlyCreateImage->isChecked() );
+  m_checkRemoveBufferFiles->setDisabled( m_checkOnlyCreateImage->isChecked() || !m_checkCacheImage->isChecked() );
   if( m_checkOnlyCreateImage->isChecked() ) {
     m_checkRemoveBufferFiles->setChecked(false);
-    m_buttonStart->setDisabled(false);
+    setButtonEnabled( START_BUTTON, true );
   }
-  m_tempDirSelectionWidget->setDisabled( m_checkOnTheFly->isChecked() && !m_checkOnlyCreateImage->isChecked() );
+  m_tempDirSelectionWidget->setDisabled( !m_checkCacheImage->isChecked() && !m_checkOnlyCreateImage->isChecked() );
   m_writerSelectionWidget->setDisabled( m_checkOnlyCreateImage->isChecked() );
   m_spinCopies->setDisabled( m_checkSimulate->isChecked() || m_checkOnlyCreateImage->isChecked() );
 
   if( !m_dvd ) {
-    // default is cdrecord and cdrecord supports all modes
+    // we only support DAO with cdrdao
     if( m_writerSelectionWidget->writingApp() == K3b::CDRDAO )
       m_writingModeWidget->setSupportedModes( K3b::DAO );
-    else
-      m_writingModeWidget->setSupportedModes( K3b::DAO | K3b::TAO | K3b::RAW );
   }
+
+  if( m_checkOnlyCreateImage->isChecked() )
+    setButtonText( START_BUTTON, 
+		   i18n("Start"),
+		   i18n("Start the image creation") );
+  else
+    setButtonText( START_BUTTON, i18n("Burn"),
+		   i18n("Start the burning process") );
 }
 
 
-int K3bProjectBurnDialog::exec( bool burn )
+int K3bProjectBurnDialog::execBurnDialog( bool burn )
 {
   if( burn && m_job == 0 ) {
-    m_buttonStart->show();
+    setButtonShown( START_BUTTON, true );
     setDefaultButton( START_BUTTON );
-    if( !m_writerSelectionWidget->writerDevice() )
-      KMessageBox::information( this, 
-				i18n("K3b did not find a suitable writer. "
-				     "You will only be able to create an image."),
-				i18n("No Writer Available"),
-				"project_no_writer" );
   }
   else {
-    m_buttonStart->hide();
+    setButtonShown( START_BUTTON, false );
     setDefaultButton( SAVE_BUTTON );
   }
 
-  return K3bInteractionDialog::exec();
+  return K3bInteractionDialog::exec(false);
 }
 
 
@@ -178,14 +192,34 @@ void K3bProjectBurnDialog::slotStartClicked()
 {
   saveSettings();
 
-  // check if enough space in tempdir if not on-the-fly
-  if( m_tempDirSelectionWidget )
-    if( (!doc()->onTheFly() || doc()->onlyCreateImages()) &&
-	doc()->size()/1024 > m_tempDirSelectionWidget->freeTempSpace() ) {
-      if( KMessageBox::warningYesNo( this, i18n("There seems to be not enough free space in temporary directory. "
-						"Write anyway?") ) == KMessageBox::No )
-	return;
+  if( m_tempDirSelectionWidget ) {
+    if( !doc()->onTheFly() || doc()->onlyCreateImages() ) {
+      //
+      // check if the temp dir exists
+      //
+      QString tempDir = m_tempDirSelectionWidget->tempDirectory();
+      if( !QFile::exists( tempDir ) ) {
+	if( KMessageBox::warningYesNo( this, i18n("Image folder '%1' does not exist. Do you want K3b to create it?").arg( tempDir ) )
+	    == KMessageBox::Yes ) {
+	  if( !KStandardDirs::makeDir( tempDir ) ) {
+	    KMessageBox::error( this, i18n("Failed to create folder '%1'.").arg( tempDir ) );
+	    return;
+	  }
+	}
+	else
+	  return;
+      }
+
+      //    
+      // check if enough space in tempdir if not on-the-fly
+      //
+      if( doc()->size()/1024 > m_tempDirSelectionWidget->freeTempSpace() ) {
+	if( KMessageBox::warningContinueCancel( this, i18n("There seems to be not enough free space in temporary directory. "
+							   "Write anyway?") ) == KMessageBox::Cancel )
+	  return;
+      }
     }
+  }
 
   K3bJobProgressDialog* dlg = 0;
   if( m_checkOnlyCreateImage && m_checkOnlyCreateImage->isChecked() )
@@ -199,7 +233,9 @@ void K3bProjectBurnDialog::slotStartClicked()
     m_job->setWritingApp( m_writerSelectionWidget->writingApp() );
   prepareJob( m_job );
 
-  hide();
+  if( !exitLoopOnHide() )
+    hide();
+
   dlg->startJob(m_job);
 
   kdDebug() << "(K3bProjectBurnDialog) job done. cleaning up." << endl;
@@ -214,17 +250,25 @@ void K3bProjectBurnDialog::slotStartClicked()
 
 void K3bProjectBurnDialog::prepareGui()
 {
-  m_tabWidget = new QTabWidget( this );
-  setMainWidget( m_tabWidget );
+  QVBoxLayout* mainLay = new QVBoxLayout( mainWidget() );
+  mainLay->setAutoAdd( true );
+  mainLay->setMargin( 0 );
+  mainLay->setSpacing( KDialog::spacingHint() );
+
+  m_writerSelectionWidget = new K3bWriterSelectionWidget( mainWidget() );
+  m_writerSelectionWidget->setWantedMediumType( m_dvd ? K3bDevice::MEDIA_WRITABLE_DVD : K3bDevice::MEDIA_WRITABLE_CD );
+  m_writerSelectionWidget->setWantedMediumState( K3bDevice::STATE_EMPTY );
+
+  m_tabWidget = new QTabWidget( mainWidget() );
+
   QWidget* w = new QWidget( m_tabWidget );
   m_tabWidget->addTab( w, i18n("Writing") );
-  m_writerSelectionWidget = new K3bWriterSelectionWidget( m_dvd, w );
 
   QGroupBox* groupWritingMode = new QGroupBox( 1, Qt::Vertical, i18n("Writing Mode"), w );
   groupWritingMode->setInsideMargin( marginHint() );
   m_writingModeWidget = new K3bWritingModeWidget( groupWritingMode );
 
-  m_optionGroup = new QGroupBox( 0, Qt::Vertical, i18n("Options"), w );
+  m_optionGroup = new QGroupBox( 0, Qt::Vertical, i18n("Settings"), w );
   m_optionGroup->layout()->setMargin(0);
   m_optionGroup->layout()->setSpacing(0);
   m_optionGroupLayout = new QVBoxLayout( m_optionGroup->layout() );
@@ -232,13 +276,13 @@ void K3bProjectBurnDialog::prepareGui()
   m_optionGroupLayout->setSpacing( KDialog::spacingHint() );
 
   // add the options
-  m_checkOnTheFly = K3bStdGuiItems::onTheFlyCheckbox( m_optionGroup );
+  m_checkCacheImage = K3bStdGuiItems::createCacheImageCheckbox( m_optionGroup );
   m_checkSimulate = K3bStdGuiItems::simulateCheckbox( m_optionGroup );
   m_checkRemoveBufferFiles = K3bStdGuiItems::removeImagesCheckbox( m_optionGroup );
   m_checkOnlyCreateImage = K3bStdGuiItems::onlyCreateImagesCheckbox( m_optionGroup );
 
   m_optionGroupLayout->addWidget(m_checkSimulate);
-  m_optionGroupLayout->addWidget(m_checkOnTheFly);
+  m_optionGroupLayout->addWidget(m_checkCacheImage);
   m_optionGroupLayout->addWidget(m_checkOnlyCreateImage);
   m_optionGroupLayout->addWidget(m_checkRemoveBufferFiles);
 
@@ -255,22 +299,13 @@ void K3bProjectBurnDialog::prepareGui()
   grid->setMargin( KDialog::marginHint() );
   grid->setSpacing( KDialog::spacingHint() );
 
-  grid->addMultiCellWidget( m_writerSelectionWidget, 0, 0, 0, 1 );
-  grid->addWidget( groupWritingMode, 1, 0 );
-  grid->addMultiCellWidget( m_optionGroup, 1, 3, 1, 1 );
-  grid->addWidget( groupCopies, 3, 0 );
+  grid->addWidget( groupWritingMode, 0, 0 );
+  grid->addMultiCellWidget( m_optionGroup, 0, 2, 1, 1 );
+  grid->addWidget( groupCopies, 2, 0 );
   //  grid->addMultiCellWidget( m_tempDirSelectionWidget, 1, 3, 1, 1 );
-  grid->setRowStretch( 2, 1 );
+  grid->setRowStretch( 1, 1 );
   grid->setColStretch( 1, 1 );
 
-  // some default connections that should always be useful
-  connect( m_writerSelectionWidget, SIGNAL(writerChanged()), this, SLOT(slotWriterChanged()) );
-  connect( m_writerSelectionWidget, SIGNAL(writingAppChanged(int)), this, SLOT(slotWritingAppChanged(int)) );
-  connect( m_checkOnTheFly, SIGNAL(toggled(bool)), this, SLOT(toggleAllOptions()) );
-  connect( m_checkSimulate, SIGNAL(toggled(bool)), this, SLOT(toggleAllOptions()) );
-  connect( m_checkOnlyCreateImage, SIGNAL(toggled(bool)), this, SLOT(toggleAllOptions()) );
-  connect( m_writingModeWidget, SIGNAL(writingModeChanged(int)), this, SLOT(toggleAllOptions()) );
-
   QWidget* tempW = new QWidget( m_tabWidget );
   grid = new QGridLayout( tempW );
   grid->setMargin( KDialog::marginHint() );
@@ -284,6 +319,16 @@ void K3bProjectBurnDialog::prepareGui()
   setTabOrder( m_writerSelectionWidget, m_writingModeWidget );
   setTabOrder( m_writingModeWidget, groupCopies );
   setTabOrder( groupCopies, m_optionGroup );
+
+  // some default connections that should always be useful
+  connect( m_writerSelectionWidget, SIGNAL(writerChanged()), this, SLOT(slotWriterChanged()) );
+  connect( m_writerSelectionWidget, SIGNAL(writerChanged(K3bDevice::Device*)), 
+	   m_writingModeWidget, SLOT(determineSupportedModesFromMedium(K3bDevice::Device*)) );
+  connect( m_writerSelectionWidget, SIGNAL(writingAppChanged(int)), this, SLOT(slotWritingAppChanged(int)) );
+  connect( m_checkCacheImage, SIGNAL(toggled(bool)), this, SLOT(slotToggleAll()) );
+  connect( m_checkSimulate, SIGNAL(toggled(bool)), this, SLOT(slotToggleAll()) );
+  connect( m_checkOnlyCreateImage, SIGNAL(toggled(bool)), this, SLOT(slotToggleAll()) );
+  connect( m_writingModeWidget, SIGNAL(writingModeChanged(int)), this, SLOT(slotToggleAll()) );
 }
 
 
@@ -296,7 +341,7 @@ void K3bProjectBurnDialog::addPage( QWidget* page, const QString& title )
 void K3bProjectBurnDialog::saveSettings()
 {
   m_doc->setDummy( m_checkSimulate->isChecked() );
-  m_doc->setOnTheFly( m_checkOnTheFly->isChecked() );
+  m_doc->setOnTheFly( !m_checkCacheImage->isChecked() );
   m_doc->setOnlyCreateImages( m_checkOnlyCreateImage->isChecked() );
   m_doc->setRemoveImages( m_checkRemoveBufferFiles->isChecked() );
   m_doc->setSpeed( m_writerSelectionWidget->writerSpeed() );
@@ -310,7 +355,7 @@ void K3bProjectBurnDialog::saveSettings()
 void K3bProjectBurnDialog::readSettings()
 {
   m_checkSimulate->setChecked( doc()->dummy() );
-  m_checkOnTheFly->setChecked( doc()->onTheFly() );
+  m_checkCacheImage->setChecked( !doc()->onTheFly() );
   m_checkOnlyCreateImage->setChecked( m_doc->onlyCreateImages() );
   m_checkRemoveBufferFiles->setChecked( m_doc->removeImages() );
   m_writingModeWidget->setWritingMode( doc()->writingMode() );
@@ -325,28 +370,26 @@ void K3bProjectBurnDialog::saveUserDefaults( KConfigBase* c )
 {
   m_writingModeWidget->saveConfig( c );
   c->writeEntry( "simulate", m_checkSimulate->isChecked() );
-  c->writeEntry( "on_the_fly", m_checkOnTheFly->isChecked() );
+  c->writeEntry( "on_the_fly", !m_checkCacheImage->isChecked() );
   c->writeEntry( "remove_image", m_checkRemoveBufferFiles->isChecked() );
   c->writeEntry( "only_create_image", m_checkOnlyCreateImage->isChecked() );
+  c->writeEntry( "copies", m_spinCopies->value() );
 
+  m_tempDirSelectionWidget->saveConfig( c );
   m_writerSelectionWidget->saveConfig( c );
-
-  if( m_tempDirSelectionWidget->isEnabled() ) {
-    m_tempDirSelectionWidget->saveConfig();
-  }
 }
 
 
 void K3bProjectBurnDialog::loadUserDefaults( KConfigBase* c )
 {
-  m_tempDirSelectionWidget->setTempPath( K3b::defaultTempPath() );
-
   m_writingModeWidget->loadConfig( c );
   m_checkSimulate->setChecked( c->readBoolEntry( "simulate", false ) );
-  m_checkOnTheFly->setChecked( c->readBoolEntry( "on_the_fly", true ) );
+  m_checkCacheImage->setChecked( !c->readBoolEntry( "on_the_fly", true ) );
   m_checkRemoveBufferFiles->setChecked( c->readBoolEntry( "remove_image", true ) );
   m_checkOnlyCreateImage->setChecked( c->readBoolEntry( "only_create_image", false ) );
+  m_spinCopies->setValue( c->readNumEntry( "copies", 1 ) );
 
+  m_tempDirSelectionWidget->readConfig( c );
   m_writerSelectionWidget->loadConfig( c );
 }
 
@@ -356,11 +399,15 @@ void K3bProjectBurnDialog::loadK3bDefaults()
   m_writerSelectionWidget->loadDefaults();
   m_writingModeWidget->setWritingMode( K3b::WRITING_MODE_AUTO );
   m_checkSimulate->setChecked( false );
-  m_checkOnTheFly->setChecked( true );
+  m_checkCacheImage->setChecked( false );
   m_checkRemoveBufferFiles->setChecked( true );
   m_checkOnlyCreateImage->setChecked( false );
+  m_spinCopies->setValue( 1 );
 
-  m_tempDirSelectionWidget->setTempPath( KGlobal::dirs()->resourceDirs( "tmp" ).first() );
+  if( m_tempDirSelectionWidget->selectionMode() == K3bTempDirSelectionWidget::DIR )
+    m_tempDirSelectionWidget->setTempPath( K3b::defaultTempPath() );
+  else
+    m_tempDirSelectionWidget->setTempPath( K3b::defaultTempPath() + doc()->name() + ".iso" );
 }
 
 #include "k3bprojectburndialog.moc"
