@@ -1,10 +1,10 @@
 /*
 *
-* $Id: k3bvcdtrackdialog.cpp 392819 2005-02-24 12:56:32Z coles $
+* $Id: k3bvcdtrackdialog.cpp 619556 2007-01-03 17:38:12Z trueg $
 * Copyright (C) 2003-2004 Christian Kvasny <chris@k3b.org>
 *
 * This file is part of the K3b project.
-* Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+* Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -449,7 +449,7 @@ void K3bVcdTrackDialog::setupPbcTab()
 
 
     //////////////////////////////////////////////////////////////////////////////////////////
-    QGroupBox* groupOptions = new QGroupBox( 3, Qt::Vertical, i18n( "Options" ), w );
+    QGroupBox* groupOptions = new QGroupBox( 3, Qt::Vertical, i18n( "Settings" ), w );
     groupOptions->layout() ->setSpacing( spacingHint() );
     groupOptions->layout() ->setMargin( marginHint() );
 
