@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bvideodvdburndialog.h 401319 2005-03-28 16:26:58Z trueg $
+ * $Id: k3bvideodvdburndialog.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 
 class K3bVideoDvdDoc;
-class K3bDataVolumeDescWidget;
+class K3bDataImageSettingsWidget;
 class QCheckBox;
 
 
@@ -34,8 +34,7 @@ class K3bVideoDvdBurnDialog : public K3bProjectBurnDialog
    ~K3bVideoDvdBurnDialog();
 
  protected slots:
-   void toggleAllOptions();
-
+   void slotStartClicked();
    void saveSettings();
    void readSettings();
 
@@ -43,9 +42,10 @@ class K3bVideoDvdBurnDialog : public K3bProjectBurnDialog
    void loadK3bDefaults();
    void loadUserDefaults( KConfigBase* );
    void saveUserDefaults( KConfigBase* );
+   void toggleAll();
 
  private:
-   K3bDataVolumeDescWidget* m_volumeDescWidget;
+   K3bDataImageSettingsWidget* m_imageSettingsWidget;
 
    QCheckBox* m_checkVerify;
 
