@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3baudiocdlistview.cpp 489631 2005-12-19 10:58:06Z trueg $
+ * $Id: k3baudiocdlistview.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2004 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #include <klocale.h>
 
 #include <qheader.h>
+#include <qtooltip.h>
 
 
 K3bAudioCdListView::K3bAudioCdListView( K3bAudioCdView* view, QWidget* parent, const char* name )
@@ -37,7 +38,7 @@ K3bAudioCdListView::K3bAudioCdListView( K3bAudioCdView* view, QWidget* parent, c
   addColumn( i18n("Length") );
   addColumn( i18n("Size") );
 
-  setDoubleClickForEdit( false );
+  setDoubleClickForEdit( true );
 
   header()->setClickEnabled(false);
   setColumnWidthMode( 0, QListView::Manual );
@@ -45,6 +46,8 @@ K3bAudioCdListView::K3bAudioCdListView( K3bAudioCdView* view, QWidget* parent, c
   header()->setResizeEnabled( false,0 );
 
   setColumnAlignment( 4, Qt::AlignHCenter );
+
+  QToolTip::add( viewport(), i18n("Check the tracks that should be ripped") );
 }
 
 
