@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3baudiocdview.cpp 409817 2005-05-05 18:44:15Z trueg $
+ * $Id: k3baudiocdview.cpp 624215 2007-01-16 19:10:03Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 #include "k3baudiorippingdialog.h"
 #include "k3baudiocdlistview.h"
 
+#include <k3bpassivepopup.h>
 #include <k3btoc.h>
 #include <k3bdiskinfo.h>
 #include <k3bdevicehandler.h>
@@ -29,9 +30,9 @@
 #include <kcutlabel.h>
 #include <k3bstdguiitems.h>
 #include <k3bapplication.h>
-#include <cdinfo/k3bdiskinfodetector.h>
 #include <k3bthememanager.h>
 #include <k3baudiocdtrackdrag.h>
+#include <k3bthemedlabel.h>
 
 #include <klocale.h>
 #include <kdebug.h>
@@ -53,29 +54,33 @@
 #include <qfont.h>
 #include <qdragobject.h>
 
-// FIXME: use a K3bListViewItem which can be checked
-class K3bAudioCdView::AudioTrackViewItem : public QCheckListItem
+
+
+
+class K3bAudioCdView::AudioTrackViewItem : public K3bCheckListViewItem
 {
 public:
   AudioTrackViewItem( QListView* parent, 
 		      QListViewItem* after,
 		      int _trackNumber,
 		      const K3b::Msf& length) 
-    : QCheckListItem( parent,
-		      after,
-		      QString::null,
-		      QCheckListItem::CheckBox ) {
+    : K3bCheckListViewItem( parent, after ) {
+
     setText( 1, QString::number(_trackNumber).rightJustify( 2, ' ' ) );
     setText( 3, i18n("Track %1").arg(_trackNumber) );
     setText( 4, " " + length.toString() + " " );
     setText( 5, " " + KIO::convertSize( length.audioBytes() ) + " " );
 
     trackNumber = _trackNumber;
-    setOn(true);
+
+    setEditor( 2, LINE );
+    setEditor( 3, LINE );
+
+    setChecked(true);
   }
 
   void setup() {
-    QCheckListItem::setup();
+    K3bCheckListViewItem::setup();
     
     setHeight( height() + 4 );
   }
@@ -90,7 +95,11 @@ public:
 
 
 K3bAudioCdView::K3bAudioCdView( QWidget* parent, const char *name )
-  : K3bCdContentsView( true, parent, name )
+  : K3bMediaContentsView( true, 
+			  K3bMedium::CONTENT_AUDIO,
+			  K3bDevice::MEDIA_CD_ALL,
+			  K3bDevice::STATE_INCOMPLETE|K3bDevice::STATE_COMPLETE,
+			  parent, name )
 {
   QGridLayout* mainGrid = new QGridLayout( mainWidget() );
 
@@ -123,10 +132,6 @@ K3bAudioCdView::K3bAudioCdView( QWidget* parent, const char *name )
 
   m_cddb = new K3bCddb( this );
 
-  connect( m_cddb, SIGNAL(infoMessage(const QString&)),
-	   k3bappcore, SLOT(requestBusyInfo(const QString&)) );
-  connect( m_cddb, SIGNAL(queryFinished(int)),
-	   k3bappcore, SLOT(requestBusyFinish()) );
   connect( m_cddb, SIGNAL(queryFinished(int)),
 	   this, SLOT(slotCddbQueryFinished(int)) );
 
@@ -135,6 +140,11 @@ K3bAudioCdView::K3bAudioCdView( QWidget* parent, const char *name )
 
   setLeftPixmap( K3bTheme::MEDIA_LEFT );
   setRightPixmap( K3bTheme::MEDIA_AUDIO );
+
+  m_busyInfoLabel = new K3bThemedLabel( i18n("Searching for Artist information..."), this );
+  m_busyInfoLabel->setFrameStyle( QFrame::Box|QFrame::Plain );
+  m_busyInfoLabel->setMargin( 6 );
+  m_busyInfoLabel->hide();
 }
 
 
@@ -143,14 +153,14 @@ K3bAudioCdView::~K3bAudioCdView()
 }
 
 
-void K3bAudioCdView::setDisk( K3bDevice::DiskInfoDetector* did )
+void K3bAudioCdView::reloadMedium()
 {
-  m_toc = did->toc();
-  m_device = did->device();
+  m_toc = medium().toc();
+  m_device = medium().device();
 
   // initialize cddb info for editing
   m_cddbInfo = K3bCddbResultEntry();
-  m_cddbInfo.discid = QString::number( did->toc().discId(), 16 );
+  m_cddbInfo.discid = QString::number( medium().toc().discId(), 16 );
 
   for( int i = 0; i < (int)m_toc.count(); ++i ) {
     m_cddbInfo.titles.append("");
@@ -159,11 +169,11 @@ void K3bAudioCdView::setDisk( K3bDevice::DiskInfoDetector* did )
   }
 
   m_trackView->clear();
-  enableInteraction(false);
+  showBusyLabel(true);
 
   // create a listviewItem for every audio track
   int index = 1;
-  for( K3bToc::const_iterator it = m_toc.begin(); 
+  for( K3bDevice::Toc::const_iterator it = m_toc.begin(); 
        it != m_toc.end(); ++it ) {
 
     // for now skip data tracks since we are not able to rip them to iso
@@ -178,14 +188,8 @@ void K3bAudioCdView::setDisk( K3bDevice::DiskInfoDetector* did )
     index++;
   }
 
-  m_cdText = did->cdText();
+  m_cdText = medium().cdText();
       
-  reload();
-}
-
-
-void K3bAudioCdView::reload()
-{
   // simulate a cddb entry with the cdtext data
   m_cddbInfo.cdTitle = m_cdText.title();
   m_cddbInfo.cdArtist = m_cdText.performer();
@@ -209,12 +213,12 @@ void K3bAudioCdView::reload()
 	KMessageBox::questionYesNo( this, 
 				    i18n("Found Cd-Text. Do you want to use it instead of querying CDDB?"),
 				    i18n("Found Cd-Text"), 
-				    KStdGuiItem::yes(),
-				    KStdGuiItem::no(),
+				    i18n("Use CD-Text"),
+				    i18n("Query CDDB"),
 				    "prefereCdTextOverCddb" ) == KMessageBox::No ) )
     queryCddb();
   else
-    enableInteraction(true);
+    showBusyLabel(false);
 }
 
 
@@ -222,25 +226,26 @@ void K3bAudioCdView::initActions()
 {
   m_actionCollection = new KActionCollection( this );
 
-  KAction* actionSelectAll = KStdAction::selectAll( this, SLOT(slotSelectAll()), 
-						    m_actionCollection, "select_all" );
-  KAction* actionDeselectAll = KStdAction::deselect( this, SLOT(slotDeselectAll()), 
-						     m_actionCollection, "deselect_all" );
-  actionDeselectAll->setText( i18n("Dese&lect All") );
-  KAction* actionSelect = new KAction( i18n("Select Track"), 0, 0, this,
+  KAction* actionSelectAll = new KAction( i18n("Check All"), 0, 0, this,
+					  SLOT(slotCheckAll()), actionCollection(),
+					  "check_all" );
+  KAction* actionDeselectAll = new KAction( i18n("Uncheck All"), 0, 0, this,
+					    SLOT(slotUncheckAll()), actionCollection(),
+					    "uncheck_all" );
+  KAction* actionSelect = new KAction( i18n("Check Track"), 0, 0, this,
 				       SLOT(slotSelect()), actionCollection(),
 				       "select_track" );
-  KAction* actionDeselect = new KAction( i18n("Deselect Track"), 0, 0, this,
+  KAction* actionDeselect = new KAction( i18n("Uncheck Track"), 0, 0, this,
 					 SLOT(slotDeselect()), actionCollection(),
 					 "deselect_track" );
-  KAction* actionEditTrackCddbInfo = new KAction( i18n("Edit cddb Info"), "edit", 0, this,
+  KAction* actionEditTrackCddbInfo = new KAction( i18n("Edit Track cddb Info"), "edit", 0, this,
 						  SLOT(slotEditTrackCddb()), actionCollection(),
 						  "edit_track_cddb" );
   KAction* actionEditAlbumCddbInfo = new KAction( i18n("Edit Album cddb Info"), "edit", 0, this,
 						  SLOT(slotEditAlbumCddb()), actionCollection(),
 						  "edit_album_cddb" );
 
-  KAction* actionStartRip = new KAction( i18n("Start Ripping"), "run", 0, this,
+  KAction* actionStartRip = new KAction( i18n("Start Ripping"), "cddarip", 0, this,
 					 SLOT(startRip()), actionCollection(), "start_rip" );
 
   KAction* actionQueryCddb = new KAction( i18n("Query cddb"), "reload", 0, this,
@@ -265,7 +270,7 @@ void K3bAudioCdView::initActions()
   m_popupMenu->insert( actionStartRip );
 
   // setup the toolbox
-  m_toolBox->addButton( actionStartRip );
+  m_toolBox->addButton( actionStartRip, true );
   m_toolBox->addSpacing();
   m_toolBox->addButton( actionQueryCddb );
   m_toolBox->addButton( actionSaveCddbLocally );
@@ -305,7 +310,7 @@ void K3bAudioCdView::startRip()
   QValueList<int> trackNumbers;
   for( QListViewItemIterator it( m_trackView ); it.current(); ++it ) {
     AudioTrackViewItem* a = (AudioTrackViewItem*)it.current();
-    if( a->isOn() )
+    if( a->isChecked() )
       trackNumbers.append( a->trackNumber );
   }
 
@@ -354,7 +359,7 @@ void K3bAudioCdView::slotEditTrackCddb()
     grid->setRowStretch( 4, 1 );
 
     d.setMainWidget(w);
-    d.resize(260, d.sizeHint().height());
+    d.resize( QMAX( QMAX(d.sizeHint().height(), d.sizeHint().width()), 300), d.sizeHint().height() );
 
     if( d.exec() == QDialog::Accepted ) {
       m_cddbInfo.titles[a->trackNumber-1] = editTitle->text();
@@ -410,7 +415,7 @@ void K3bAudioCdView::slotEditAlbumCddb()
   grid->setRowStretch( 7, 1 );
 
   d.setMainWidget(w);
-  d.resize(260, d.sizeHint().height());
+  d.resize( QMAX( QMAX(d.sizeHint().height(), d.sizeHint().width()), 300), d.sizeHint().height() );
 
   if( d.exec() == QDialog::Accepted ) {
     m_cddbInfo.cdTitle = editTitle->text();
@@ -435,7 +440,7 @@ void K3bAudioCdView::queryCddb()
   if( c->readBoolEntry( "use local cddb query", true ) || 
       c->readBoolEntry( "use remote cddb", false ) ) {
 
-    enableInteraction(false);
+    showBusyLabel(true);
  
     m_cddb->query( m_toc );
   }
@@ -444,8 +449,6 @@ void K3bAudioCdView::queryCddb()
 
 void K3bAudioCdView::slotCddbQueryFinished( int error )
 {
-  k3bappcore->requestBusyFinish();
-
   if( error == K3bCddbQuery::SUCCESS ) {
     m_cddbInfo = m_cddb->result();
 
@@ -455,32 +458,17 @@ void K3bAudioCdView::slotCddbQueryFinished( int error )
     if( c->readBoolEntry( "save cddb entries locally", true ) )
       m_cddb->saveEntry( m_cddbInfo );
 
-    //       kdDebug() << "cddb info:" << endl;
-    //       kdDebug() << "DTITLE:  '" << m_cddbInfo.cdTitle << "'" << endl;
-    //       kdDebug() << "DARTIST: '" << m_cddbInfo.cdArtist << "'" << endl;
-    //       kdDebug() << "DEXT:    '" << m_cddbInfo.cdExtInfo << "'" << endl;
-    //       kdDebug() << "DISCID:  '" << m_cddbInfo.discid << "'" << endl;
-
-    //       for( QStringList::const_iterator it = m_cddbInfo.titles.begin();
-    // 	   it != m_cddbInfo.titles.end(); ++it ) {
-    // 	kdDebug() << "TTITLE:  '" << *it << "'" << endl;
-    //       }
-    //       for( QStringList::const_iterator it = m_cddbInfo.artists.begin();
-    // 	   it != m_cddbInfo.artists.end(); ++it ) {
-    // 	kdDebug() << "TARTIST: '" << *it << "'" << endl;
-    //       }
-    //       for( QStringList::const_iterator it = m_cddbInfo.extInfos.begin();
-    // 	   it != m_cddbInfo.extInfos.end(); ++it ) {
-    // 	kdDebug() << "TEXT:    '" << *it << "'" << endl;
-    //       }
-
     updateDisplay();
   }
   else if( error == K3bCddbQuery::NO_ENTRY_FOUND ) {
-    KMessageBox::information( this, i18n("No CDDB entry found."), i18n("CDDB") );
+    if( !KConfigGroup( k3bcore->config(), "Cddb" ).readBoolEntry( "use remote cddb", false ) )
+      K3bPassivePopup::showPopup( i18n("<p>No CDDB entry found. Enable remote CDDB queries in the K3b settings to get access "
+				       "to more entries through the internet."), i18n("CDDB") );
+    else
+      K3bPassivePopup::showPopup( i18n("No CDDB entry found."), i18n("CDDB") );
   }
-  else {
-    KMessageBox::information( this, m_cddb->errorString(), i18n("Cddb error") );
+  else if( error != K3bCddbQuery::CANCELED ) {
+    K3bPassivePopup::showPopup( m_cddb->errorString(), i18n("CDDB Error") );
   }
 
   enableInteraction(true);
@@ -527,23 +515,23 @@ void K3bAudioCdView::slotSaveCddbLocally()
   m_cddb->readConfig( c );
 
   m_cddb->saveEntry( m_cddbInfo );
-  KMessageBox::information( this, 
-			    i18n("Saved entry (%1) in category %2.")
-			    .arg(m_cddbInfo.discid)
-			    .arg(m_cddbInfo.category) );
+  K3bPassivePopup::showPopup( i18n("Saved entry (%1) in category %2.")
+			      .arg(m_cddbInfo.discid)
+			      .arg(m_cddbInfo.category),
+			      i18n("CDDB") );
 }
 
 
-void K3bAudioCdView::slotSelectAll()
+void K3bAudioCdView::slotCheckAll()
 {
   for( QListViewItemIterator it( m_trackView ); it.current(); ++it )
-    ((AudioTrackViewItem*)it.current())->setOn(true);
+    ((AudioTrackViewItem*)it.current())->setChecked(true);
 }
 
-void K3bAudioCdView::slotDeselectAll()
+void K3bAudioCdView::slotUncheckAll()
 {
   for( QListViewItemIterator it( m_trackView ); it.current(); ++it )
-    ((AudioTrackViewItem*)it.current())->setOn(false);
+    ((AudioTrackViewItem*)it.current())->setChecked(false);
 }
 
 void K3bAudioCdView::slotSelect()
@@ -551,7 +539,7 @@ void K3bAudioCdView::slotSelect()
   QPtrList<QListViewItem> items( m_trackView->selectedItems() );
   for( QPtrListIterator<QListViewItem> it( items );
        it.current(); ++it )
-    static_cast<AudioTrackViewItem*>(it.current())->setOn(true);
+    static_cast<AudioTrackViewItem*>(it.current())->setChecked(true);
 }
 
 void K3bAudioCdView::slotDeselect()
@@ -559,7 +547,7 @@ void K3bAudioCdView::slotDeselect()
   QPtrList<QListViewItem> items( m_trackView->selectedItems() );
   for( QPtrListIterator<QListViewItem> it( items );
        it.current(); ++it )
-    static_cast<AudioTrackViewItem*>(it.current())->setOn(false);
+    static_cast<AudioTrackViewItem*>(it.current())->setChecked(false);
 }
 
 void K3bAudioCdView::updateDisplay()
@@ -585,10 +573,37 @@ void K3bAudioCdView::updateDisplay()
 }
 
 
+void K3bAudioCdView::showBusyLabel( bool b )
+{
+  if( !b ) {
+    actionCollection()->action( "start_rip" )->setEnabled( true );
+    m_trackView->setEnabled( true );
+    m_busyInfoLabel->hide();
+  }
+  else {
+    // the themed label is a cut label, thus its size hint is
+    // based on the cut text, we force it to be full
+    m_busyInfoLabel->resize( width(), height() );
+    m_busyInfoLabel->resize( m_busyInfoLabel->sizeHint() );
+    int x = (width() - m_busyInfoLabel->width())/2;
+    int y = (height() - m_busyInfoLabel->height())/2;
+    QRect r( QPoint( x, y ), m_busyInfoLabel->size() );
+    m_busyInfoLabel->setGeometry( r );
+    m_busyInfoLabel->show();
+
+    m_trackView->setEnabled( false );
+    enableInteraction( false );
+  }
+}
+
+
 void K3bAudioCdView::enableInteraction( bool b )
 {
-  m_trackView->setEnabled(b);
-  m_toolBox->setEnabled(b);
+  // we leave the track view enabled in default disabled mode
+  // since drag'n'drop to audio projects does not need an inserted CD
+  actionCollection()->action( "start_rip" )->setEnabled( b );
+  if( b )
+    showBusyLabel( false );
 }
 
 
@@ -601,11 +616,13 @@ QDragObject* K3bAudioCdView::dragObject()
     tracks.append( static_cast<AudioTrackViewItem*>(it.current())->trackNumber );
 
   if( !items.isEmpty() ) {
-    return new K3bAudioCdTrackDrag( m_toc, 
-				    tracks, 
-				    m_cddbInfo,
-				    m_device,
-				    this );
+    QDragObject* drag = new K3bAudioCdTrackDrag( m_toc, 
+						 tracks, 
+						 m_cddbInfo,
+						 m_device,
+						 this );
+    drag->setPixmap( m_trackView->createDragPixmap( items ) );
+    return drag;
   }
   else
     return 0;
