@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3baudiocdview.h 330821 2004-07-19 09:15:18Z trueg $
+ * $Id: k3baudiocdview.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 #ifndef _K3B_AUDIOCD_VIEW_H_
 #define _K3B_AUDIOCD_VIEW_H_
 
-#include <k3bcdcontentsview.h>
+#include <k3bmediacontentsview.h>
+#include <k3bmedium.h>
 
 #include <k3btoc.h>
 #include <k3bcddbresult.h>
@@ -36,12 +37,11 @@ class QDragObject;
 
 
 namespace K3bDevice {
-  class DiskInfoDetector;
   class Device;
 }
 
 
-class K3bAudioCdView : public K3bCdContentsView
+class K3bAudioCdView : public K3bMediaContentsView
 {
   Q_OBJECT
 
@@ -49,10 +49,6 @@ class K3bAudioCdView : public K3bCdContentsView
   K3bAudioCdView( QWidget* parent = 0, const char * name = 0 );
   ~K3bAudioCdView();
 
-  void setDisk( K3bDevice::DiskInfoDetector* );
-
-  //  const K3bDevice::DiskInfo& displayedDisk() const { return m_diskInfo; }
-
   KActionCollection* actionCollection() const { return m_actionCollection; }
 
   /**
@@ -61,7 +57,6 @@ class K3bAudioCdView : public K3bCdContentsView
   QDragObject* dragObject();
 
  public slots:
-  void reload();
   void queryCddb();
 
  private slots:
@@ -74,15 +69,18 @@ class K3bAudioCdView : public K3bCdContentsView
   void slotEditTrackCddb();
   void slotEditAlbumCddb();
   void startRip();
-  void slotSelectAll();
-  void slotDeselectAll();
+  void slotCheckAll();
+  void slotUncheckAll();
   void slotSelect();
   void slotDeselect();
 
  private:
+  void reloadMedium();
+
   void initActions();
   void updateDisplay();
   void enableInteraction( bool );
+  void showBusyLabel( bool );
 
   K3bDevice::Toc m_toc;
   K3bDevice::Device* m_device;
@@ -101,6 +99,8 @@ class K3bAudioCdView : public K3bCdContentsView
   K3bCddb* m_cddb;
 
   K3bDevice::CdText m_cdText;
+
+  QLabel* m_busyInfoLabel;
 };
 
 
