@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3baudioprojectconvertingthread.cpp 572907 2006-08-14 10:27:41Z trueg $
+ * $Id: k3baudioprojectconvertingthread.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2005 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2005 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -86,6 +86,12 @@ void K3bAudioProjectConvertingThread::setEncoder( K3bAudioEncoder* f )
 }
 
 
+void K3bAudioProjectConvertingThread::init()
+{
+  d->canceled = false;
+}
+
+
 void K3bAudioProjectConvertingThread::run()
 {
   emitStarted();
@@ -96,7 +102,6 @@ void K3bAudioProjectConvertingThread::run()
       d->waveFileWriter = new K3bWaveFileWriter();
     
 
-  d->canceled = false;
   d->overallBytesRead = 0;
   d->overallBytesToRead = m_doc->length().audioBytes();
 
@@ -113,9 +118,7 @@ void K3bAudioProjectConvertingThread::run()
     // initialize
     bool isOpen = true;
     if( d->encoder ) {
-      isOpen = d->encoder->openFile( d->fileType, filename, m_doc->length() );
-      
-      if( isOpen ) {
+      if( isOpen = d->encoder->openFile( d->fileType, filename, m_doc->length() ) ) {
 	// here we use cd Title and Artist
 	d->encoder->setMetaData( K3bAudioEncoder::META_TRACK_ARTIST, m_cddbEntry.cdArtist );
 	d->encoder->setMetaData( K3bAudioEncoder::META_TRACK_TITLE, m_cddbEntry.cdTitle );
@@ -126,6 +129,8 @@ void K3bAudioProjectConvertingThread::run()
 	d->encoder->setMetaData( K3bAudioEncoder::META_YEAR, QString::number(m_cddbEntry.year) );
 	d->encoder->setMetaData( K3bAudioEncoder::META_GENRE, m_cddbEntry.genre );
       }
+      else
+	emitInfoMessage( d->encoder->lastErrorString(), K3bJob::ERROR );
     }
     else {
       isOpen = d->waveFileWriter->open( filename );
@@ -150,6 +155,8 @@ void K3bAudioProjectConvertingThread::run()
       break;
     }
 
+    emitInfoMessage( i18n("Successfully converted track %1.").arg(i+1), K3bJob::INFO );
+
     track = track->next();
     ++i;
   }
@@ -161,15 +168,22 @@ void K3bAudioProjectConvertingThread::run()
       d->waveFileWriter->close();
   }
   
-  if( !d->canceled && m_writePlaylist ) {
+  if( !d->canceled && success && m_writePlaylist ) {
     success = success && writePlaylist();
   }
 
-  if( !d->canceled && m_writeCueFile && m_singleFile ) {
+  if( !d->canceled && success && m_writeCueFile && m_singleFile ) {
     success = success && writeCueFile();
   }
 
   if( d->canceled ) {
+    if( d->currentTrackIndex >= 0 && d->currentTrackIndex < (int)m_tracks.count() ) {
+      if( QFile::exists( m_tracks[d->currentTrackIndex].second ) ) {
+	QFile::remove( m_tracks[d->currentTrackIndex].second );
+	emitInfoMessage( i18n("Removed partial file '%1'.").arg(m_tracks[d->currentTrackIndex].second), K3bJob::INFO );
+      }
+    }
+
     emitCanceled();
     emitFinished(false);
   }
@@ -204,6 +218,8 @@ bool K3bAudioProjectConvertingThread::convertTrack( K3bAudioTrack* track, const
 	d->encoder->setMetaData( K3bAudioEncoder::META_YEAR, QString::number(m_cddbEntry.year) );
 	d->encoder->setMetaData( K3bAudioEncoder::META_GENRE, m_cddbEntry.genre );
       }
+      else
+	emitInfoMessage( d->encoder->lastErrorString(), K3bJob::ERROR );
     }
     else {
       isOpen = d->waveFileWriter->open( filename );
@@ -248,6 +264,7 @@ bool K3bAudioProjectConvertingThread::convertTrack( K3bAudioTrack* track, const
 
       if( d->encoder->encode( buffer, readLength ) < 0 ) {
 	kdDebug() << "(K3bAudioProjectConvertingThread) error while encoding." << endl;
+	emitInfoMessage( d->encoder->lastErrorString(), K3bJob::ERROR );
 	emitInfoMessage( i18n("Error while encoding track %1.").arg(d->currentTrackIndex+1), K3bJob::ERROR );
 	return false;
       }
