@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3baudiorippingdialog.cpp 401319 2005-03-28 16:26:58Z trueg $
- * Copyright (C) 2003-2005 Sebastian Trueg <trueg@k3b.org>
+ * $Id: k3baudiorippingdialog.cpp 619556 2007-01-03 17:38:12Z trueg $
+ * Copyright (C) 2003-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2005 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 
 
 #include "k3baudiorippingdialog.h"
-#include "k3baudioripthread.h"
+#include "k3baudioripjob.h"
 #include "k3bpatternparser.h"
 #include "k3bcddbpatternwidget.h"
 #include "k3baudioconvertingoptionwidget.h"
@@ -25,8 +25,7 @@
 #include <k3bglobals.h>
 #include <k3btrack.h>
 #include <k3bstdguiitems.h>
-#include <k3bthreadjob.h>
-
+#include <k3bfilesysteminfo.h>
 #include <k3bpluginmanager.h>
 #include <k3baudioencoder.h>
 
@@ -75,6 +74,7 @@ public:
 
   QValueVector<QString> filenames;
   QString playlistFilename;
+  K3bFileSystemInfo fsInfo;
 };
 
 
@@ -124,7 +124,7 @@ void K3bAudioRippingDialog::setupGui()
   Form1Layout->setMargin( 0 );
 
   m_viewTracks = new KListView( frame, "m_viewTracks" );
-  m_viewTracks->addColumn(i18n( "Filename (relative to base directory)") );
+  m_viewTracks->addColumn(i18n( "Filename") );
   m_viewTracks->addColumn(i18n( "Length") );
   m_viewTracks->addColumn(i18n( "File Size") );
   m_viewTracks->addColumn(i18n( "Type") );
@@ -135,7 +135,7 @@ void K3bAudioRippingDialog::setupGui()
   QTabWidget* mainTab = new QTabWidget( frame );
 
   m_optionWidget = new K3bAudioConvertingOptionWidget( mainTab );
-  mainTab->addTab( m_optionWidget, i18n("Options") );
+  mainTab->addTab( m_optionWidget, i18n("Settings") );
 
 
   // setup filename pattern page
@@ -155,14 +155,14 @@ void K3bAudioRippingDialog::setupGui()
 
   m_comboParanoiaMode = K3bStdGuiItems::paranoiaModeComboBox( advancedPage );
   m_spinRetries = new QSpinBox( advancedPage );
-  m_checkNeverSkip = new QCheckBox( i18n("Never skip"), advancedPage );
+  m_checkIgnoreReadErrors = new QCheckBox( i18n("Ignore read errors"), advancedPage );
   m_checkUseIndex0 = new QCheckBox( i18n("Don't read pregaps"), advancedPage );
 
   advancedPageLayout->addWidget( new QLabel( i18n("Paranoia mode:"), advancedPage ), 0, 0 );
   advancedPageLayout->addWidget( m_comboParanoiaMode, 0, 1 );
   advancedPageLayout->addWidget( new QLabel( i18n("Read retries:"), advancedPage ), 1, 0 );
   advancedPageLayout->addWidget( m_spinRetries, 1, 1 );
-  advancedPageLayout->addMultiCellWidget( m_checkNeverSkip, 2, 2, 0, 1 );
+  advancedPageLayout->addMultiCellWidget( m_checkIgnoreReadErrors, 2, 2, 0, 1 );
   advancedPageLayout->addMultiCellWidget( m_checkUseIndex0, 3, 3, 0, 1 );
   advancedPageLayout->setRowStretch( 4, 1 );
   advancedPageLayout->setColStretch( 2, 1 );
@@ -186,13 +186,8 @@ void K3bAudioRippingDialog::setupContextHelp()
   QToolTip::add( m_spinRetries, i18n("Maximal number of read retries") );
   QWhatsThis::add( m_spinRetries, i18n("<p>This specifies the maximum number of retries to "
 				       "read a sector of audio data from the cd. After that "
-				       "K3b will either skip the sector or stop the process "
-				       "if the <em>never-skip</em> option is enabled.") );
-  QToolTip::add( m_checkNeverSkip, i18n("Never skip a sector on error") );
-  QWhatsThis::add( m_checkNeverSkip, i18n("<p>If this option is checked K3b will never skip "
-					  "an audio sector if it was not readable (see retries)."
-					  "<p>K3b will stop the ripping process if a read error "
-					  "occurs.") );
+				       "K3b will either skip the sector if the <em>Ignore Read Errors</em> "
+				       "option is enabled or stop the process.") );
   QToolTip::add( m_checkUseIndex0, i18n("Do not read the pregaps at the end of every track") );
   QWhatsThis::add( m_checkUseIndex0, i18n("<p>If this option is checked K3b will not rip the audio "
 					  "data in the pregaps. Most audio tracks contain an empty "
@@ -246,7 +241,7 @@ void K3bAudioRippingDialog::slotStartClicked()
     if( KMessageBox::questionYesNoList( this, 
 					i18n("Do you want to overwrite these files?"),
 					filesToOverwrite,
-					i18n("Files Exist") ) == KMessageBox::No )
+					i18n("Files Exist"), i18n("Overwrite"), KStdGuiItem::cancel() ) == KMessageBox::No )
       return;
 
 
@@ -259,35 +254,31 @@ void K3bAudioRippingDialog::slotStartClicked()
     ++i;
   }
 
-
-  K3bAudioEncoder* encoder = m_optionWidget->encoder();
-
-  K3bAudioRipThread* thread = new K3bAudioRipThread();
-  thread->setDevice( m_device );
-  thread->setCddbEntry( m_cddbEntry );
-  thread->setTracksToRip( tracksToRip );
-  thread->setParanoiaMode( m_comboParanoiaMode->currentText().toInt() );
-  thread->setMaxRetries( m_spinRetries->value() );
-  thread->setNeverSkip( m_checkNeverSkip->isChecked() );
-  thread->setSingleFile( m_optionWidget->createSingleFile() );
-  thread->setWriteCueFile( m_optionWidget->createCueFile() );
-  thread->setEncoder( encoder );
-  thread->setWritePlaylist( m_optionWidget->createPlaylist() );
-  thread->setPlaylistFilename( d->playlistFilename );
-  thread->setUseRelativePathInPlaylist( m_optionWidget->playlistRelativePath() );
-  thread->setUseIndex0( m_checkUseIndex0->isChecked() );
-  if( encoder )
-    thread->setFileType( m_optionWidget->extension() );
-
   K3bJobProgressDialog ripDialog( parentWidget(), "Ripping" );
 
-  K3bThreadJob job( thread, &ripDialog, this );
+  K3bAudioEncoder* encoder = m_optionWidget->encoder();
+  K3bAudioRipJob* job = new K3bAudioRipJob( &ripDialog, this );
+  job->setDevice( m_device );
+  job->setCddbEntry( m_cddbEntry );
+  job->setTracksToRip( tracksToRip );
+  job->setParanoiaMode( m_comboParanoiaMode->currentText().toInt() );
+  job->setMaxRetries( m_spinRetries->value() );
+  job->setNeverSkip( !m_checkIgnoreReadErrors->isChecked() );
+  job->setSingleFile( m_optionWidget->createSingleFile() );
+  job->setWriteCueFile( m_optionWidget->createCueFile() );
+  job->setEncoder( encoder );
+  job->setWritePlaylist( m_optionWidget->createPlaylist() );
+  job->setPlaylistFilename( d->playlistFilename );
+  job->setUseRelativePathInPlaylist( m_optionWidget->playlistRelativePath() );
+  job->setUseIndex0( m_checkUseIndex0->isChecked() );
+  if( encoder )
+    job->setFileType( m_optionWidget->extension() );
 
   hide();
-  ripDialog.startJob(&job);
+  ripDialog.startJob(job);
 
-  kdDebug() << "(K3bAudioRippingDialog) deleting ripthread." << endl;
-  delete thread;
+  kdDebug() << "(K3bAudioRippingDialog) deleting ripjob." << endl;
+  delete job;
 
   close();
 }
@@ -299,6 +290,7 @@ void K3bAudioRippingDialog::refresh()
   d->filenames.clear();
 
   QString baseDir = K3b::prepareDir( m_optionWidget->baseDir() );
+  d->fsInfo.setPath( baseDir );
 
   KIO::filesize_t overallSize = 0;
 
@@ -336,6 +328,7 @@ void K3bAudioRippingDialog::refresh()
       filename = i18n("Album");
     }
 
+    filename = d->fsInfo.fixupPath( filename );
 
     (void)new KListViewItem( m_viewTracks,
 			     m_viewTracks->lastItem(),
@@ -343,8 +336,7 @@ void K3bAudioRippingDialog::refresh()
 			     K3b::Msf(length).toString(),
 			     fileSize < 0 ? i18n("unknown") : KIO::convertSize( fileSize ),
 			     i18n("Audio") );
-
-    d->filenames.append( K3b::fixupPath( baseDir + "/" + filename + "." + extension ) );
+    d->filenames.append( baseDir + "/" + filename + "." + extension );
 
     if( m_optionWidget->createCueFile() )
       (void)new KListViewItem( m_viewTracks,
@@ -394,6 +386,8 @@ void K3bAudioRippingDialog::refresh()
 	filename = i18n("Track%1").arg( QString::number( *it ).rightJustify( 2, '0' ) ) + "." + extension;
       }
 
+      filename = d->fsInfo.fixupPath( filename );
+
       (void)new KListViewItem( m_viewTracks,
 			       m_viewTracks->lastItem(),
 			       filename,
@@ -401,7 +395,7 @@ void K3bAudioRippingDialog::refresh()
 			       fileSize < 0 ? i18n("unknown") : KIO::convertSize( fileSize ),
 			       (m_toc[index].type() == K3bTrack::AUDIO ? i18n("Audio") : i18n("Data") ) );
 
-      d->filenames.append( K3b::fixupPath( baseDir + "/" + filename ) );
+      d->filenames.append( baseDir + "/" + filename );
     }
   }
 
@@ -419,7 +413,7 @@ void K3bAudioRippingDialog::refresh()
 			     "-",
 			     i18n("Playlist") );
     
-    d->playlistFilename = K3b::fixupPath( baseDir + "/" + filename );
+    d->playlistFilename = d->fsInfo.fixupPath( baseDir + "/" + filename );
   }
 
   if( overallSize > 0 )
@@ -438,8 +432,8 @@ void K3bAudioRippingDialog::setStaticDir( const QString& path )
 void K3bAudioRippingDialog::loadK3bDefaults()
 {
   m_comboParanoiaMode->setCurrentItem( 0 );
-  m_spinRetries->setValue(20);
-  m_checkNeverSkip->setChecked( false );
+  m_spinRetries->setValue(5);
+  m_checkIgnoreReadErrors->setChecked( true );
   m_checkUseIndex0->setChecked( false );
   
   m_optionWidget->loadDefaults();
@@ -451,8 +445,8 @@ void K3bAudioRippingDialog::loadK3bDefaults()
 void K3bAudioRippingDialog::loadUserDefaults( KConfigBase* c )
 {
   m_comboParanoiaMode->setCurrentItem( c->readNumEntry( "paranoia_mode", 0 ) );
-  m_spinRetries->setValue( c->readNumEntry( "read_retries", 20 ) );
-  m_checkNeverSkip->setChecked( c->readBoolEntry( "never_skip", false ) );
+  m_spinRetries->setValue( c->readNumEntry( "read_retries", 5 ) );
+  m_checkIgnoreReadErrors->setChecked( !c->readBoolEntry( "never_skip", true ) );
   m_checkUseIndex0->setChecked( c->readBoolEntry( "use_index0", false ) );
 
   m_optionWidget->loadConfig( c );
@@ -465,7 +459,7 @@ void K3bAudioRippingDialog::saveUserDefaults( KConfigBase* c )
 {
   c->writeEntry( "paranoia_mode", m_comboParanoiaMode->currentText().toInt() );
   c->writeEntry( "read_retries", m_spinRetries->value() );
-  c->writeEntry( "never_skip", m_checkNeverSkip->isChecked() );
+  c->writeEntry( "never_skip", !m_checkIgnoreReadErrors->isChecked() );
   c->writeEntry( "use_index0", m_checkUseIndex0->isChecked() );
 
   m_optionWidget->saveConfig( c );
