@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3baudiorippingdialog.h 401319 2005-03-28 16:26:58Z trueg $
+ * $Id: k3baudiorippingdialog.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@ class K3bAudioRippingDialog : public K3bInteractionDialog
 
   QComboBox* m_comboParanoiaMode;
   QSpinBox* m_spinRetries;
-  QCheckBox* m_checkNeverSkip;
+  QCheckBox* m_checkIgnoreReadErrors;
   QCheckBox* m_checkUseIndex0;
 
   K3bCddbPatternWidget* m_patternWidget;
