@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3baudioripthread.cpp 509876 2006-02-15 19:07:34Z trueg $
+ * $Id: k3baudioripthread.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,7 +45,9 @@ class K3bAudioRipThread::Private
 {
 public:
   Private()
-    : encoder(0),
+    : paranoiaRetries(5),
+      neverSkip(false),
+      encoder(0),
       waveFileWriter(0),
       paranoiaLib(0),
       canceled(false) {
@@ -204,9 +206,7 @@ void K3bAudioRipThread::run()
     // initialize
     bool isOpen = true;
     if( d->encoder ) {
-      isOpen = d->encoder->openFile( d->fileType, filename, d->overallSectorsToRead );
-
-      if( isOpen ) {
+      if( isOpen = d->encoder->openFile( d->fileType, filename, d->overallSectorsToRead ) ) {
 	// here we use cd Title and Artist
 	d->encoder->setMetaData( K3bAudioEncoder::META_TRACK_ARTIST, m_cddbEntry.cdArtist );
 	d->encoder->setMetaData( K3bAudioEncoder::META_TRACK_TITLE, m_cddbEntry.cdTitle );
@@ -217,6 +217,8 @@ void K3bAudioRipThread::run()
 	d->encoder->setMetaData( K3bAudioEncoder::META_YEAR, QString::number(m_cddbEntry.year) );
 	d->encoder->setMetaData( K3bAudioEncoder::META_GENRE, m_cddbEntry.genre );
       }
+      else
+	emitInfoMessage( d->encoder->lastErrorString(), K3bJob::ERROR );
     }
     else {
       isOpen = d->waveFileWriter->open( filename );
@@ -276,8 +278,8 @@ void K3bAudioRipThread::run()
     emitFinished(false);
   }
   else {
-  if( k3bcore->globalSettings()->ejectMedia() )
-    m_device->eject();
+    if( k3bcore->globalSettings()->ejectMedia() )
+      m_device->eject();
 
     emitFinished(success);
   }
@@ -320,6 +322,8 @@ bool K3bAudioRipThread::ripTrack( int track, const QString& filename )
 	  d->encoder->setMetaData( K3bAudioEncoder::META_YEAR, QString::number(m_cddbEntry.year) );
 	  d->encoder->setMetaData( K3bAudioEncoder::META_GENRE, m_cddbEntry.genre );
 	}
+	else
+	  emitInfoMessage( d->encoder->lastErrorString(), K3bJob::ERROR );
       }
       else {
 	isOpen = d->waveFileWriter->open( filename );
@@ -366,6 +370,7 @@ bool K3bAudioRipThread::ripTrack( int track, const QString& filename )
 	    if( d->encoder->encode( buf, 
 				    CD_FRAMESIZE_RAW ) < 0 ) {
 	      kdDebug() << "(K3bAudioRipThread) error while encoding." << endl;
+	      emitInfoMessage( d->encoder->lastErrorString(), K3bJob::ERROR );
 	      emitInfoMessage( i18n("Error while encoding track %1.").arg(track), K3bJob::ERROR );
 	      return false;
 	    }
