@@ -1,10 +1,10 @@
 /*
 *
-* $Id: k3bvideocdview.cpp 358238 2004-10-27 16:16:40Z binner $
+* $Id: k3bvideocdview.cpp 619556 2007-01-03 17:38:12Z trueg $
 * Copyright (C) 2003 Christian Kvasny <chris@k3b.org>
 *
 * This file is part of the K3b project.
-* Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+* Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -30,12 +30,13 @@
 #include <qheader.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <qcursor.h>
+#include <qapplication.h>
 
 // k3b includes
 #include "k3bvideocdview.h"
 #include "k3bvideocdrippingdialog.h"
 
-#include <cdinfo/k3bdiskinfodetector.h>
 #include <k3bdevice.h>
 #include <k3bmsf.h>
 #include <k3btoc.h>
@@ -61,8 +62,8 @@ class K3bVideoCdView::VideoTrackViewItem : public QListViewItem
         }
         
         VideoTrackViewItem( QListViewItem* parent,
-                            QString name,
-                            QString id,
+                            const QString& name,
+                            const QString& id,
                             int _trackNumber,
                             const K3b::Msf& length )
                 : QListViewItem( parent )
@@ -92,7 +93,7 @@ class K3bVideoCdView::VideoTrackViewCheckItem : public QCheckListItem
 {
     public:
         VideoTrackViewCheckItem( QListViewItem* parent,
-                                 QString desc )
+                                 const QString& desc )
                 : QCheckListItem( parent,
                                   QString::null,
                                   QCheckListItem::CheckBox )
@@ -103,7 +104,7 @@ class K3bVideoCdView::VideoTrackViewCheckItem : public QCheckListItem
         }
 
         VideoTrackViewCheckItem( QListView* parent,
-                                 QString desc )
+                                 const QString& desc )
                 : QCheckListItem( parent,
                                   QString::null,
                                   QCheckListItem::CheckBox )
@@ -114,7 +115,7 @@ class K3bVideoCdView::VideoTrackViewCheckItem : public QCheckListItem
         }
 
         VideoTrackViewCheckItem( VideoTrackViewCheckItem* parent,
-                                 QString desc )
+                                 const QString& desc )
                 : QCheckListItem( parent,
                                   QString::null,
                                   QCheckListItem::CheckBox )
@@ -136,7 +137,11 @@ class K3bVideoCdView::VideoTrackViewCheckItem : public QCheckListItem
 };
 
 K3bVideoCdView::K3bVideoCdView( QWidget* parent, const char *name )
-        : K3bCdContentsView( true, parent, name )
+        : K3bMediaContentsView( true,
+				K3bMedium::CONTENT_VIDEO_CD,
+				K3bDevice::MEDIA_CD_ALL,
+				K3bDevice::STATE_INCOMPLETE|K3bDevice::STATE_COMPLETE,
+				parent, name )
 {
     QGridLayout * mainGrid = new QGridLayout( mainWidget() );
 
@@ -198,13 +203,15 @@ K3bVideoCdView::~K3bVideoCdView()
 }
 
 
-void K3bVideoCdView::setDisk( K3bDevice::DiskInfoDetector* did )
+void K3bVideoCdView::reloadMedium()
 {
-  m_toc = did->toc();
-    m_device = did->device();
+    m_toc = medium().toc();
 
     m_trackView->clear();
-    enableInteraction( false );
+
+    m_trackView->setEnabled( false );
+    m_toolBox->setEnabled( false );
+    QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
 
     m_contentList.append( new VideoTrackViewCheckItem( m_trackView, i18n("Video CD MPEG tracks") ) );
     m_contentList.append( new VideoTrackViewCheckItem( m_trackView, i18n("Video CD DATA track" ) ) );
@@ -218,7 +225,7 @@ void K3bVideoCdView::setDisk( K3bDevice::DiskInfoDetector* did )
             
     K3b::Msf sequenceSize;
 
-    for ( K3bToc::const_iterator it = m_toc.begin();
+    for ( K3bDevice::Toc::const_iterator it = m_toc.begin();
             it != m_toc.end(); ++it ) {
 
         if ( index > 0 ) {
@@ -239,10 +246,10 @@ void K3bVideoCdView::setDisk( K3bDevice::DiskInfoDetector* did )
 
     ( ( VideoTrackViewCheckItem* ) m_contentList[ 0 ] ) ->updateData( sequenceSize, true );
 
-    m_videooptions ->setVideoCdSource( m_device->devicename() );
+    m_videooptions ->setVideoCdSource( device()->devicename() );
     
     m_videocdinfo = new K3bVideoCdInfo( this );
-    m_videocdinfo->info( m_device->devicename() );
+    m_videocdinfo->info( device()->devicename() );
 
     connect( m_videocdinfo, SIGNAL( infoFinished( bool ) ),
              this, SLOT( slotVideoCdInfoFinished( bool ) ) );
@@ -251,13 +258,15 @@ void K3bVideoCdView::setDisk( K3bDevice::DiskInfoDetector* did )
 
 void K3bVideoCdView::slotVideoCdInfoFinished( bool success )
 {
-
     if ( success ) {
         m_videocdinfoResult = m_videocdinfo->result();
         updateDisplay();
     }
 
-    enableInteraction( true );
+    m_trackView->setEnabled( true );
+    m_toolBox->setEnabled( true );
+    QApplication::restoreOverrideCursor();
+
 }
 
 void K3bVideoCdView::updateDisplay()
@@ -341,7 +350,7 @@ void K3bVideoCdView::initActions()
     m_popupMenu->insert( actionStartRip );
 
     // setup the toolbox
-    m_toolBox->addButton( actionStartRip );
+    m_toolBox->addButton( actionStartRip, true );
 }
 
 
@@ -458,11 +467,10 @@ void K3bVideoCdView::slotDeselect()
 
 void K3bVideoCdView::enableInteraction( bool b )
 {
-    m_trackView->setEnabled( b );
-    m_toolBox->setEnabled( b );
+  actionCollection()->action( "start_rip" )->setEnabled( b );
 }
 
-void K3bVideoCdView::buildTree( QListViewItem *parentItem, const QDomElement &parentElement, QString pname )
+void K3bVideoCdView::buildTree( QListViewItem *parentItem, const QDomElement &parentElement, const QString& pname )
 {
     VideoTrackViewItem * thisItem = 0;
     QDomNode node = parentElement.firstChild();
@@ -477,13 +485,12 @@ void K3bVideoCdView::buildTree( QListViewItem *parentItem, const QDomElement &pa
             QString txt = node.firstChild().toElement().text();
             thisItem->setText( 0, txt);
             if ( node.nodeName() == "folder" ) {
-                pname += "_" + txt.lower();
+		buildTree( thisItem, node.toElement(), pname + "_" + txt.lower() );
             }
             else {
                 thisItem->setText( 1, pname + "_" + txt.lower() );
+		buildTree( thisItem, node.toElement(), pname );
             }
-
-            buildTree( thisItem, node.toElement(), pname );
         } else if ( node.isElement() && node.nodeName() == "segment-item" || node.nodeName() == "sequence-item" ) {
             if ( parentItem == 0 )
                 thisItem = new VideoTrackViewItem( m_trackView, thisItem );
